function H = L14(p)
% ------------------------------------------------------------------------------
% 2017-10-01 Wojciech Bruzda; name[at]uj.edu.pl : name = w.bruzda
%            https://chaos.if.uj.edu.pl/~karol/hadamard/
%            https://github.com/matrix-toolbox/
% ------------------------------------------------------------------------------
% A 2-parametric family of CHM of order N = 14, stemming from BH(14, 10).
% Taken from Example 2.1 of https://arxiv.org/pdf/1707.02287.pdf by P. Lampio et al.
% It is permuted and dephased yet still equivalent to the original one.
%
% >> H = L14(rand(1, 2));
% ------------------------------------------------------------------------------

    L14 = exp(2j*pi*[ % LOG-form
         0 0 0 0 0 0 0 0 0 0 0 0 0 0;
         0 0 8 6 5 4 2 0 0 8 6 5 4 2;
         0 0 8 6 5 4 2 5 5 3 1 0 9 7;
         0 1 3 5 2 9 5 7 9 3 7 7 1 5;
         0 2 4 4 9 6 9 9 4 5 1 6 7 1;
         0 2 6 2 5 8 7 3 7 1 5 0 5 0;
         0 4 0 2 3 4 7 9 5 8 7 2 9 5;
         0 4 4 8 1 2 3 5 7 9 9 4 6 9;
         0 5 8 0 1 6 0 4 2 4 6 6 2 8;
         0 6 2 6 7 2 7 5 3 9 4 8 1 1;
         0 6 2 1 7 2 2 0 8 4 4 8 6 6;
         0 6 7 4 9 8 4 8 2 0 2 2 4 6;
         0 8 2 8 3 7 8 4 0 6 2 2 6 4;
         0 8 6 0 7 0 5 2 5 5 9 4 1 3;
    ]/10);

    R = [
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 p(2) p(2) p(2) p(2) p(2) p(2) p(2);
        0 0 0 0 0 0 0 p(2) p(2) p(2) p(2) p(2) p(2) p(2);
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 p(1) 0 0 p(1) p(1) p(1) p(1) 0 0 p(1) p(1);
        0 0 0 p(1) 0 0 p(1) p(1) p(1) p(1) 0 0 p(1) p(1);
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
        0 0 0 0 0 0 0 0 0 0 0 0 0 0;
    ];

    H = L14 .* exp(2j * pi * R);

end
