function H = P13(p)
% ------------------------------------------------------------------------------
% 2006-12-05 Wojciech Bruzda; name[at]uj.edu.pl : name = w.bruzda
%            https://chaos.if.uj.edu.pl/~karol/hadamard/
%            https://github.com/matrix-toolbox/
% ------------------------------------------------------------------------------
% A 2-parametric family stemming from BH(13, 60), found by M. Petrescu
%
% >> H = P13(rand(1, 2));
% ------------------------------------------------------------------------------
    a = p(1);
    b = p(2);

    P13 = exp(2j * pi * [
        0  0  0  0  0  0  0  0  0  0  0  0  0;
        0 30 20 40 10 25 55 45 15 32  8 44 56;
        0 20 30 10 40 55 25 15 45 32  8 44 56;
        0 40 10 30 20 45 15 25 55  8 32 56 44;
        0 10 40 20 30 15 45 55 25  8 32 56 44;
        0 25 55  5 35 30 20 40 10 44 56  8 32;
        0 55 25 35  5 20 30 10 40 44 56  8 32;
        0  5 35 25 55 40 10 30 20 56 44 32  8;
        0 35  5 55 25 10 40 20 30 56 44 32  8;
        0  8  8 32 32 56 56 44 44 40 20 20 20;
        0 32 32  8  8 44 44 56 56 20 40 20 20;
        0 56 56 44 44 32 32  8  8 20 20 40 20;
        0 44 44 56 56  8  8 32 32 20 20 20 40;
    ]/60);

    G = angle(- cos(b) / 2 + i * (sqrt(2) / 4) * sqrt(7 - cos(2 * b))) - 2 * pi / 3;

    R = [
        0        0        0        0        0       0       0       0       0 0 0 0 0;
        0        0        0        b        b       a       a (a + G) (a + G) 0 0 0 0;
        0        0        0        b        b       a       a (a + G) (a + G) 0 0 0 0;
        0        b        b        0        0 (a + G) (a + G)       a       a 0 0 0 0;
        0        b        b        0        0 (a + G) (a + G)       a       a 0 0 0 0;
        0       -a       -a -(a + G) -(a + G)       0       0      -b      -b 0 0 0 0;
        0       -a       -a -(a + G) -(a + G)       0       0      -b      -b 0 0 0 0;
        0 -(a + G) -(a + G)       -a       -a      -b      -b       0       0 0 0 0 0;
        0 -(a + G) -(a + G)       -a       -a      -b      -b       0       0 0 0 0 0;
        0        0        0        0        0       0       0       0       0 0 0 0 0;
        0        0        0        0        0       0       0       0       0 0 0 0 0;
        0        0        0        0        0       0       0       0       0 0 0 0 0;
        0        0        0        0        0       0       0       0       0 0 0 0 0;
    ];

    H = P13 .* exp(i * R);

end
