function H = S16(p)
% ------------------------------------------------------------------------------
% 2006-12-05 Wojciech Bruzda; name[at]uj.edu.pl : name = w.bruzda
%            https://chaos.if.uj.edu.pl/~karol/hadamard/
%            https://github.com/matrix-toolbox/
% ------------------------------------------------------------------------------
% A 11-parametric family of CHM stemming from BH(16, 8) found by M. Matolcsi et al.
% https://arxiv.org/abs/quant-ph/0607073
%
% >> S16(rand(1, 11));
% ------------------------------------------------------------------------------

    S16 = exp(2j*pi*[
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0;
        0, 4, 6, 2, 7, 3, 5, 1, 0, 4, 6, 2, 0, 4, 6, 2;
        0, 0, 4, 4, 6, 6, 2, 2, 0, 0, 4, 4, 0, 0, 4, 4;
        0, 4, 2, 6, 5, 1, 7, 3, 0, 4, 2, 6, 0, 4, 2, 6;
        0, 0, 0, 0, 4, 4, 4, 4, 5, 0, 0, 0, 1, 4, 4, 4;
        0, 4, 6, 2, 3, 7, 1, 5, 5, 4, 6, 2, 1, 0, 2, 6;
        0, 0, 4, 4, 2, 2, 6, 6, 5, 0, 4, 4, 1, 4, 0, 0;
        0, 4, 2, 6, 1, 5, 3, 7, 5, 4, 2, 6, 1, 0, 6, 2;
        0, 0, 0, 6, 0, 0, 0, 0, 4, 4, 4, 2, 4, 4, 4, 4;
        0, 4, 6, 0, 7, 3, 5, 1, 4, 0, 2, 4, 4, 0, 2, 6;
        0, 0, 4, 2, 6, 6, 2, 2, 4, 4, 0, 6, 4, 4, 0, 0;
        0, 4, 2, 4, 5, 1, 7, 3, 4, 0, 6, 0, 4, 0, 6, 2;
        0, 0, 0, 6, 4, 4, 4, 4, 1, 4, 4, 2, 5, 0, 0, 0;
        0, 4, 6, 0, 3, 7, 1, 5, 1, 0, 2, 4, 5, 4, 6, 2;
        0, 0, 4, 2, 2, 2, 6, 6, 1, 4, 0, 6, 5, 0, 4, 4;
        0, 4, 2, 4, 1, 5, 3, 7, 1, 0, 6, 0, 5, 4, 2, 6;
    ]/8);

    R = [
        0 0 0         0         0          0          0          0          0     0     0         0         0     0      0          0        ;
        0 0 p(8)+p(9) p(9)      p(3)       p(3)       p(2)       p(2)       p(11) p(11) p(9)      p(9)      p(11) p(11)  p(9)       p(8)+p(9);
        0 0 0         0         p(4)       p(4)       p(4)       p(4)       0     0     0         0         0     0      0          0        ;
        0 0 p(8)+p(9) p(9)      p(3)+p(10) p(3)+p(10) p(2)+p(10) p(2)+p(10) p(11) p(11) p(9)      p(9)      p(11) p(11)  p(9)       p(8)+p(9);
        0 0 p(8)      0         0          0          0          0          p(1)  p(6)  p(5)      0         p(1)  p(6)   p(5)       p(8)     ;
        0 0 p(9)      p(9)      p(3)       p(3)       p(2)       p(2)       p(1)  p(6)  p(5)+p(9) p(9)      p(1)  p(6)   p(5)+p(9)  p(9)     ;
        0 0 p(8)      0         p(4)       p(4)       p(4)       p(4)       p(1)  p(6)  p(5)      0         p(1)  p(6)   p(5)       p(8)     ;
        0 0 p(9)      p(9)      p(3)+p(10) p(3)+p(10) p(2)+p(10) p(2)+p(10) p(1)  p(6)  p(5)+p(9) p(9)      p(1)  p(6)   p(5)+p(9)  p(9)     ;
        0 0 p(8)      p(7)      0          0          0          0          0     0     0         p(7)      0     0      0          p(8)     ;
        0 0 p(9)      p(7)+p(9) p(3)       p(3)       p(2)       p(2)       p(11) p(11) p(9)      p(7)+p(9) p(11) p(11)  p(9)       p(9)     ;
        0 0 p(8)      p(7)      p(4)       p(4)       p(4)       p(4)       0     0     0         p(7)      0     0      0          p(8)     ;
        0 0 p(9)      p(7)+p(9) p(3)+p(10) p(3)+p(10) p(2)+p(10) p(2)+p(10) p(11) p(11) p(9)      p(7)+p(9) p(11) p(11)  p(9)       p(9)     ;
        0 0 0         p(7)      0          0          0          0          p(1)  p(6)  p(5)      p(7)      p(1)  p(6)   p(5)       0        ;
        0 0 p(8)+p(9) p(7)+p(9) p(3)       p(3)       p(2)       p(2)       p(1)  p(6)  p(5)+p(9) p(7)+p(9) p(1)  p(6)   p(5)+p(9)  p(8)+p(9);
        0 0 0         p(7)      p(4)       p(4)       p(4)       p(4)       p(1)  p(6)  p(5)      p(7)      p(1)  p(6)   p(5)       0        ;
        0 0 p(8)+p(9) p(7)+p(9) p(3)+p(10) p(3)+p(10) p(2)+p(10) p(2)+p(10) p(1)  p(6)  p(5)+p(9) p(7)+p(9) p(1)  p(6)   p(5)+p(9)  p(8)+p(9);
    ];

    H = S16 .* exp(2j * pi * R);

end
