function Y = SH_10_8_58()
% ------------------------------------------------------------------------------
% 2023-02-25 Wojciech Bruzda; name[at]uj.edu.pl : name = w.bruzda
%            https://chaos.if.uj.edu.pl/~karol/hadamard/
%            https://github.com/matrix-toolbox/
% ------------------------------------------------------------------------------
% Symmetric CHM of order N = 10 with d = 5 and #L = 58.
% It is a special solution of "SH_10_0_134.m".
%
% Parameter `a` is a root of the palindromic polynomial:
%
% p(x) = 1 + 4x - 40x^2 - 60x^3 + 180x^4 + 490x^5 + 328x^6 - 340x^7 - 730x^8
%        -340x^9 + 328x^10 + 492x^11 + 180x^12 - 60x^13 - 40x^14 + 4x^15 + x^16;
% ------------------------------------------------------------------------------

    a = -0.345785662532608 - 0.938313527338749i;

    DELTA = (1 + 1/a^4)^2 - 4*(2/a^4 + 2/a^5)*(2 + 2*a);
    b = (-(1 + 1/a^4) + sqrt(DELTA)) / 2 / (2/a^4 + 2/a^5);

    Y = [
        1   1       1        1        1        1         1         1      1         1        ;
        1  -a^4/b  -b/a^2    a        b/a^2    a^4/b    -a^2      -1      a^2      -a        ;
        1  -b/a^2  -b^2/a^3  b^2/a^4  b/a^2    1/a      -b^2/a^4  -1/a    b^2/a^3  -1        ;
        1   a       b^2/a^4  b^2/a^5  b^2/a^5  1         b^2/a^4   b/a^4  b         a        ;
        1   b/a^2   b/a^2    b^2/a^5  1/b      1/b       1/a^2     1/a^2  1         a^3/b^2  ;
        1   a^4/b   1/a      1        1/b      a^5/b^2   a^4/b^2   1/a    a^5/b^2   a^4/b^2  ;
        1  -a^2    -b^2/a^4  b^2/a^4  1/a^2    a^4/b^2  -1        -1/a^2  a^2      -a^4/b^2  ;
        1  -1      -1/a      b/a^4    1/a^2    1/a      -1/a^2    -b/a^4  a^2/b    -a^2/b    ;
        1   a^2     b^2/a^3  b        1        a^5/b^2   a^2       a^2/b  b         a^2/b    ;
        1  -a      -1        a        a^3/b^2  a^4/b^2  -a^4/b^2  -a^2/b  a^2/b    -a^3/b^2  ;
    ];

end


%Solve[
% 2 + 2 a^2
% + (16*a^3*(1 + a)^2)/(-1 + a^4*(-1 + Sqrt[1 + 1/a^8 - (2*(8 + a*(15 + 8*a)))/a^5]))^2
% + (8*a*(1 + a))/(-1 + a^4*(-1 + Sqrt[1 + 1/a^8 - (2*(8 + a*(15 + 8*a)))/a^5])) 
% + (-1 + a^4*(-1 + Sqrt[1 + 1/a^8 - (2*(8 + a*(15 + 8*a)))/a^5]))^2/(16*a*(1 + a)^2)
% + (-a + a^5*(-1 + Sqrt[1 + 1/a^8 - (2*(8 + a*(15 + 8*a)))/a^5]))/(2*(1 + a)) == 0,
% a]