function Y = HH_12_13_18(p)
% ------------------------------------------------------------------------------
% 2023-01-25 Wojciech Bruzda; name[at]uj.edu.pl : name = w.bruzda
%            https://chaos.if.uj.edu.pl/~karol/hadamard/
%            https://github.com/matrix-toolbox/
% ------------------------------------------------------------------------------
% A 2-parametric Hermitian affine family of CHM stemming from BH(12, 2) (d = 55)
% with generic d = 13 and #L = 18.
% Found as a solution of "HH_12_5_1902.m" and defined as a separate pattern.
% ------------------------------------------------------------------------------
% |-----|-----|----|----|--------------|
% | p1  | p2  | d  | #L | q : BH(12,q) |
% |-----|-----|----|----|--------------|
% | r1  | r2  | 13*| 18 | -            |
% | 0   | 1/4 | 27 | 4  | 4            |
% | 1/3 | 1/3 | 37 | 6  | 6            |
% | 0   | 0   | 55 | 2  | 2            |
% |-----|-----|----|----|--------------|
% ------------------------------------------------------------------------------

    a = exp(2j*pi* p(1));
    b = exp(2j*pi* p(2));
    c = -b/a;
    Y = [
        1    1    1    1    1    1    1    1    1    1    1    1  ;
        1    1    b   -b    1   -1    a    c   -1   -1   -c   -a  ;
        1    b'   1    1   -1   -b'   c'  -1    c'  -c'  -1   -c' ;
        1   -b'   1    1   -1    b'  -c'  -1   -c'   c'  -1    c' ;
        1    1   -1   -1    1    1   -1   -1    1    1   -1   -1  ;
        1   -1   -b    b    1    1   -a    c   -1   -1   -c    a  ;
        1    a'   c   -c   -1   -a'  -1    1    1   -1    1   -1  ;
        1    c'  -1   -1   -1    c'   1   -1   -c'  -c'   1    1  ;
        1   -1    c   -c    1   -1    1   -c   -1    1    c   -1  ;
        1   -1   -c    c    1   -1   -1   -c    1   -1    c    1  ;
        1   -c'  -1   -1   -1   -c'   1    1    c'   c'  -1    1  ;
        1   -a'  -c    c   -1    a'  -1    1   -1    1    1   -1  ;
    ];

end
