function Y = TU_16_17_146A(p)
% ------------------------------------------------------------------------------
% 2022-12-26 Wojciech Bruzda; name[at]uj.edu.pl : name = w.bruzda
%            https://chaos.if.uj.edu.pl/~karol/hadamard/
%            https://github.com/matrix-toolbox/
% ------------------------------------------------------------------------------
% A 4-parametric 2-unitary CHM(16)... Probably equivalent to TU_16_17_146B(p).
%
% p1      p2      p3      p4      d       #L     q
% ------------------------------------------------
% r       r       r       r       17     146    ..
% 1/9     2/3     1/3     1/2     23      18    18
% 1/9     1/3     1/3     1/2     24      18    18
% 1/5     1/4     1/4     1/4     25      20    20
% 1/6     2/3     2/3     1/5     29      18    30
% 1/3     0       0       1/4     33      12    12
% 1/9     2/3     1/2     1/2     35      18    18
% 1/4     1/4     1/4     1/5     37      12    20
% 1/2     1/2     2/3     1/4     39      12    12
% 1/3     0       0       1/2     41       6     6
% 5/6     2/3     1/2     1/2     45       6     6
% 1/2     1/3     1/4     1/2     49      12    12
% 0       0       1/3     1/2     57       6     6
% 0       0       2/3     1       63       6     6
% 1/2     1/3     0       1/2     65       6     6
% 1       1/4     1       1/2     73       4     4
% 0       0       0       0       105      2    ..
% :       :       :       :       :        :     :
%
% It might happen that for different pj the defect is the same,
% but #L and/or q are different.
%
%
% ------------------------------------------------------------------------------
% k1    k2    k3    k4    d
% ==============================
% 1  &  0  &  1  &  3  &  17* \\
% 2  &  0  &  3  &  1  &  19  \\
% 1  &  2  &  5  &  0  &  23  \\
% 1  &  0  &  1  &  0  &  24  \\
% 1  &  0  &  4  &  3  &  25  \\
% 2  &  0  &  3  &  0  &  26  \\
% 1  &  0  &  7  &  3  &  29  \\
% 4  &  1  &  3  &  0  &  30  \\
% 1  &  2  &  4  &  0  &  31  \\
% 1  &  0  &  4  &  0  &  32  \\
% 0  &  1  &  3  &  1  &  33  \\
% 0  &  1  &  5  &  1  &  35  \\
% 1  &  0  &  7  &  8  &  37  \\
% 0  &  0  &  1  &  1  &  39  \\
% 0  &  0  &  4  &  1  &  41  \\
% 2  &  1  &  4  &  0  &  43  \\
% 0  &  1  &  0  &  1  &  45  \\
% 0  &  1  &  5  &  0  &  47  \\
% 0  &  1  &  2  &  0  &  49  \\
% 4  &  0  &  4  &  0  &  51  \\
% 0  &  0  &  1  &  8  &  57  \\
% 0  &  0  &  1  &  0  &  63  \\
% 0  &  0  &  4  &  0  &  65  \\
% 0  &  0  &  0  &  1  &  73  \\
% 0  &  0  &  0  &  0  &  105 \\
% :  &  :  &  :  &  :  &  :   \\
%
% where pj = kj/16 ...
% ------------------------------------------------------------------------------

    a=exp(2j*pi*p(1));
    b=exp(2j*pi*p(2));
    c=exp(2j*pi*p(3));
    d=exp(2j*pi*p(4)); % d = -a;
    A=a*c;
    B=c*d;
    C=b*d;

    Y = [
        1   1   1     1     1   1     1   1     1   1   1     1     1     1   1     1 ;
        1   a  -d/a   d/a  -a  -1     d  -d     a   1   d/a  -d/a  -1    -a  -d     d ;
        1   b   d/a  -C/a   a   a/b   d  -d/b  -b  -1   C/a  -d/a  -a/b  -a   d/b  -d ;
        1  -b  -1     b/a  -1   1/b   1  -a/b   b  -1  -b/a   1    -1/b   1   a/b  -1 ;
        1   c  -c    -c     c   1    -1  -1     c   1  -c    -c     1     c  -1    -1 ;
        1   A   B/a  -B/a  -A  -1    -d   d     A   1  -B/a   B/a  -1    -A   d    -d ;
        1   b  -B/a   C/a   A   A/b  -d   B/b  -b  -1  -C/a   B/a  -A/b  -A  -B/b   d ;
        1  -b   c    -b/a  -c   c/b  -1   A/b   b  -1   b/a  -c    -c/b   c  -A/b   1 ;
        1  -1  -1    -1    -1   1     1   1    -1   1  -1    -1     1    -1   1     1 ;
        1  -a   d/a  -d/a   a  -1     d  -d    -a   1  -d/a   d/a  -1     a  -d     d ;
        1   b  -d/a  -C/a  -a  -a/b   d   d/b  -b  -1   C/a   d/a   a/b   a  -d/b  -d ;
        1  -b   1     b/a   1  -1/b   1   a/b   b  -1  -b/a  -1     1/b  -1  -a/b  -1 ;
        1  -c   c     c    -c   1    -1  -1    -c   1   c     c     1    -c  -1    -1 ;
        1  -A  -B/a   B/a   A  -1    -d   d    -A   1   B/a  -B/a  -1     A   d    -d ;
        1   b   B/a   C/a  -A  -A/b  -d  -B/b  -b  -1  -C/a  -B/a   A/b   A   B/b   d ;
        1  -b  -c    -b/a   c  -c/b  -1  -A/b   b  -1   b/a   c     c/b  -c   A/b   1 ;
    ];

    w1 = exp(1j*pi/3);
    w2 = exp(2j*pi/3);

    DL = diag(exp(1j*pi*[0,4,0,2,4,5,1,0,4,2,4,0,0,1,3,2]/3));
    DR = diag([1, 1, 1, 1, 1, b^2, b^2/a, b^2/a, -1/b, b, -1, 1, -a/b*w1, a/b*w1, w2^2, w1]);

    Y = DL * Y * DR;

end

