function Y = TU_16_23_26(p)
% ------------------------------------------------------------------------------
% 2022-12-30 Wojciech Bruzda; name[at]uj.edu.pl : name = w.bruzda
%            https://chaos.if.uj.edu.pl/~karol/hadamard/
%            https://github.com/matrix-toolbox/
% ------------------------------------------------------------------------------
% A 2-parameter 2-unitary family of CHM.
%
% p1    p2    d    #L   q : BH(16, q)
%------------------------------------
% r     r     23   -    -
% 2/3   2/3   27   6    6
% 5/6   1/6   35   6    6
% 3/4   3/4   45   4    4
% r     0     49   -    -
% 0     0     105  2    2
%
% "exhaustive" check for Y(p1/16, p2/16)
% p1 &  p2 &    d
%----------------
% 1  &  2  &   23 * <-- generic value of defect
% 1  &  1  &   27
% 1  &  7  &   35
% 4  &  4  &   45
% 0  &  1  &   49
% 0  &  0  &  105
% ------------------------------------------------------------------------------

    a = exp(2j*pi*p(1));
    b = exp(2j*pi*p(2));

    Y = [
        1    1     1     1       1       1      1       1       1      1       1      1      1       1       1       1      ;
        1   -1     1    -1       1      -1      1      -1       b      1      -b     -1     -1/b    -1       1/b     1      ;
        1    b     b    -1      -1/b     1     -1      -1/b    -b      1      -1     -b      1       1/b     1/b    -1      ;
        1    1/b  -1    -1/b    -1/b^2  -1/b    1/b^2   1/b    -1/b    1/b    -1/b    1/b   -1/b     1/b    -1/b     1/b    ;
        1    a    -1     1/b     a/b    -a     -a/b    -1/b    -1      1/b     1      a     -a/b    -1/b     a/b    -a      ;
        1   -a    -1    -1/b     a/b     a     -a/b     1/b    -a     -1/b    -a      a      1/b    -1/b     1/b     a      ;
        1    1     1/a   1/b     1/b     1/a    1/b/a   1/b/a  -1/a   -1/b    -1     -1     -1/b/a  -1/b/a  -1/b    -1/a    ;
        1   -1     1     1/b/a  -1/b/a  -1     -1/b/a   1/b/a   1/a    1/b/a  -1/a    1      1/b    -1/b/a  -1/b    -1      ;
        1    1     1    -1      -1       1     -1      -1       1     -1       1      1     -1      -1      -1       1      ;
        1   -1     1     1      -1      -1     -1       1      -b     -1       b     -1     -1/b     1       1/b     1      ;
        1   -b    -b     1      -1/b     1      1      -1/b     b     -1      -1      b     -1       1/b     1/b    -1      ;
        1   -1/b  -1    -1/b     1/b^2   1/b   -1/b^2   1/b     1/b    1/b     1/b   -1/b   -1/b     1/b    -1/b    -1/b    ;
        1   -a    -1     1/b    -a/b     a      a/b    -1/b    -1      1/b     1     -a      a/b    -1/b    -a/b     a      ;
        1    a    -1    -1/b    -a/b    -a      a/b     1/b     a     -1/b     a     -a      1/b    -1/b     1/b    -a      ;
        1    1    -1/a   1/b     1/b    -1/a   -1/b/a  -1/b/a   1/a   -1/b    -1     -1      1/b/a   1/b/a  -1/b     1/a    ;
        1   -1     1    -1/b/a   1/b/a  -1      1/b/a  -1/b/a  -1/a   -1/b/a   1/a    1      1/b     1/b/a  -1/b    -1      ;
    ];


    DL = diag([1, 1, 1, 1, 1, -1, -a, -a/b, 1, 1, 1, -1, b/a, -b/a, b, 1]);
    DR = diag([1, 1, 1, 1, 1, 1/b, -1, -1/b, -1/b, 1, 1/b, -1/b^2, -b^2, b^2, -b^2, 1]);
    Y = DL * Y * DR;

end
