(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    429417,       8961]
NotebookOptionsPosition[    423594,       8795]
NotebookOutlinePosition[    423984,       8812]
CellTagsIndexPosition[    423941,       8809]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"F6Foray", ".", 
    RowBox[{"nb", ":", " ", 
     RowBox[{
     "Some", " ", "More", " ", "Hadamards", " ", "of", " ", "Order", " ", 
      "6"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"A", ".", " ", "J", ".", " ", "Skinner"}], ",", " ", 
    RowBox[{"V", ".", " ", "A", ".", " ", "Newell"}], ",", " ", 
    RowBox[{"R", ".", " ", "Sanchez"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", " ", 
   RowBox[{"askinner", " ", "at", " ", "skidmore", " ", "dot", " ", "edu"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"518", "-", "580", "-", "5127"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Skidmore", " ", "College", " ", "Physics"}], ",", " ", 
    RowBox[{"815", " ", "North", " ", "Broadway"}], ",", " ", 
    RowBox[{"Saratoga", " ", "Springs"}], ",", " ", 
    RowBox[{"NY", " ", "12866"}], ",", " ", "USA"}], " ", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.445766407236092*^9, 3.4457666826557426`*^9}, {
  3.445766713018427*^9, 3.4457667509134274`*^9}, {3.4457667873362617`*^9, 
  3.445766837110818*^9}, {3.445771658330852*^9, 3.445771658798897*^9}, {
  3.445773210336595*^9, 3.445773210751672*^9}, {3.445773246273965*^9, 
  3.445773253855281*^9}, {3.4457851184144983`*^9, 3.445785118745244*^9}, {
  3.44578604421415*^9, 3.445786079352882*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "notebook", " ", "numerically", " ", "integrates", " ", "the",
     " ", "four", " ", "parameter", " ", "family", " ", "described", " ", 
    "in"}], " ", "*)"}], 
  RowBox[{
  "(*", " ", 
   "\"\<Unbiased bases (Hadamards) for six-level systems: Four ways from \
Fourier\>\"", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "published", " ", "in", " ", "the", " ", "Journal", " ", "of", " ", 
     "Mathematical", " ", "Physics"}], ",", " ", "50", ",", " ", "012107", 
    ",", " ", "2009"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"also", " ", "available", " ", "at", " ", 
     RowBox[{"http", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{"arxiv", ".", "org"}], "/", "abs"}], "/", "0810.1761"}]}], " ", 
   "*)"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.4457669145791883`*^9, 3.445766914854377*^9}, {
  3.4457716758732147`*^9, 3.4457716845445337`*^9}, {3.445772285170027*^9, 
  3.445772285391938*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalNu]", "=", "6"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "order", " ", "or", " ", "Hilbert", " ", "space", " ", 
    "dimension"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"here", ",", " ", 
    RowBox[{
    "the", " ", "symbol", " ", "\"\<\[CapitalNu]\>\"", " ", "is", " ", 
     "obtained", " ", "by", " ", "typing", " ", "\"\<esc shift-N esc\>\""}]}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"beware", ":", " ", 
    RowBox[{
    "this", " ", "\"\<\[CapitalNu]\>\"", " ", "is", " ", "different", " ", 
     "from", " ", "the", " ", "\"\<N\>\"", " ", "obtained", " ", "by", " ", 
     "typing", " ", "\"\<shift-N\>\""}]}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.442672524167851*^9, 3.442672532230056*^9}, {
  3.445766861279972*^9, 3.44576687267927*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "complex", " ", "Hadamards", " ", "of", " ", "order", " ", 
    "\[CapitalNu]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "are", " ", "\[CapitalNu]", " ", "x", " ", "\[CapitalNu]", " ", "unitary", 
    " ", "matrices", " ", "of", " ", "equimodular", " ", "elements", " ", 
    FractionBox["1", 
     SqrtBox["\[CapitalNu]"]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "im"]}]]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.442665491774665*^9, 3.442665576539095*^9}, {
  3.4426657240933943`*^9, 3.442665730236216*^9}, {3.442665767133182*^9, 
  3.4426657879611588`*^9}, {3.442672389313633*^9, 3.442672412983777*^9}, {
  3.4426724459753036`*^9, 3.442672452871274*^9}, {3.442680808885354*^9, 
  3.442680827688691*^9}, {3.442832998711844*^9, 3.442833076671377*^9}, {
  3.443879421862028*^9, 3.443879483196458*^9}, {3.443972859687461*^9, 
  3.443972990580165*^9}, {3.44397302146129*^9, 3.4439730946142273`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"here", " ", 
    SubscriptBox["\[Phi]", "im"], " ", "is", " ", "the", " ", "phase", " ", 
    "of", " ", "the", " ", 
    SuperscriptBox["i", "th"], " ", "component", " ", "of", " ", "the", " ", 
    SuperscriptBox["m", "th"], " ", "column"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"m", ",", " ", "n", ",", " ", "o", ",", " ", 
    RowBox[{"p", " ", "shall", " ", "be", " ", "column", " ", "indices"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"i", ",", " ", "j", ",", " ", "k", ",", " ", 
    RowBox[{"l", " ", "shall", " ", "be", " ", "row", " ", "indices"}]}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"throughout", " ", "this", " ", "notebook"}], " ", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.442833082320292*^9, 3.4439729453902893`*^9, {3.445766886380476*^9, 
   3.4457668913107443`*^9}, {3.4457717155706787`*^9, 3.445771719088086*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "can", " ", "represent", " ", "a", " ", "matrix", " ", "of", 
    " ", "equimodular", " ", "elements", " ", 
    FractionBox["1", 
     SqrtBox["\[CapitalNu]"]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Phi]", "im"]}]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "by", " ", "a", " ", "matrix", " ", "of", " ", "its", " ", "phases", " ", 
    SubscriptBox["\[Phi]", "im"]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"phases", "[", "mat_", "]"}], ":=", 
     RowBox[{"Arg", "[", "mat", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"for", " ", "example"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", 
    RowBox[{"phases", "[", 
     RowBox[{
      FractionBox["1", 
       SqrtBox["2"]], 
      RowBox[{"(", GridBox[{
         {"1", 
          RowBox[{"-", "1", " "}]},
         {"\[ImaginaryI]", 
          RowBox[{"-", "\[ImaginaryI]"}]}
        }], ")"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.44266299932719*^9, 3.4426631717222233`*^9}, {
  3.442663215230816*^9, 3.442663257276166*^9}, {3.442663312301025*^9, 
  3.442663312495536*^9}, {3.4426634593874826`*^9, 3.442663503284042*^9}, {
  3.442663567245076*^9, 3.442663657045691*^9}, {3.4426647253789387`*^9, 
  3.442664727618857*^9}, {3.442664757762804*^9, 3.442664790256013*^9}, {
  3.442666511783247*^9, 3.4426666237946997`*^9}, {3.442666881447962*^9, 
  3.442666895715991*^9}, {3.442670828654529*^9, 3.442671092103929*^9}, {
  3.442671149320207*^9, 3.4426711671120367`*^9}, {3.44267122219549*^9, 
  3.442671223727281*^9}, {3.442671605648245*^9, 3.442671645295178*^9}, {
  3.442671678848867*^9, 3.4426717574804*^9}, {3.442671968162263*^9, 
  3.4426719831944647`*^9}, {3.44267263179287*^9, 3.4426726329204206`*^9}, {
  3.442674116434573*^9, 3.442674116841424*^9}, {3.443975716170382*^9, 
  3.443975716805485*^9}, {3.44448573795263*^9, 3.4444857450949707`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "\[Pi]"},
     {
      FractionBox["\[Pi]", "2"], 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.442671758635824*^9, 3.442671985234968*^9, 3.44267285701506*^9, 
   3.442674117413723*^9, 3.4438801175168962`*^9, 3.443880373382307*^9, 
   3.44388042111648*^9, 3.443880489060863*^9, 3.443881851077681*^9, 
   3.4438908563321733`*^9, 3.443892157339574*^9, 3.443972386953437*^9, 
   3.443972596867775*^9, 3.443974885551346*^9, 3.443975087590035*^9, 
   3.443975306245476*^9, 3.443975693468726*^9, 3.443977631578347*^9, 
   3.4439791445812283`*^9, 3.445608871573062*^9, 3.445611515966619*^9, 
   3.445612612670908*^9, 3.445613314857235*^9, 3.445614571244878*^9, 
   3.445680790214427*^9, 3.445681630654603*^9, 3.445687842934074*^9, 
   3.445688945089711*^9, 3.445689877566625*^9, {3.445690076552907*^9, 
   3.4456901000754013`*^9}, 3.445690156058742*^9, 3.445690187207283*^9, 
   3.4456902658906183`*^9, 3.445690477569839*^9, 3.445690937268243*^9, 
   3.445691082963126*^9, 3.445691522242671*^9, 3.4456916002511463`*^9, 
   3.445691715729615*^9, 3.445692912090626*^9, 3.445693122776016*^9, 
   3.445694996946292*^9, 3.445695674806635*^9, 3.445696055581553*^9, 
   3.445698517689056*^9, 3.4457698595672007`*^9, 3.445770046766644*^9, {
   3.44577225884308*^9, 3.445772281184227*^9}, 3.445772788464925*^9, 
   3.44577303530438*^9, 3.445773185671937*^9, 3.44577322153933*^9, 
   3.445773266875568*^9, 3.4457734170950813`*^9, 3.445773605133811*^9, 
   3.445773721528111*^9, 3.4457740888905888`*^9, 3.44577893604706*^9, 
   3.44578222529543*^9, 3.445782872536104*^9, 3.445783901299715*^9, 
   3.445785192406247*^9, 3.445786109304916*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "can", " ", "make", " ", "a", " ", "long", " ", "vector", " ", 
    RowBox[{"(", "list", ")"}], " ", "of", " ", "phases", " ", "from", " ", 
    "a", " ", "matrix", " ", "of", " ", "phases"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"by", " ", "concatenating", " ", "1", "st", " ", "column"}], ",", 
    " ", 
    RowBox[{"2", "nd", " ", "column"}], ",", " ", "..."}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"longvec", "[", "mat_", "]"}], ":=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Transpose", "[", "mat", "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"for", " ", "example"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"longvec", "[", 
    RowBox[{"phases", "[", 
     RowBox[{
      FractionBox["1", 
       SqrtBox["2"]], 
      RowBox[{"(", GridBox[{
         {"1", 
          RowBox[{"-", "1", " "}]},
         {"\[ImaginaryI]", 
          RowBox[{"-", "\[ImaginaryI]"}]}
        }], ")"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442067066883807*^9, 3.442067181218753*^9}, {
   3.442067211860689*^9, 3.4420672250726748`*^9}, {3.442067405675721*^9, 
   3.4420674493173733`*^9}, {3.442659791732339*^9, 3.442659797234755*^9}, {
   3.4426613145178137`*^9, 3.442661352156081*^9}, {3.442672610016553*^9, 
   3.442672618440015*^9}, {3.442672959120801*^9, 3.442672964776141*^9}, 
   3.442673514580913*^9, {3.442674122810643*^9, 3.44267412315366*^9}, {
   3.4439757249592524`*^9, 3.443975725430867*^9}, {3.44448574963135*^9, 
   3.4444857533909187`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["\[Pi]", "2"], ",", "\[Pi]", ",", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.442067225887628*^9, {3.442067426872404*^9, 3.442067450597953*^9}, 
   3.4426728570765333`*^9, 3.442672968407658*^9, 3.442673516277234*^9, 
   3.442674123710265*^9, 3.443880117576429*^9, 3.443880373424679*^9, 
   3.4438804211587276`*^9, 3.443880489102785*^9, 3.443881851121849*^9, 
   3.443890856378119*^9, 3.443892157384736*^9, 3.4439723869994*^9, 
   3.443972596898087*^9, 3.443974885594575*^9, 3.443975087627692*^9, 
   3.4439753062895193`*^9, 3.443975693528142*^9, 3.443977631625526*^9, 
   3.443979144628038*^9, 3.445608871614471*^9, 3.44561151601145*^9, 
   3.445612612719598*^9, 3.445613314902958*^9, 3.445614571290246*^9, 
   3.445680790245776*^9, 3.445681630685927*^9, 3.44568784297668*^9, 
   3.445688945131567*^9, 3.445689877591483*^9, {3.445690076592484*^9, 
   3.445690100118774*^9}, 3.445690156099942*^9, 3.445690187256545*^9, 
   3.4456902659298687`*^9, 3.445690477611928*^9, 3.44569093730989*^9, 
   3.445691083012882*^9, 3.445691522283678*^9, 3.4456916002922163`*^9, 
   3.445691715770303*^9, 3.445692912133596*^9, 3.445693122827544*^9, 
   3.445694996991076*^9, 3.4456956748565903`*^9, 3.445696055644374*^9, 
   3.445698517732863*^9, 3.445769859643409*^9, 3.445770046815153*^9, {
   3.445772258887788*^9, 3.4457722812304573`*^9}, 3.445772788514485*^9, 
   3.4457730353803453`*^9, 3.4457731857164707`*^9, 3.445773221587584*^9, 
   3.445773266923079*^9, 3.445773417156427*^9, 3.445773605177815*^9, 
   3.445773721572454*^9, 3.445774088968606*^9, 3.445778936092029*^9, 
   3.445782225343651*^9, 3.4457828725798483`*^9, 3.445783901343371*^9, 
   3.445785192449285*^9, 3.44578610935006*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"here", "'"}], "s", " ", "the", " ", "Fourier", " ", "matrix", 
    " ", "written", " ", "as", " ", "a", " ", "longvec", " ", 
    RowBox[{"(", 
     RowBox[{"of", " ", "phases"}], ")"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fourier", "=", 
     RowBox[{"longvec", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"2", "\[Pi]", 
         RowBox[{"(", 
          RowBox[{"j", "-", "1"}], ")"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"m", "-", "1"}], ")"}], "/", "\[CapitalNu]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "1", ",", "\[CapitalNu]"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"fourier", "=", 
    RowBox[{"Mod", "[", 
     RowBox[{"fourier", ",", 
      RowBox[{"2", "\[Pi]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.443879866362583*^9, 3.443879873901083*^9}, {
  3.443879914853438*^9, 3.443880031014718*^9}, {3.443880071119198*^9, 
  3.443880100662125*^9}, {3.443880396047223*^9, 3.443880402349223*^9}, {
  3.443891669953938*^9, 3.443891678757967*^9}, {3.4456819762332163`*^9, 
  3.445681985495078*^9}, {3.445782175876122*^9, 3.445782190002595*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   FractionBox["\[Pi]", "3"], ",", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"], ",", "\[Pi]", ",", 
   FractionBox[
    RowBox[{"4", " ", "\[Pi]"}], "3"], ",", 
   FractionBox[
    RowBox[{"5", " ", "\[Pi]"}], "3"], ",", "0", ",", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"], ",", 
   FractionBox[
    RowBox[{"4", " ", "\[Pi]"}], "3"], ",", "0", ",", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"], ",", 
   FractionBox[
    RowBox[{"4", " ", "\[Pi]"}], "3"], ",", "0", ",", "\[Pi]", ",", "0", ",", 
   "\[Pi]", ",", "0", ",", "\[Pi]", ",", "0", ",", 
   FractionBox[
    RowBox[{"4", " ", "\[Pi]"}], "3"], ",", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"], ",", "0", ",", 
   FractionBox[
    RowBox[{"4", " ", "\[Pi]"}], "3"], ",", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"], ",", "0", ",", 
   FractionBox[
    RowBox[{"5", " ", "\[Pi]"}], "3"], ",", 
   FractionBox[
    RowBox[{"4", " ", "\[Pi]"}], "3"], ",", "\[Pi]", ",", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"], ",", 
   FractionBox["\[Pi]", "3"]}], "}"}]], "Output",
 CellChangeTimes->{{3.4438800924653788`*^9, 3.4438801185878887`*^9}, 
   3.4438801528809843`*^9, {3.4438803735867157`*^9, 3.443880421293511*^9}, 
   3.443880489254759*^9, 3.44388185124677*^9, 3.4438908565728407`*^9, 
   3.4438916803568563`*^9, 3.4438921575092497`*^9, 3.443972596964517*^9, 
   3.4439748856458263`*^9, 3.443975087678484*^9, 3.443975306339717*^9, 
   3.443975693579914*^9, 3.443977631675755*^9, 3.443979144679132*^9, 
   3.44560887166389*^9, 3.4456115160617456`*^9, 3.445612612784079*^9, 
   3.445613314952035*^9, 3.4456145713394613`*^9, 3.445680790313504*^9, 
   3.445681630751677*^9, 3.4456819869857273`*^9, 3.445687843028099*^9, 
   3.445688945182213*^9, 3.4456898776276827`*^9, {3.445690076643362*^9, 
   3.4456901001682577`*^9}, 3.445690156150124*^9, 3.445690187306674*^9, 
   3.445690265980443*^9, 3.445690477661757*^9, 3.4456909373610353`*^9, 
   3.445691083062928*^9, 3.445691522320881*^9, 3.445691600342886*^9, 
   3.4456917158210173`*^9, 3.445692912179226*^9, 3.445693122875022*^9, 
   3.4456949970411167`*^9, 3.445695674903129*^9, 3.4456960556934*^9, 
   3.445698517783888*^9, 3.445769859710617*^9, 3.445770046895763*^9, {
   3.4457722589383173`*^9, 3.445772281293725*^9}, 3.445772788593566*^9, 
   3.445773035463773*^9, 3.445773185768256*^9, 3.4457732216860743`*^9, 
   3.445773267003093*^9, 3.445773417223102*^9, 3.44577360522831*^9, 
   3.445773721623431*^9, 3.445774089052622*^9, 3.445778936126899*^9, 
   3.445782225423457*^9, 3.445782872631106*^9, 3.445783901421815*^9, 
   3.445785192501178*^9, 3.445786109399495*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "can", " ", "turn", " ", "a", " ", "longvec", " ", "back", " ", 
    "into", " ", "a", " ", "candidate", " ", "Hadamard", " ", "matrix"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"candmat", "[", "lv_", "]"}], ":=", 
    RowBox[{
     FractionBox["1", 
      SqrtBox["\[CapitalNu]"]], 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"lv", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"\[CapitalNu]", 
             RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}]}], "+", "i"}], "]"}], "]"}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "1", ",", "\[CapitalNu]"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"for", " ", "example"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", 
    RowBox[{
     SqrtBox["6"], 
     RowBox[{"candmat", "[", "fourier", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.443891723478178*^9, 3.443891919193347*^9}, {
   3.4439723103596373`*^9, 3.443972371066053*^9}, {3.443972582169983*^9, 
   3.44397258400605*^9}, {3.443972679070587*^9, 3.443972679835532*^9}, {
   3.44397575322334*^9, 3.4439757617671967`*^9}, {3.44448576547992*^9, 
   3.444485769070796*^9}, 3.445766955121558*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1", "1", "1", "1"},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      RowBox[{"-", "1"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}]},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      RowBox[{"-", "1"}], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "3"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.443972373606724*^9, 3.443972387527055*^9}, 
   3.443972597033095*^9, 3.4439726804385757`*^9, 3.443974885713229*^9, 
   3.4439750877295647`*^9, 3.443975306390835*^9, 3.443975693646306*^9, 
   3.443977631742898*^9, 3.4439791447465763`*^9, 3.445608871730186*^9, 
   3.445611516127921*^9, 3.445612612852469*^9, 3.44561331501969*^9, 
   3.445614571406207*^9, 3.445680790378285*^9, 3.445681630820487*^9, 
   3.445687843078452*^9, 3.4456889452478237`*^9, 3.445689877675231*^9, {
   3.445690076693644*^9, 3.445690100218919*^9}, 3.445690156201397*^9, 
   3.4456901873576603`*^9, 3.445690266031355*^9, 3.445690477711808*^9, 
   3.445690937410993*^9, 3.445691083113793*^9, 3.445691522368828*^9, 
   3.445691600392033*^9, 3.445691715871017*^9, 3.445692912229151*^9, 
   3.445693122940859*^9, 3.4456949970920877`*^9, 3.445695674953023*^9, 
   3.44569605576093*^9, 3.4456985178344316`*^9, 3.445769859777178*^9, 
   3.4457700469628153`*^9, {3.44577225898845*^9, 3.4457722813611917`*^9}, 
   3.4457727886612787`*^9, 3.445773035547615*^9, 3.4457731858184853`*^9, 
   3.445773221752714*^9, 3.445773267070849*^9, 3.445773417290378*^9, 
   3.4457736052789173`*^9, 3.4457737216740017`*^9, 3.445774089136332*^9, 
   3.445778936176016*^9, 3.4457822255098257`*^9, 3.4457828726814013`*^9, 
   3.4457839014919786`*^9, 3.44578519253736*^9, 3.445786109450181*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "we", " ", "begin", " ", "with", " ", "\[CapitalNu]", " ", "x", 
    " ", "\[CapitalNu]", " ", "matrices", " ", "of", " ", "equimodular", " ", 
    "elements", " ", 
    FractionBox["1", 
     SqrtBox["\[CapitalNu]"]], 
    SuperscriptBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", "im"]}]], "  "]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "whose", " ", "columns", " ", "are", " ", "automatically", " ", "unbiased",
     " ", "with", " ", "respect", " ", "to", " ", "the", " ", "standard", " ",
     "basis"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"and", " ", "look", " ", "for", " ", "unitarity"}], ",", " ", 
    RowBox[{
     RowBox[{"i", ".", "e", ".", " ", "for"}], " ", "the", " ", "columns", 
     " ", "to", " ", "form", " ", "an", " ", "orthonormal", " ", "basis"}]}], 
   " ", "*)"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.44266537661382*^9, 3.442665448987348*^9}, 
   3.4426655869084997`*^9, {3.4426656254438753`*^9, 3.4426656974617853`*^9}, {
   3.442665816884132*^9, 3.442665873251708*^9}, {3.442665911549304*^9, 
   3.4426659758756638`*^9}, {3.442666051037303*^9, 3.442666052204523*^9}, {
   3.442666167086274*^9, 3.4426662644287167`*^9}, {3.442666330621138*^9, 
   3.442666367836348*^9}, {3.442671355641913*^9, 3.442671356183652*^9}, {
   3.443890877352715*^9, 3.443890886183806*^9}, {3.4439727677204103`*^9, 
   3.443972769045794*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "define", " ", "the", " ", "nonunitarity", " ", "\"\<f\>\"", 
    " ", "as", " ", "proportional", " ", "to", " ", "the", " ", "sum"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "over", " ", "probabilities", " ", "between", " ", "nontrivial", " ", 
    "pairings", " ", "of", " ", "column", " ", "vectors"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"f", " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[CapitalNu]", "2"], "/", "2"}], ")"}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"<", 
         SubscriptBox["e", "m"]}], "|", 
        RowBox[{
         SubscriptBox["e", "n"], ">", "<", 
         SubscriptBox["e", "n"]}], "|", 
        RowBox[{
         SubscriptBox["e", "m"], ">"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"m", "+", "1"}], ",", "\[CapitalNu]"}], "}"}]}], "]"}]}]}], 
   " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4426713664604073`*^9, 3.442671375485097*^9}, {
  3.442672040727336*^9, 3.44267208258962*^9}, {3.442672639189827*^9, 
  3.442672656150627*^9}, {3.442672691919681*^9, 3.442672800134809*^9}, {
  3.4426744071693373`*^9, 3.442674414575253*^9}, {3.442674883506607*^9, 
  3.4426748902871304`*^9}, {3.445766973648525*^9, 3.445766974501396*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "there", " ", "is", " ", "a", " ", "constant", " ", "part", " ", "of", " ",
     "the", " ", "nonunitarity"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"f0", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{"(*", " ", 
     RowBox[{
     "over", " ", "mth", " ", "and", " ", "nth", " ", "column", " ", 
      "vectors"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"over", " ", "their", " ", "jth"}], " ", "=", " ", 
        RowBox[{"ith", " ", "components"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "i", ",", "i"}], "}"}]}], "]"}], " ", 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"m", "+", "1"}], ",", "\[CapitalNu]"}], "}"}]}], "]"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.4420654459173203`*^9, 3.442065482160865*^9}, {
  3.442065553493536*^9, 3.442065682411023*^9}, {3.442066676015789*^9, 
  3.442066702698715*^9}, {3.4420673214757433`*^9, 3.442067328252836*^9}, {
  3.442067400979636*^9, 3.442067402028488*^9}, {3.442067482972681*^9, 
  3.442067632197359*^9}, {3.442067763429551*^9, 3.4420678128372993`*^9}, {
  3.442067853557448*^9, 3.442067867669401*^9}, {3.442067910591772*^9, 
  3.442067993685688*^9}, {3.442068044013968*^9, 3.4420680477574883`*^9}, {
  3.4420680780216208`*^9, 3.442068099645403*^9}, {3.442068308589675*^9, 
  3.442068324389433*^9}, {3.4420683625920477`*^9, 3.4420683633328667`*^9}, {
  3.442672096346287*^9, 3.442672099312326*^9}, {3.442672823760606*^9, 
  3.4426728423870363`*^9}, {3.442672903291698*^9, 3.442672917720127*^9}, {
  3.442674618061123*^9, 3.442674653616365*^9}}],

Cell[BoxData["45"], "Output",
 CellChangeTimes->{
  3.442067587171007*^9, 3.442067870393195*^9, {3.4420683593663607`*^9, 
   3.442068364013832*^9}, 3.442672857175501*^9, 3.44388011767001*^9, 
   3.443880373487158*^9, 3.443880421221119*^9, 3.4438804891497393`*^9, 
   3.443881851184142*^9, 3.4438908564713373`*^9, 3.443892157444521*^9, 
   3.4439748858112164`*^9, 3.443975087805895*^9, 3.4439753064684973`*^9, 
   3.443975693723813*^9, 3.443977631848261*^9, 3.443979144852469*^9, 
   3.445608871837029*^9, 3.4456115162268953`*^9, 3.445612612956935*^9, 
   3.4456133151262712`*^9, 3.44561457151243*^9, 3.4456807904782267`*^9, 
   3.445681630918314*^9, 3.445687843154665*^9, 3.445688945369278*^9, 
   3.445689877741666*^9, {3.445690076758148*^9, 3.4456901002977943`*^9}, 
   3.4456901562791758`*^9, 3.4456901874353657`*^9, 3.445690266109312*^9, 
   3.445690477777628*^9, 3.4456909374758244`*^9, 3.445691083188694*^9, 
   3.445691522432966*^9, 3.445691600469317*^9, 3.445691715948435*^9, 
   3.445692912295484*^9, 3.445693123045165*^9, 3.4456949971682043`*^9, 
   3.445695675028322*^9, 3.445696055853569*^9, 3.4456985179096212`*^9, 
   3.445769859853333*^9, 3.4457700470806437`*^9, {3.445772259055006*^9, 
   3.445772281477476*^9}, 3.4457727887780333`*^9, 3.445773035633562*^9, 
   3.44577318589282*^9, 3.4457732218587914`*^9, 3.445773267176293*^9, 
   3.4457734173838453`*^9, 3.445773605355137*^9, 3.4457737217502947`*^9, 
   3.4457740892453213`*^9, 3.445778936241012*^9, 3.44578222561616*^9, 
   3.4457828727653*^9, 3.4457839016065273`*^9, 3.445785192611597*^9, 
   3.4457861095266333`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "a", " ", "total", " ", "nonunitary", " ", "of", " ", "a", " ",
     "matrix", " ", "of", " ", "equimodular", " ", "elements"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "here", " ", "\"\<lv\>\"", " ", "is", " ", "a", " ", "long", " ", "vector",
     " ", "of", " ", "phases"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"f", "[", "lv_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "f", ",", "m", ",", "n", ",", "i", ",", "j", ",", "im", ",", "jm", ",", 
       "in", ",", "jn", ",", "arg", ",", "co"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "=", "f0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{"(*", " ", 
        RowBox[{
        "loop", " ", "over", " ", "mth", " ", "and", " ", "nth", " ", 
         "column", " ", "vectors"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{"(*", " ", 
           RowBox[{
           "loop", " ", "over", " ", "their", " ", "ith", " ", "and", " ", 
            "jth", " ", "components"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "solve", " ", "for", " ", "longvec", " ", "indices", " ", "from", 
            " ", "row", " ", "and", " ", "column", " ", "indices"}], " ", 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"im", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}]}], "+", "i"}]}], ";", 
            RowBox[{"jm", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}]}], "+", "j"}]}], ";", 
            RowBox[{"in", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}], "+", "i"}]}], ";", 
            RowBox[{"jn", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}], "+", "j"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"find", " ", "the", " ", "overall", " ", "argument"}], 
              ",", " ", 
              RowBox[{"its", " ", "cosine"}], ",", " ", 
              RowBox[{"and", " ", "update", " ", "f"}]}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"arg", "=", 
             RowBox[{
              RowBox[{"lv", "[", 
               RowBox[{"[", "in", "]"}], "]"}], "-", 
              RowBox[{"lv", "[", 
               RowBox[{"[", "im", "]"}], "]"}], "+", 
              RowBox[{"lv", "[", 
               RowBox[{"[", "jm", "]"}], "]"}], "-", 
              RowBox[{"lv", "[", 
               RowBox[{"[", "jn", "]"}], "]"}]}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"co", "=", 
             RowBox[{"Cos", "[", "arg", "]"}]}], ";", 
            RowBox[{"f", "=", 
             RowBox[{"f", "+", "co"}]}], ";"}], "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"i", "+", "1"}], ",", "\[CapitalNu]"}], "}"}]}], "]"}], 
         ";"}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"m", "+", "1"}], ",", "\[CapitalNu]"}], "}"}]}], "]"}], ";",
       "\[IndentingNewLine]", "f"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{"returns", " ", "the", " ", "total", " ", "nonunitarity"}], " ", 
     "*)"}], "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442065668710927*^9, 3.442065698242983*^9}, {
   3.442065736737393*^9, 3.442065737537373*^9}, {3.442066545549385*^9, 
   3.4420666615151567`*^9}, {3.442066717965166*^9, 3.4420668374281883`*^9}, {
   3.442066873557021*^9, 3.442066874433915*^9}, {3.442067288961893*^9, 
   3.4420673026365*^9}, {3.442067347483324*^9, 3.442067383899748*^9}, {
   3.4420683748794727`*^9, 3.442068641809148*^9}, {3.442672976425138*^9, 
   3.44267301863568*^9}, {3.442674685766024*^9, 3.442674709365838*^9}, {
   3.4426747635337343`*^9, 3.442674833640379*^9}, {3.4426749296139402`*^9, 
   3.4426749564708757`*^9}, {3.442680891703559*^9, 3.4426808936762667`*^9}, {
   3.442833192797269*^9, 3.442833197253227*^9}, {3.4438795701487837`*^9, 
   3.443879613114478*^9}, {3.443879682275633*^9, 3.443879774035947*^9}, 
   3.443880146174345*^9, {3.443880443118164*^9, 3.443880471843998*^9}, {
   3.443880517871729*^9, 3.443880528395644*^9}, 3.443882140230073*^9, {
   3.443882241708228*^9, 3.4438822928604727`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "Fourier", " ", "matrix", " ", "is", " ", "unitary"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"f", "[", "fourier", "]"}]}]], "Input",
 CellChangeTimes->{{3.443880284397278*^9, 3.4438803495777407`*^9}, {
  3.44388040616539*^9, 3.443880407106908*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.443880286307185*^9, {3.443880352749134*^9, 3.443880424941437*^9}, {
   3.443880489303173*^9, 3.4438804951207523`*^9}, 3.443880531726318*^9, 
   3.443881851288865*^9, 3.4438908566098146`*^9, 3.443892157567596*^9, 
   3.443974885877408*^9, 3.443975087854415*^9, 3.443975306525581*^9, 
   3.443975693788739*^9, 3.443977631917863*^9, 3.44397914492132*^9, 
   3.445608871905937*^9, 3.445611516286647*^9, 3.445612613028414*^9, 
   3.445613315194481*^9, 3.445614571564801*^9, 3.445680790537656*^9, 
   3.445681630961492*^9, 3.445687843221439*^9, 3.44568894544034*^9, 
   3.445689877785736*^9, {3.445690076818653*^9, 3.445690100352509*^9}, 
   3.4456901563442574`*^9, 3.445690187504562*^9, 3.445690266172988*^9, 
   3.4456904778213997`*^9, 3.445690937520746*^9, 3.445691083256653*^9, 
   3.445691522478388*^9, 3.4456916005358152`*^9, 3.445691716016564*^9, 
   3.445692912338624*^9, 3.445693123099731*^9, 3.445694997235215*^9, 
   3.445695675095654*^9, 3.445696055936653*^9, 3.445698517976071*^9, 
   3.445769859919099*^9, 3.445770047145005*^9, {3.445772259114222*^9, 
   3.445772281543446*^9}, 3.4457727888398323`*^9, 3.445773035697237*^9, 
   3.4457731859595003`*^9, 3.445773221930472*^9, 3.4457732672317047`*^9, 
   3.445773417470278*^9, 3.445773605421905*^9, 3.445773721816071*^9, 
   3.445774089346427*^9, 3.44577893628557*^9, 3.445782225687846*^9, 
   3.445782872828438*^9, 3.445783901670602*^9, 3.4457851926679287`*^9, 
   3.445786109591997*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "will", " ", "need", " ", "to", " ", "know", " ", "how", " ", 
    "the", " ", "nonunitarity", " ", "varies", " ", "as", " ", "we", " ", 
    "vary", " ", "the", " ", "phases"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "we", " ", "need", " ", "the", " ", "gradient", " ", "g", " ", 
    "and", " ", "the", " ", "Hessian", " ", "h"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g36", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        SuperscriptBox["\[CapitalNu]", "2"], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h36", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        SuperscriptBox["\[CapitalNu]", "2"], "}"}], ",", 
       RowBox[{"{", 
        SuperscriptBox["\[CapitalNu]", "2"], "}"}]}], "]"}]}], ";"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.4438810486793747`*^9, 3.44388121055691*^9}, {
  3.443881951934877*^9, 3.443881988516914*^9}, {3.44397318335047*^9, 
  3.4439731967659597`*^9}, {3.445611462545389*^9, 3.445611464952326*^9}, {
  3.445611693001357*^9, 3.44561178506645*^9}, {3.4456118444835253`*^9, 
  3.445611910182075*^9}, {3.445612065227334*^9, 3.4456120680641747`*^9}, {
  3.445612421056945*^9, 3.445612456478072*^9}, {3.445612529008225*^9, 
  3.445612592337096*^9}, {3.44561264159409*^9, 3.445612647690153*^9}, {
  3.445613626777718*^9, 3.4456136835116873`*^9}, {3.445613717080976*^9, 
  3.4456137667776833`*^9}, {3.4456141829187717`*^9, 3.445614195858739*^9}, {
  3.4456813716827993`*^9, 3.445681372870863*^9}, {3.445681403584445*^9, 
  3.445681404606879*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"fgh", "[", "lv", "]"}], " ", "finds", " ", "the", " ", 
    "gradient", " ", "and", " ", "Hessian", " ", "while", " ", "figuring", 
    " ", "the", " ", "nonunitarity"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"it", " ", "takes", " ", "longer", " ", "than", " ", 
    RowBox[{"f", "[", "lv", "]"}], " ", "but", " ", "returns", " ", "more", 
    " ", "useful", " ", "information"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"again", ",", " ", 
    RowBox[{
    "\"\<lv\>\"", " ", "is", " ", "a", " ", "longvec", " ", "of", " ", 
     "phases"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fgh", "[", "lv_", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "f", ",", "m", ",", "n", ",", "i", ",", "j", ",", "im", ",", "jm", ",", 
       "in", ",", "jn", ",", "arg", ",", "co", ",", "si", ",", "kos", ",", 
       "kosigns", ",", "kocase", ",", "lps", ",", "lpsigns", ",", "lpcase"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "=", "f0"}], ";", 
      RowBox[{"g36", "=", 
       RowBox[{"0", "g36"}]}], ";", 
      RowBox[{"h36", "=", 
       RowBox[{"0", "h36"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"initialize", " ", "f"}], ",", " ", "g", ",", " ", "h"}], " ",
        "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{"(*", " ", 
        RowBox[{
        "loop", " ", "over", " ", "mth", " ", "and", " ", "nth", " ", 
         "column", " ", "vectors"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Do", "[", 
          RowBox[{"(*", " ", 
           RowBox[{
           "loop", " ", "over", " ", "their", " ", "ith", " ", "and", " ", 
            "jth", " ", "components"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "solve", " ", "for", " ", "longvec", " ", "indices", " ", "from", 
            " ", "row", " ", "and", " ", "column", " ", "indices"}], " ", 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"im", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}]}], "+", "i"}]}], ";", 
            RowBox[{"jm", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}]}], "+", "j"}]}], ";", 
            RowBox[{"in", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}], "+", "i"}]}], ";", 
            RowBox[{"jn", "=", 
             RowBox[{
              RowBox[{"\[CapitalNu]", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}], "+", "j"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"find", " ", "the", " ", "overall", " ", "argument"}], 
              ",", " ", 
              RowBox[{"its", " ", "cosine"}], ",", " ", 
              RowBox[{"its", " ", "sine"}], ",", " ", 
              RowBox[{"and", " ", "update", " ", "f"}]}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"arg", "=", 
             RowBox[{
              RowBox[{"lv", "[", 
               RowBox[{"[", "in", "]"}], "]"}], "-", 
              RowBox[{"lv", "[", 
               RowBox[{"[", "im", "]"}], "]"}], "+", 
              RowBox[{"lv", "[", 
               RowBox[{"[", "jm", "]"}], "]"}], "-", 
              RowBox[{"lv", "[", 
               RowBox[{"[", "jn", "]"}], "]"}]}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"co", "=", 
             RowBox[{"Cos", "[", "arg", "]"}]}], ";", 
            RowBox[{"si", "=", 
             RowBox[{"Sin", "[", "arg", "]"}]}], ";", 
            RowBox[{"f", "=", 
             RowBox[{"f", "+", "co"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "now", " ", "for", " ", "the", " ", "gradient", " ", "and", " ", 
              "Hessian", " ", "and", " ", "all", " ", "their", " ", 
              "Kronecker", " ", "deltas"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{"the", " ", "-", 
              RowBox[{
               RowBox[{"Sin", "[", "arg", "]"}], " ", "only", " ", 
               "contributes", " ", "to", " ", "the", " ", "gradient", " ", 
               RowBox[{
                RowBox[{"\[PartialD]", "f"}], "/", 
                RowBox[{"\[PartialD]", 
                 SubscriptBox["\[Phi]", "ko"]}]}]}]}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "i"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"k", " ", "&"}], " ", "m"}], "=", 
               RowBox[{"o", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"with", " ", "a", " ", "factor"}], " ", "-", "1"}], 
                 ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "j"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"k", " ", "&"}], " ", "m"}], "=", 
               RowBox[{"o", " ", 
                RowBox[{"(", 
                 RowBox[{"with", " ", "a", " ", "factor", " ", "1"}], 
                 ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "i"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"k", " ", "&"}], " ", "n"}], "=", 
               RowBox[{"o", " ", 
                RowBox[{"(", 
                 RowBox[{"with", " ", "a", " ", "factor", " ", "1"}], 
                 ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "j"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"k", " ", "&"}], " ", "n"}], "=", 
               RowBox[{"o", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"with", " ", "a", " ", "factor"}], " ", "-", "1"}], 
                 ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "so", " ", "here", " ", "is", " ", "a", " ", "list", " ", "of", 
              " ", "the", " ", "four", " ", "scenarios"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"kos", "=", 
             RowBox[{"{", 
              RowBox[{"im", ",", "jm", ",", "in", ",", "jn"}], "}"}]}], ";", 
            RowBox[{"kosigns", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{"the", " ", "-", 
              RowBox[{
               RowBox[{"Cos", "[", "arg", "]"}], " ", "only", " ", 
               "contributes", " ", "to", " ", "the", " ", "Hessian", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["\[PartialD]", "2"], "f"}], "/", 
                RowBox[{"\[PartialD]", 
                 SubscriptBox["\[Phi]", "ko"]}]}], 
               RowBox[{"\[PartialD]", 
                SubscriptBox["\[Phi]", "lp"]}]}]}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "per", " ", "the", " ", "aforementioned", " ", "scenarios", " ", 
              "and"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "furthermore", " ", "i"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"l", " ", "&"}], " ", "m"}], "=", 
               RowBox[{"p", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                  "with", " ", "an", " ", "additional", " ", "factor"}], " ", 
                  "-", "1"}], ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]",
             
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "furthermore", " ", "j"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"l", " ", "&"}], " ", "m"}], "=", 
               RowBox[{"p", " ", 
                RowBox[{"(", 
                 RowBox[{
                 "with", " ", "an", " ", "additional", " ", "factor", " ", 
                  "1"}], ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "furthermore", " ", "i"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"l", " ", "&"}], " ", "n"}], "=", 
               RowBox[{"p", " ", 
                RowBox[{"(", 
                 RowBox[{
                 "with", " ", "an", " ", "additional", " ", "factor", " ", 
                  "1"}], ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"when", " ", "furthermore", " ", "j"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"l", " ", "&"}], " ", "n"}], "=", 
               RowBox[{"p", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                  "with", " ", "an", " ", "additional", " ", "factor"}], " ", 
                  "-", "1"}], ")"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]",
             
            RowBox[{"(*", " ", 
             RowBox[{
             "so", " ", "here", " ", "is", " ", "a", " ", "list", " ", "of", 
              " ", "the", " ", "four", " ", "additional", " ", "scenarios"}], 
             " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"lps", "=", 
             RowBox[{"{", 
              RowBox[{"im", ",", "jm", ",", "in", ",", "jn"}], "}"}]}], ";", 
            RowBox[{"lpsigns", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"and", " ", "now", " ", 
               RowBox[{"we", "'"}], "ll", " ", "loop", " ", "over", " ", 
               "the", " ", "non"}], "-", 
              RowBox[{"zero", " ", "contributions"}]}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "and", " ", "add", " ", "them", " ", "into", " ", "the", " ", 
              "right", " ", "matrix", " ", "elements", " ", "of", " ", "g", 
              " ", "and", " ", "h"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"Do", "[", " ", 
             RowBox[{"(*", " ", 
              RowBox[{
              "loop", " ", "over", " ", "the", " ", "four", " ", "gradient", 
               " ", "scenarios", " ", "mentioned", " ", "above"}], " ", 
              "*)"}], "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"g36", "[", 
                 RowBox[{"[", 
                  RowBox[{"kos", "[", 
                   RowBox[{"[", "kocase", "]"}], "]"}], "]"}], "]"}], "=", 
                RowBox[{
                 RowBox[{"g36", "[", 
                  RowBox[{"[", 
                   RowBox[{"kos", "[", 
                    RowBox[{"[", "kocase", "]"}], "]"}], "]"}], "]"}], "-", 
                 RowBox[{
                  RowBox[{"kosigns", "[", 
                   RowBox[{"[", "kocase", "]"}], "]"}], "si"}]}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"Do", "[", 
                RowBox[{"(*", " ", 
                 RowBox[{
                 "loop", " ", "over", " ", "the", " ", "additional", " ", 
                  "four", " ", "Hessian", " ", "scenarios", " ", "mentioned", 
                  " ", "above"}], " ", "*)"}], "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"h36", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"kos", "[", 
                    RowBox[{"[", "kocase", "]"}], "]"}], ",", 
                    RowBox[{"lps", "[", 
                    RowBox[{"[", "lpcase", "]"}], "]"}]}], "]"}], "]"}], "=", 
                   
                   RowBox[{
                    RowBox[{"h36", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"kos", "[", 
                    RowBox[{"[", "kocase", "]"}], "]"}], ",", 
                    RowBox[{"lps", "[", 
                    RowBox[{"[", "lpcase", "]"}], "]"}]}], "]"}], "]"}], "-", 
                    
                    RowBox[{
                    RowBox[{"lpsigns", "[", 
                    RowBox[{"[", "lpcase", "]"}], "]"}], 
                    RowBox[{"kosigns", "[", 
                    RowBox[{"[", "kocase", "]"}], "]"}], "co"}]}]}], ";"}], 
                 "\[IndentingNewLine]", ",", 
                 RowBox[{"{", 
                  RowBox[{"lpcase", ",", "1", ",", "4"}], "}"}]}], "]"}], 
               ";"}], "\[IndentingNewLine]", ",", 
              RowBox[{"{", 
               RowBox[{"kocase", ",", "1", ",", "4"}], "}"}]}], "]"}], ";"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"i", "+", "1"}], ",", "\[CapitalNu]"}], "}"}]}], "]"}], 
         ";"}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "1", ",", "\[CapitalNu]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"m", "+", "1"}], ",", "\[CapitalNu]"}], "}"}]}], "]"}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"f", ",", "g36", ",", "h36"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4438807933170347`*^9, 3.443880842476117*^9}, {
   3.4438808758800907`*^9, 3.4438808856810417`*^9}, 3.4438812344741488`*^9, {
   3.443881282178711*^9, 3.443881364556329*^9}, {3.443881446965377*^9, 
   3.443881729226405*^9}, {3.443882011809025*^9, 3.443882078066189*^9}, 
   3.443882144722392*^9, 3.443882262461635*^9, {3.4438823034144*^9, 
   3.443882370563862*^9}, {3.443888909481742*^9, 3.443889005190198*^9}, {
   3.443889044199851*^9, 3.4438892078308372`*^9}, 3.443889246655237*^9, {
   3.4438894105835543`*^9, 3.443889613293285*^9}, {3.4438898013422747`*^9, 
   3.443889815007448*^9}, {3.443889849304405*^9, 3.4438898590313587`*^9}, {
   3.443889902664688*^9, 3.4438901108334217`*^9}, {3.4438901829504967`*^9, 
   3.443890242050062*^9}, {3.4438904539956207`*^9, 3.4438905376719933`*^9}, {
   3.443890567835264*^9, 3.4438905783145723`*^9}, {3.443890609834898*^9, 
   3.443890825281105*^9}, {3.4438910126416407`*^9, 3.4438910412137947`*^9}, {
   3.443891081717663*^9, 3.443891112888549*^9}, {3.443891148685956*^9, 
   3.443891286071467*^9}, {3.443891364245401*^9, 3.443891386279113*^9}, {
   3.443891494329142*^9, 3.443891496582007*^9}, {3.4438915585044823`*^9, 
   3.443891563021937*^9}, {3.443891981245016*^9, 3.443891983018196*^9}, {
   3.443973208488443*^9, 3.443973257498165*^9}, {3.443974947736039*^9, 
   3.443974992868019*^9}, {3.443975161693673*^9, 3.4439751977808027`*^9}, {
   3.443975247224205*^9, 3.443975259891206*^9}, {3.443975408833852*^9, 
   3.4439754193238153`*^9}, {3.445611469728067*^9, 3.445611489400811*^9}, 
   3.4456815939856987`*^9, {3.445690338401626*^9, 3.4456903435041*^9}, {
   3.4457670334531107`*^9, 3.445767047727042*^9}, {3.4457670992596703`*^9, 
   3.44576717134599*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"now", " ", 
    RowBox[{"let", "'"}], "s", " ", "try", " ", "it", " ", "out", " ", "on", 
    " ", "the", " ", "Fourier", " ", 
    RowBox[{"matrix", "'"}], "s", " ", "longvec", " ", "of", " ", "phases"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "Fourier", " ", "matrix", " ", "is", " ", "unitary"}],
     ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"i", ".", "e", ".", " ", "its"}], " ", "nonunitarity", " ", 
      "f"}], "=", "0"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "but", " ", "the", " ", "nonunitary", " ", "varies", " ", "with", " ", 
    "adjustments", " ", "to", " ", "the", " ", "phases"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"not", " ", "to", " ", "first", " ", "order"}], ",", " ", 
    RowBox[{
    "because", " ", "fourier", " ", "minimizes", " ", "the", " ", 
     "nonunitarity"}], ",", " ", 
    RowBox[{
     RowBox[{"so", " ", "g36"}], "=", "0"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "but", " ", "definitely", " ", "to", " ", "second", " ", "order"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"so", " ", "h36"}], "\[NotEqual]", "0"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nonu", ",", "g36", ",", "h36"}], "}"}], "=", 
     RowBox[{"fgh", "[", "fourier", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "nonu", "\[IndentingNewLine]", "g36", "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", "h36", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Eigenvalues", "[", "h36", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.443974796489303*^9, 3.443974869951214*^9}, {
   3.443975215799053*^9, 3.4439752372214947`*^9}, {3.443975283831911*^9, 
   3.443975286490838*^9}, {3.443975428177157*^9, 3.443975430257079*^9}, {
   3.443975464415812*^9, 3.443975565861565*^9}, 3.443975807584023*^9, {
   3.443977598774372*^9, 3.443977606302237*^9}, {3.443977708024529*^9, 
   3.443977722070174*^9}, {3.443979051177668*^9, 3.443979063863118*^9}, {
   3.445608839570574*^9, 3.445608848432289*^9}, {3.445611548139316*^9, 
   3.445611550008128*^9}, {3.445681605616313*^9, 3.445681616382278*^9}, {
   3.44568170477671*^9, 3.445681711838415*^9}, {3.445690362335884*^9, 
   3.4456904271605873`*^9}, {3.445767197602213*^9, 3.445767287928938*^9}, {
   3.445773402293089*^9, 3.445773402703477*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.443974870969442*^9, 3.443974886723419*^9}, 
   3.443974960788389*^9, 3.443974996342749*^9, 3.443975088450672*^9, {
   3.4439751849542923`*^9, 3.443975206545869*^9}, {3.443975238356235*^9, 
   3.4439753066345882`*^9}, {3.443975423403428*^9, 3.443975431097713*^9}, 
   3.443975693892397*^9, 3.443977608114849*^9, 3.443977641971628*^9, 
   3.4439777228249903`*^9, 3.443979145043721*^9, 3.445608872007687*^9, 
   3.445611516388373*^9, 3.445613315297246*^9, 3.445680790733431*^9, 
   3.445681382880224*^9, 3.445681631065613*^9, 3.4456817136697273`*^9, 
   3.445687843341568*^9, 3.445688945562008*^9, 3.445689877905493*^9, {
   3.44569007693983*^9, 3.445690100465187*^9}, 3.445690156464563*^9, 
   3.445690187620311*^9, 3.445690266317725*^9, 3.445690428008502*^9, 
   3.445690477942089*^9, 3.445690937624625*^9, 3.445691083377411*^9, 
   3.44569152258197*^9, 3.4456916006559258`*^9, 3.445691716135345*^9, 
   3.445692912443543*^9, 3.445693123217423*^9, 3.445694997353664*^9, 
   3.4456956752152863`*^9, 3.445696056086925*^9, 3.445698518096301*^9, 
   3.445769860041099*^9, 3.44577004727223*^9, {3.445772259219943*^9, 
   3.44577228165744*^9}, 3.445772788960799*^9, 3.445773035829879*^9, 
   3.445773186064891*^9, 3.445773222052087*^9, 3.445773267352982*^9, 
   3.4457734175996513`*^9, 3.445773605543396*^9, 3.445773721937707*^9, 
   3.445774089500128*^9, 3.4457789363882504`*^9, 3.445782225805499*^9, 
   3.445782872945681*^9, 3.4457839018337603`*^9, 3.445785192781358*^9, 
   3.445786109712973*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.443974870969442*^9, 3.443974886723419*^9}, 
   3.443974960788389*^9, 3.443974996342749*^9, 3.443975088450672*^9, {
   3.4439751849542923`*^9, 3.443975206545869*^9}, {3.443975238356235*^9, 
   3.4439753066345882`*^9}, {3.443975423403428*^9, 3.443975431097713*^9}, 
   3.443975693892397*^9, 3.443977608114849*^9, 3.443977641971628*^9, 
   3.4439777228249903`*^9, 3.443979145043721*^9, 3.445608872007687*^9, 
   3.445611516388373*^9, 3.445613315297246*^9, 3.445680790733431*^9, 
   3.445681382880224*^9, 3.445681631065613*^9, 3.4456817136697273`*^9, 
   3.445687843341568*^9, 3.445688945562008*^9, 3.445689877905493*^9, {
   3.44569007693983*^9, 3.445690100465187*^9}, 3.445690156464563*^9, 
   3.445690187620311*^9, 3.445690266317725*^9, 3.445690428008502*^9, 
   3.445690477942089*^9, 3.445690937624625*^9, 3.445691083377411*^9, 
   3.44569152258197*^9, 3.4456916006559258`*^9, 3.445691716135345*^9, 
   3.445692912443543*^9, 3.445693123217423*^9, 3.445694997353664*^9, 
   3.4456956752152863`*^9, 3.445696056086925*^9, 3.445698518096301*^9, 
   3.445769860041099*^9, 3.44577004727223*^9, {3.445772259219943*^9, 
   3.44577228165744*^9}, 3.445772788960799*^9, 3.445773035829879*^9, 
   3.445773186064891*^9, 3.445773222052087*^9, 3.445773267352982*^9, 
   3.4457734175996513`*^9, 3.445773605543396*^9, 3.445773721937707*^9, 
   3.445774089500128*^9, 3.4457789363882504`*^9, 3.445782225805499*^9, 
   3.445782872945681*^9, 3.4457839018337603`*^9, 3.445785192781358*^9, 
   3.445786109716403*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]},
     {
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"]},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1"},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"]},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"]},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}]},
     {"1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"]},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1"},
     {
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}]},
     {
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1"},
     {
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}]},
     {
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1"},
     {
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"]},
     {"1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"]},
     {
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}]},
     {"1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"]},
     {
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"]},
     {"1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]},
     {
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1"},
     {
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]},
     {
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {"1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"], "1", 
      FractionBox["1", "2"], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.443974870969442*^9, 3.443974886723419*^9}, 
   3.443974960788389*^9, 3.443974996342749*^9, 3.443975088450672*^9, {
   3.4439751849542923`*^9, 3.443975206545869*^9}, {3.443975238356235*^9, 
   3.4439753066345882`*^9}, {3.443975423403428*^9, 3.443975431097713*^9}, 
   3.443975693892397*^9, 3.443977608114849*^9, 3.443977641971628*^9, 
   3.4439777228249903`*^9, 3.443979145043721*^9, 3.445608872007687*^9, 
   3.445611516388373*^9, 3.445613315297246*^9, 3.445680790733431*^9, 
   3.445681382880224*^9, 3.445681631065613*^9, 3.4456817136697273`*^9, 
   3.445687843341568*^9, 3.445688945562008*^9, 3.445689877905493*^9, {
   3.44569007693983*^9, 3.445690100465187*^9}, 3.445690156464563*^9, 
   3.445690187620311*^9, 3.445690266317725*^9, 3.445690428008502*^9, 
   3.445690477942089*^9, 3.445690937624625*^9, 3.445691083377411*^9, 
   3.44569152258197*^9, 3.4456916006559258`*^9, 3.445691716135345*^9, 
   3.445692912443543*^9, 3.445693123217423*^9, 3.445694997353664*^9, 
   3.4456956752152863`*^9, 3.445696056086925*^9, 3.445698518096301*^9, 
   3.445769860041099*^9, 3.44577004727223*^9, {3.445772259219943*^9, 
   3.44577228165744*^9}, 3.445772788960799*^9, 3.445773035829879*^9, 
   3.445773186064891*^9, 3.445773222052087*^9, 3.445773267352982*^9, 
   3.4457734175996513`*^9, 3.445773605543396*^9, 3.445773721937707*^9, 
   3.445774089500128*^9, 3.4457789363882504`*^9, 3.445782225805499*^9, 
   3.445782872945681*^9, 3.4457839018337603`*^9, 3.445785192781358*^9, 
   3.445786109773271*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12", ",", "12", ",", "12", ",", "12", ",", "12", ",", "9", ",", "9", ",", 
   "9", ",", "9", ",", "9", ",", "9", ",", "9", ",", "9", ",", "9", ",", "9", 
   ",", "9", ",", "9", ",", "3", ",", "3", ",", "3", ",", "3", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.443974870969442*^9, 3.443974886723419*^9}, 
   3.443974960788389*^9, 3.443974996342749*^9, 3.443975088450672*^9, {
   3.4439751849542923`*^9, 3.443975206545869*^9}, {3.443975238356235*^9, 
   3.4439753066345882`*^9}, {3.443975423403428*^9, 3.443975431097713*^9}, 
   3.443975693892397*^9, 3.443977608114849*^9, 3.443977641971628*^9, 
   3.4439777228249903`*^9, 3.443979145043721*^9, 3.445608872007687*^9, 
   3.445611516388373*^9, 3.445613315297246*^9, 3.445680790733431*^9, 
   3.445681382880224*^9, 3.445681631065613*^9, 3.4456817136697273`*^9, 
   3.445687843341568*^9, 3.445688945562008*^9, 3.445689877905493*^9, {
   3.44569007693983*^9, 3.445690100465187*^9}, 3.445690156464563*^9, 
   3.445690187620311*^9, 3.445690266317725*^9, 3.445690428008502*^9, 
   3.445690477942089*^9, 3.445690937624625*^9, 3.445691083377411*^9, 
   3.44569152258197*^9, 3.4456916006559258`*^9, 3.445691716135345*^9, 
   3.445692912443543*^9, 3.445693123217423*^9, 3.445694997353664*^9, 
   3.4456956752152863`*^9, 3.445696056086925*^9, 3.445698518096301*^9, 
   3.445769860041099*^9, 3.44577004727223*^9, {3.445772259219943*^9, 
   3.44577228165744*^9}, 3.445772788960799*^9, 3.445773035829879*^9, 
   3.445773186064891*^9, 3.445773222052087*^9, 3.445773267352982*^9, 
   3.4457734175996513`*^9, 3.445773605543396*^9, 3.445773721937707*^9, 
   3.445774089500128*^9, 3.4457789363882504`*^9, 3.445782225805499*^9, 
   3.445782872945681*^9, 3.4457839018337603`*^9, 3.445785192781358*^9, 
   3.445786109961203*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"longvecs", ",", " ", 
    RowBox[{"or", " ", "candidate", " ", "hadamards"}], ",", " ", 
    RowBox[{"live", " ", "in", " ", "an", " ", 
     SuperscriptBox["\[CapitalNu]", "2"], " ", "dimensional", " ", "space", 
     " ", "of", " ", "phases"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "here", " ", "are", " ", "two", " ", "directions", " ", "in", " ", "which",
     " ", "one", " ", "can", " ", "move", " ", "away", " ", "from", " ", 
    "fourier"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "corresponding", " ", "to", " ", "the", " ", "first", " ", "fourier", " ", 
    "family"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"phi12", "=", 
     RowBox[{
      FractionBox["1", 
       SqrtBox["6"]], 
      RowBox[{"(", GridBox[{
         {"0", "0", "0", "0", "0", "0", "0", "1", "0", "1", "0", "1", "0", 
          "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
          "0", "1", "0", "1", "0", "0", "0", "0", "0", "0"},
         {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
          "1", "0", "1", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", 
          "0", "0", "0", "0", "0", "1", "0", "1", "0", "1"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"here", " ", "are", " ", "two", " ", "more", " ", "directions"}],
      ",", " ", 
     RowBox[{
     "corresponding", " ", "to", " ", "the", " ", "second", " ", "fourier", 
      " ", "family"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"phi34", "=", 
     RowBox[{
      FractionBox["1", 
       SqrtBox["6"]], 
      RowBox[{"(", GridBox[{
         {"0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", "0", 
          "0", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", "0", "0", 
          "0", "0", "0", "0", "0", "1", "0", "0", "1", "0"},
         {"0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", 
          "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", "0", 
          "0", "0", "0", "0", "0", "0", "1", "0", "0", "1"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"here", "'"}], "s", " ", "a", " ", "list", " ", "of", " ", "all",
      " ", "four", " ", "of", " ", "those", " ", "directions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", 
    RowBox[{
     SqrtBox["6"], 
     RowBox[{"(", 
      RowBox[{"phi1234", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"phi12", ",", "phi34"}], "]"}]}], ")"}]}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.4439732935213823`*^9, 3.4439734750932837`*^9}, {
  3.443976894333482*^9, 3.4439768978369293`*^9}, {3.443979509917452*^9, 
  3.44397952033302*^9}, {3.445681733913743*^9, 3.4456817341676207`*^9}, {
  3.445688914441576*^9, 3.4456889235276127`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "0", "0", "0", "1", "0", "1", "0", "1", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "1", 
      "0", "1", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
      "0", "1", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "1", "0", "1", "0", "1"},
     {"0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", "0", "0", 
      "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", "0", "0", "0", "0", 
      "0", "0", "0", "1", "0", "0", "1", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", "0", 
      "0", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0", "0", "0", "0", 
      "0", "0", "0", "0", "1", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.445681738850412*^9, 3.4456878436287327`*^9, 3.445688945848443*^9, 
   3.445689878191576*^9, {3.445690077226226*^9, 3.445690100751635*^9}, 
   3.445690156750094*^9, 3.44569018790665*^9, 3.445690266598296*^9, 
   3.445690478227315*^9, 3.4456909379123287`*^9, 3.4456910836614647`*^9, 
   3.445691522868029*^9, 3.445691600941629*^9, 3.445691716421089*^9, 
   3.4456929127306843`*^9, 3.4456931235095463`*^9, 3.4456949976406803`*^9, 
   3.445695675501451*^9, 3.445696056403697*^9, 3.445698518383175*^9, 
   3.445769860360374*^9, 3.445770047565301*^9, {3.4457722595214443`*^9, 
   3.445772281947036*^9}, 3.445772789263042*^9, 3.445773036148698*^9, 
   3.445773186367015*^9, 3.445773222354597*^9, 3.445773267639727*^9, 
   3.445773417929656*^9, 3.445773605844832*^9, 3.445773722223042*^9, 
   3.445774089913034*^9, 3.445778936676103*^9, 3.445782226174583*^9, 
   3.445782873246567*^9, 3.445783902227405*^9, 3.445785193067933*^9, 
   3.445786110016489*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "those", " ", "four", " ", "directions", " ", "are", " ", "in", " ", "the",
     " ", "fourier", " ", 
    RowBox[{"Hessian", "'"}], "s", " ", "nullspace"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"i", ".", "e", ".", " ", "moving"}], " ", "in", " ", "any", " ", 
    "one", " ", "of", " ", "those", " ", "directions", " ", 
    RowBox[{"doesn", "'"}], "t", " ", "change", " ", "the", " ", 
    "nonunitarity"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"to", " ", "second", " ", "order"}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"MatrixForm", "[", 
   RowBox[{"h36", ".", 
    RowBox[{"Transpose", "[", "phi1234", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.443979110366184*^9, 3.443979123172538*^9}, {
  3.443979206129171*^9, 3.443979277333713*^9}, {3.44397932249621*^9, 
  3.443979332829445*^9}, {3.4456817500643597`*^9, 3.445681750397585*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.443979124078505*^9, 3.443979182867461*^9, 3.4439792946282454`*^9, 
   3.443979561377759*^9, 3.445608872557282*^9, 3.44561331565281*^9, 
   3.445680791094277*^9, 3.445681751366008*^9, 3.44568784367761*^9, 
   3.445688945966701*^9, 3.4456898782268667`*^9, {3.4456900772762213`*^9, 
   3.445690100801735*^9}, 3.445690156797554*^9, 3.445690187956587*^9, 
   3.44569026664666*^9, 3.445690478277665*^9, 3.445690937960462*^9, 
   3.4456910837121162`*^9, 3.4456915229017477`*^9, 3.445691600991803*^9, 
   3.4456917164699297`*^9, 3.445692912778516*^9, 3.445693123557374*^9, 
   3.4456949976920433`*^9, 3.445695675551049*^9, 3.44569605646035*^9, 
   3.445698518433824*^9, 3.445769860426632*^9, 3.44577004768069*^9, {
   3.445772259570869*^9, 3.4457722820619173`*^9}, 3.445772789314024*^9, 
   3.445773036232478*^9, 3.445773186417149*^9, 3.4457732224693937`*^9, 
   3.445773267689769*^9, 3.445773418098276*^9, 3.4457736058938293`*^9, 
   3.445773722273246*^9, 3.445774090002883*^9, 3.445778936726747*^9, 
   3.4457822262269983`*^9, 3.445782873297555*^9, 3.44578390227932*^9, 
   3.445785193117712*^9, 3.445786110066626*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "while", " ", "those", " ", "four", " ", "directions", " ", "span", " ", 
    "the", " ", "nullspace"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "they", " ", "are", " ", "not", " ", "necessarily", " ", "compatible"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"there", " ", "is"}], ",", " ", 
    RowBox[{"for", " ", "example"}], ",", " ", 
    RowBox[{
    "a", " ", "quartic", " ", "contribution", " ", "to", " ", "the", " ", 
     "nonunitarity"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"when", " ", "moving", " ", "in", " ", "the", " ", "phi2"}], "+", 
    
    RowBox[{"phi3", " ", "direction"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"fourier", "+", 
      RowBox[{"th", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"phi1234", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "+", 
          RowBox[{"phi1234", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "/", 
        SqrtBox["2"]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"th", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.443979340016642*^9, 3.4439793796213007`*^9}, {
  3.443979467214061*^9, 3.443979469543541*^9}, {3.443979565335061*^9, 
  3.4439795657658052`*^9}, {3.443979708110076*^9, 3.443979808814369*^9}, {
  3.445690064866558*^9, 3.4456900678317337`*^9}, {3.445694956145257*^9, 
  3.445694958845838*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl13k0lF0cB/ChCJWlKESWkGSrV0See60RKgoRaeyhInmFFmNNIcSLhOyh
bGVfJ0QSIUXZJSGhLJWk997H/DPnc77fe3/33GdmzhkRG9cT9owUCuU0A4WC
3/XsJzrpkyaAQr5Gqtdr8rsN8SlAkrQF1X8exCc+5dNacwoTMSYg5ndF4tia
hdkI/baeJ0l8xmvu3UWIhQlm/hUyX/PCfmJFzzbOWsJqzap6xFRgd6N1rPWa
PxkTp+x+1NzlsyNNO29DNGrylzUkOqxZ9Dwhv4soXBByWvOpf4lERmqOeLrL
mvf6Eiyj/mmmEhdJp1CDicrhrrYGY7c1t94h3Azt9CxjL5EurIkhJOiLTQs9
7qSp1PvEgNxNzXA+D9Is5alEzANeurjFv6R5o7MIPY5c1dpET9LnTj8mKL6H
KkwHr5DuTysiSmdeHZgV8ibdEVdCnLeyenLT2of0NZ1KQrR9VlY4/SrplfQ6
opfwe1Q+do10wlQ9cSdvi6SRxA3SPueaCG3BjIxJR1/SurYviRtNCZzPjGmk
s/raCfMbH4+FL64ZLnYSCorS4eaxfqR9G7oJjhmPVnElf9KMYz3EVGYN6/ee
NT+z7COen2HWrfUKIF20b4hI4TkefJsvEJuWUTJCXG2LazStXPNeljHCNGiY
cZdFENnXuztO7CP2qM/+Jk2LNZskNi1e8q1KDCYtfHaa+Py4suYmcZO02cNZ
ot5u3crJQdL0P/e/EV7dMV7TQrew1eaTFomTYQOl5XTS9N7+H4SslsRioPVt
0mo6ywTrysV/jBhDyfmbhlaIsadllwTT19ye9Zeoc6EUTmqGYQt7GjKAhF1H
ZkrGSKcMfWYERtEfnI9J3CH3E3FmBtL6u3L4m0lTfU+xAJZ15z+PO0aQ67tt
2cDZitWiOuNIMj82xA4MeHZ1imeSpvlmcwKVSzpzoYuk5VPnuQDPnkhZs9go
7MjdDdyAMaj4aO046Q7pI9vA3HDveTGlu+R5FMa2g9Z4kUdzPaQ7zCx3gPIF
7ZemktHYnAcOCYIsQ+fJai/SVIH9QsCP5enuW3wx2LovS0SAlE5UyBM30gc7
50RBV5DrZF8z6ZB1qmJAbJ30I1nP/7B/ijHtBq/U2TaZtZGO3BkoCf6lTZz3
E4sl57vwSIGmPxmy3V2kJa9fkgGuqgERf/bEYfdeJOQA71XrOQk/0mHsEfLA
6afgE2+5ePK8GyL3g03zsQeEwu5hBwIBJVCy799Y3Y+kF1bPHARWbid/XFJJ
wFYofawMCr5yVDROkJY/6q4KzKRn+GbgfXLe10kCUFxe+WyPI63wyRWCExMh
qs7aidjfJYzVwW8Jx6ToRNI2NTIaIMNee7V6njQzwaEJFkcZ6BxpSdjra6a0
QPyAj2bJajI2Pw/rEaAuYJ4xaPIAu8tytx6YOq3ExJJH2lP0uD7YOe1tmyeT
gn1+seoocN84uVXDnHSWG8Nx0CRl1vgukPSBZElD4OqkKE7pX/PpECPQGJL5
NmZDKratvdoJwJvNHbznH9Lcm1dPAPr49/ETt0nP379tDLbYFWRnHkzDdvr7
5RRwCNhprmJHWntbtxmoSgtnfR1BWqWk3hzYjbg4/xwnHcVWbAFKrCSl9f9L
x1aKmDoL2G7E9Q/RSXvIB1GBVRJzuMc06b/DvNaAuX/sa5JmBjKtpUPfBpiZ
pxbMfSPN/nbEDsz2GbOl8Wdic/wMsgfBViz2JzVJ+/fLOICntq78pTGkEwVu
OQL2i0TQVaUs7Iw9rs4gc25uSJpK+s/UfhegejlDZTCEdMfYsgtw9to4p/aB
dFFF3AXw3P/9aebrD5HVvEwD3IAlU3hJWSY2/cHskhv4flON06kdm8b48fwl
IBz+8HmrUDbud6+cdQfX4v6Vj6onLfje1gPsf8zFLMCSi/0+c9ILtMg+p7bJ
Y9N+vg/2BtQir6ob5mRe903CB4SXDrmN5JKOmnW9CiboeX1ZRx9hV+6SuAF8
Na0VzTyxaeXufTfAtibuKNYH2HT9mWhfoNl69fD5OexhnSM3aSD57ZGifdGP
cT76iscfHDD7s/FjFXYKY/51f/DqQ6FDzBjpWv3P/uDX0HaBHwfy8Lw7XXUB
wHjqU3B1LzZlKjY4CGz862eps7MA7y/o7noLxDudspI+jE1X7P9+C4h1S1O5
LmJTGNS9bgOQ02PbV4OdspPjViioyIktKZMtRBZu0m8IB19PTlfrt2MX8roc
jwIKrD0EGMV205ZOiwI+tc9q5ZewDdu4l6LAhj1xdJ6dRXh+lEPqXSCyqt44
dAHbMMaCOQaYZMe1Xt78BDny3OrGOJB4xt/AQYR0QYB7HBjdcqHN7AB24a0z
H+KA63WN18QZMn/Fnx8Pbp342rUhj3T6ZocEULOi8eG+wVN8nvVX+JPB+icy
Fneo2IUKj+OSgZ4jbz/NAzvysMO2B6Cn8+uAfSK2F+XQphTwLSt+RG4aW/5b
3vZUIG40M9EQWozP7x1ikg74fXVUHFOxKd98HqYDzryUULYy7I4mt+V0sMxy
UtZoFHvOzDU9A3TQyy4PHixBjk+cZ8gCPvJ+qz8/YZ9rYpjPBq5WH44n/sbW
NZIzzQF2YejLzlWKrRVQmQOOT3zSDFbFPsiQHZwLxFL0bm2NxvZSEpN5DNo5
uLll1crwee/MFheABuKCfacJNq9hG08hKHdpKvVwKSOfxwujQpDe7GVeFYsd
b1HaWgi8fAeSdb9ih62/01wERGez9tgmlCNXD2gMPwVX2pVh/EIF8guRe8nl
gF225FMLSyVyd3TEl3KQES4f9lsAe+W7snIF6DTY/d5KG9s4Nf9dBdjbyn1Z
PBabs1ORvwoMNc9mPVGqQp4+X9VYAzx3uxwd08c26PQQrAWbbo7P81CxAxfn
PWuB8uEBNe8Q7JVZHek6EN348gN8j72t8h9DOtB5lsne5lON3HSxsecZGBQW
KVm9g10YH8NWDzxoiRby6diMqx1EPUiF0dnRrdjtnZGZ9eB3DU3jtEANMnsM
4dMACiotPD/XYM+kvzn4HGwv5hpkYKhD/q6ix9ECLMN+G49tw3ZuNDZtAWl2
n1qbpLEvflpMagHSPBUVoWbYlWZ/ZV8CDU/qfzyF2D/lD5u1AsXEU1kxcnTk
qVDqizZgHvJqJEgFWzJBma8dXPNQF7yijZ3QW+rcDp4Z7I0xt8DOV0jleA0M
/qz67byJnfgzS74DWFtlnckexP4h5XC3EwTq7bh3bxLb7bIkvRNkKUZ2317A
JgY0ZzrBNLuP/gW2Z8g3J27qdwHPuqPK+xWxr/oasb0BYcKL3NXh2EWqRve6
Qemo5qvXqvXIdQaHKb3gna7ft3Ad7Fnjdcq9YCm/dpvBCWzTYjH3XqB0Vdn6
hSP2NsvYT72gfKvcEv0u9mZljc73oEKLX/jJBPb1cbHqPlCdNXc5JqYBOfeK
08ch0L9J9t6JB9jaL9u4h8GKu0stZy62aq7wwWFAwHGW8DpkWlq3h+8wqO3p
Swqawl5+M8A5AupYmps91RpRP/a/KTAK6p2TdphPI9MObS9rGQNPJ11crJaw
oyozvo2BjHMqVbaU56jf39DK9wkEOfScvsiN3T3e5PwJ6NpwJQSoYte4XuEY
B6/Ng3jzw5BpOULfbT+Dft0LPOtkmlCu9KxHZQq0NR+yZ1FCpv0XaOU8BWoP
s5VsVsd5XJV4whR4oPXQmNcE29Hdc3kK2KiNRMtcx/0Uu921X8CEkskWszbs
KPqy0VewKEFw5F1oRv2WPwGmcwCMajTf9kJWE8gb95gDwUm6vucCcB6cfTl6
DmzjNp7ddQ+Zvl94c+ccUGRweZ3QiPuPrTSOfQNeffERITteoHy2rNfwO1iJ
WOCwa8Euim27sgC09Jeb1buRKW//NN1fAGHMFJrQELKadsVs3QIQvL5x7sMC
7h/ueM2yCICzaIeRcAuyMfvrxEXgq2UYCa9g59jMtC0Bxl+POHeIv0TrnSd6
TX6BHW0a81AOW6MeXP8FFFLfv7VTRqZ7e3dl/AL2Rzbczz+KXc8ZuPALvLhn
I67hifvKz7bGLoMIFT4Vp2Zkinfo+tHfQOBasG2ZUyu6r3KHPcmr4ICh4OH+
y63496UjsnUVHBMrlmS4gUy3Spf6tQp8X4181buLvZV3yfgvGBUgvAYrkali
e7w2UGBOzXwY06ZXKA91P9JEgYp/qaUn85GF929uO8UIDY7S/bXLkVNgke4l
Rmh7X+i4Uj321p7B24wwUmnwM/873Nf9drqWEU66WvCN/sG5unWMxDqYOGxy
ze1oG6QM+1oJrKyDDPV6GuHTyMItPuuqmSAvZy677xIy1d54vpcJylqx9rlR
2lG/mZmyxARPLzdfNuZGpl5Qd5NnhsX7tTN3qGLr78nPYoYO6ZAlNxRZeDG5
MH4DfBWo0N4k9RrZ/KRZNCtU4WhljDqATDkU21nKCrPvWStZqCGnGBa4fmCF
Afl3UmZNkGmNLfyibFCld8Kd1w+ZKu8s95QNZu9N2u7cg+3bcq5/I9SY9C9k
1ujAn2etTn12KBT55VfODLK847RQFxestfbNeTKP7Nbz49RnLmj1z1bzqp/Y
UjNpK1ww8Z1K+SvGTkgp1HpxafcWyCt423N2GzKN88LC9S1wS67kvALEeYRF
nOxWyNRoP10XgaxW6Z+ezA2//BgafCvfheaF+Z2p3g5LHSPq9RSR54bWjfRu
h7QekFV3CJlTfe+Nxe1wW1nShZzDyNRTD5nkeKGGp8XKNUvkQl5G/XRemLDw
jk8sBO/X2VgdyQd1v7UZuw/h9cq0HN8dMGOq6iX7nTdofmfdziIheDHu+C7n
aGS3O7Ijb4SgktbHq8/jkSONJelLQvBlEpvMtXRkTulVp53C8JuhecRkOTK9
+ryUvTAEZUsnGz/i/fgi7RaF4fuAfQPeyt3o/NnEorAoZBd8ODs2hhz/MfBI
lhhUMw0Y+DiJ7NZdsKlSDLpHnG0dnUHuEFg/2CYG3zHwPhz+ifzCVPPRohhM
Hg+x6t/0Fj1/0Q9z2uJQttC57Y0CMueHU7KT4vCopuyj+kBk3fYzaSq7YZhT
iUOK2Du0vwL/dzYpOKWWF7JRCtlsX9llMSmow5uZ6ymHfLBrAwuQgozNMTMG
Kshq7ybOXZKC3mIenr+OI/9Uztn0Xgo6DO0PPnEV23732KO9UN2kMHN9FzLN
I38rVQYuqT0aO+fbAymqLRZq/vLQY39j8baGXkh5LPL+42kFOJTfGNop8gFS
pE8/GCWU4W/n7vt7fPogxav5alEvgHvVN6w6VPWj++lyPOeqAXXSRByLtg9C
igT1tbbMYXhF8KzoiOUQpJxIZgqQ1IPS0yYbe44OQ8pShQ1zxDG4lWOOpXEZ
WcTQou6HEVxfd79gV+IIpCib6Cq/MIYuClXvWfVHIWUxRYtnnxl8dMQmpXYJ
uUHnheiMBVz8ws85HvsR3a+sVPHLs7DkpM66GK0xSNNiazQ9YAN9dYMeFI8j
c6lJ/PjPDooM6PWmB32CtF9tt9xFHaGKUmAM3/5xSFmN4e6VdIaWO1//Yngz
Dmm3uYepxAW4+DJ81M3vM6T36cqpuLnB+PVWHifEJiB9oKP7ua473DpYksbY
iLwe/e0nPCDTdT9j5UuTkBL1cGthiCek5FgVjG6Zgmr6knd0e72ge0JB+JZ6
5NTKYr3Qq7BmbwgL18UvUO3IPzJ0hxuQS89d2p99GqZcH7luk0qD/TIdb7yr
pyHNKDgnVc8fFiZDsTGrr5D2ZqMzbT4AnilQ5BJc/QqpxUG+RwqCIC0o1a8/
dwZSidDFpMKbMG9C8D67wSykuXkGNeTfgkZc7Aebl2fhMN8u8R2/Q+FtJsYd
/ciUu1+rbZEbfy3+mUNO0dIyeYysODrQwP97FlITY28SK6GQ/2ne8YvIKYbt
38/+CYWjxkcdeVbQfqyhHzP+hkKP+LBY2z/IoUBWbn0YzAujeXshC3vc7bmC
PE7zsAxHpja7+9GRzZwsRcuwPXvfGTGFQUJFOp9tFVnyYIgHcxhk7m99XoTd
r8tUyRIGYUdddhN2vE0ZI2sY9Gp8GtqHnJLL4qyPPPX4vhHTX5SLLHf0I7df
dxkwQ6b3Xsr8yxYGN7ifpV/AedGMhe7GMKjmcDLdH1mN8eeWKOQnxw45Pcb9
dYX+opvC4BcNOYNnyML3rA65IIsp7ZJ7h/v69xaeIlvt3b7lC3LKCjV/BTlO
aOPiX9yvLj6nvTkM/g9uBxrK
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {-1.887379141862766*^-15, 0.013697187669633293`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.445695000991365*^9, 3.445695678937511*^9, 3.4456960599470177`*^9, 
   3.445698521783197*^9, 3.445769863883731*^9, 3.4457700510525618`*^9, {
   3.445772262951432*^9, 3.445772285424032*^9}, 3.445772792774137*^9, 
   3.4457730396837673`*^9, 3.445773189729723*^9, 3.445773225836185*^9, 
   3.445773271160351*^9, 3.445773421661557*^9, 3.445773609287238*^9, 
   3.445773725669105*^9, 3.445774093414268*^9, 3.445778940118346*^9, 
   3.445782229559966*^9, 3.445782876554019*^9, 3.4457839055483007`*^9, 
   3.445785196404339*^9, 3.445786113338565*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "in", " ", "quantum", " ", "mechanics", " ", "the", " ", "overall", " ", 
    "phase", " ", "of", " ", "a", " ", "state", " ", "vector", " ", "is", " ",
     "irrelevant"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "so", " ", "for", " ", "each", " ", "column", " ", "vec", " ", "we", " ", 
    "can", " ", "constrain", " ", "its", " ", "first", " ", "phase", " ", 
    RowBox[{"(", 
     RowBox[{"to", " ", "be", " ", "zero"}], ")"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "in", " ", "which", " ", "case", " ", "we", " ", "can", " ", "ignore", " ",
     "the", " ", "partials", " ", "with", " ", "respect", " ", "to", " ", 
    "those", " ", "phases"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "concentrate", " ", "on", " ", "the", " ", "others"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "here", " ", "are", " ", "the", " ", "relevant", " ", "indices", " ", 
     "from", " ", "an", " ", 
     SuperscriptBox["\[CapitalNu]", "2"]}], "-", 
    RowBox[{"element", " ", "longvec"}]}], " ", "*)"}], "\[IndentingNewLine]",
   
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{"im30", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalNu]", 
         RowBox[{"(", 
          RowBox[{"m", "-", "1"}], ")"}]}], "+", "i"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "\[CapitalNu]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "1", ",", "\[CapitalNu]"}], "}"}]}], "]"}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"im30", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Transpose", "[", "im30", "]"}], "]"}]}], "\[IndentingNewLine]", 
   
   RowBox[{"(*", " ", 
    RowBox[{
    "which", " ", "we", " ", "can", " ", "use", " ", "to", " ", "concentrate",
      " ", "on", " ", "the", " ", "relevant", " ", "partials", " ", "as", " ",
      "follows"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g30", "=", 
     RowBox[{"g36", "[", 
      RowBox[{"[", "im30", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h30", "=", 
     RowBox[{"h36", "[", 
      RowBox[{"[", 
       RowBox[{"im30", ",", "im30"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.4456140889296427`*^9, 3.445614192095017*^9}, {
   3.4456142341077633`*^9, 3.445614266020089*^9}, {3.445614306604499*^9, 
   3.445614357794875*^9}, {3.445614550314839*^9, 3.4456145523544607`*^9}, {
   3.445680716966758*^9, 3.44568072254554*^9}, {3.4456808555895567`*^9, 
   3.445680906794137*^9}, {3.445680940209881*^9, 3.445681023666098*^9}, 
   3.445681111590427*^9, {3.445681449986617*^9, 3.445681450330102*^9}, {
   3.4456817879368963`*^9, 3.445681827994227*^9}, {3.445681865769835*^9, 
   3.4456818788982964`*^9}, {3.4456820676928864`*^9, 3.445682073866673*^9}, {
   3.445771885189074*^9, 3.445771904059964*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", "8", "14", "20", "26", "32"},
     {"3", "9", "15", "21", "27", "33"},
     {"4", "10", "16", "22", "28", "34"},
     {"5", "11", "17", "23", "29", "35"},
     {"6", "12", "18", "24", "30", "36"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.445614358160131*^9, 3.4456145716119947`*^9, 3.445680790584621*^9, 
   3.445681028749104*^9, 3.445681114688251*^9, 3.445681759659026*^9, 
   3.44568190226378*^9, 3.445682077222536*^9, 3.445687847135704*^9, 
   3.445688974569681*^9, 3.4456898817281647`*^9, {3.4456900773587513`*^9, 
   3.4456901008517838`*^9}, 3.4456901568514967`*^9, 3.445690188016461*^9, 
   3.445690266706265*^9, 3.445690478329175*^9, 3.445690938011446*^9, 
   3.445691083771291*^9, 3.445691522961382*^9, 3.445691601043495*^9, 
   3.445691716521484*^9, 3.4456929128303623`*^9, 3.445693123684698*^9, 
   3.445695001140541*^9, 3.445695679043201*^9, 3.445696060051269*^9, 
   3.445698521889553*^9, 3.4457698640186777`*^9, 3.445770051137883*^9, {
   3.445772263161992*^9, 3.445772285527811*^9}, 3.445772792868808*^9, 
   3.4457730397738247`*^9, 3.445773189817609*^9, 3.445773225926214*^9, 
   3.4457732712529707`*^9, 3.445773422080221*^9, 3.445773609400325*^9, 
   3.4457737257821083`*^9, 3.4457740935210247`*^9, 3.445778940254987*^9, 
   3.4457822297016993`*^9, 3.445782876667728*^9, 3.445783905689872*^9, 
   3.4457851964838963`*^9, 3.4457861134410048`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "8", ",", "9", ",", "10", 
   ",", "11", ",", "12", ",", "14", ",", "15", ",", "16", ",", "17", ",", 
   "18", ",", "20", ",", "21", ",", "22", ",", "23", ",", "24", ",", "26", 
   ",", "27", ",", "28", ",", "29", ",", "30", ",", "32", ",", "33", ",", 
   "34", ",", "35", ",", "36"}], "}"}]], "Output",
 CellChangeTimes->{
  3.445614358160131*^9, 3.4456145716119947`*^9, 3.445680790584621*^9, 
   3.445681028749104*^9, 3.445681114688251*^9, 3.445681759659026*^9, 
   3.44568190226378*^9, 3.445682077222536*^9, 3.445687847135704*^9, 
   3.445688974569681*^9, 3.4456898817281647`*^9, {3.4456900773587513`*^9, 
   3.4456901008517838`*^9}, 3.4456901568514967`*^9, 3.445690188016461*^9, 
   3.445690266706265*^9, 3.445690478329175*^9, 3.445690938011446*^9, 
   3.445691083771291*^9, 3.445691522961382*^9, 3.445691601043495*^9, 
   3.445691716521484*^9, 3.4456929128303623`*^9, 3.445693123684698*^9, 
   3.445695001140541*^9, 3.445695679043201*^9, 3.445696060051269*^9, 
   3.445698521889553*^9, 3.4457698640186777`*^9, 3.445770051137883*^9, {
   3.445772263161992*^9, 3.445772285527811*^9}, 3.445772792868808*^9, 
   3.4457730397738247`*^9, 3.445773189817609*^9, 3.445773225926214*^9, 
   3.4457732712529707`*^9, 3.445773422080221*^9, 3.445773609400325*^9, 
   3.4457737257821083`*^9, 3.4457740935210247`*^9, 3.445778940254987*^9, 
   3.4457822297016993`*^9, 3.445782876667728*^9, 3.445783905689872*^9, 
   3.4457851964838963`*^9, 3.445786113445354*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "we", " ", "can", " ", "also", " ", "constrain", " ", "the", " ", "first", 
    " ", "phase", " ", "of", " ", "each", " ", "row"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "according", " ", "to", " ", "the", " ", "overall", " ", "phase", " ", 
    "irrelevance", " ", "of", " ", "each", " ", "standard", " ", "basis", " ",
     "vector"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "in", " ", "which", " ", "case", " ", "we", " ", "can", " ", "also", " ", 
    "ignore", " ", "the", " ", "partials", " ", "with", " ", "respect", " ", 
    "to", " ", "those", " ", "phases"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"and", " ", "concentrate", " ", "on", " ", "the", " ", "others"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "here", " ", "are", " ", "the", " ", "relevant", " ", "indices", " ", 
     "from", " ", "an", " ", 
     SuperscriptBox["\[CapitalNu]", "2"]}], "-", 
    RowBox[{"element", " ", "longvec"}]}], " ", "*)"}], 
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{"im25", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalNu]", 
         RowBox[{"(", 
          RowBox[{"m", "-", "1"}], ")"}]}], "+", "i"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "\[CapitalNu]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "2", ",", "\[CapitalNu]"}], "}"}]}], "]"}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"im25", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Transpose", "[", "im25", "]"}], "]"}]}], "\[IndentingNewLine]", 
   
   RowBox[{"(*", " ", 
    RowBox[{
    "which", " ", "we", " ", "can", " ", "use", " ", "to", " ", "concentrate",
      " ", "on", " ", "the", " ", "relevant", " ", "partials", " ", "as", " ",
      "follows"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g25", "=", 
     RowBox[{"g36", "[", 
      RowBox[{"[", "im25", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h25", "=", 
     RowBox[{"h36", "[", 
      RowBox[{"[", 
       RowBox[{"im25", ",", "im25"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.445614496074905*^9, 3.445614555514348*^9}, {
   3.445680737913933*^9, 3.445680745177446*^9}, {3.44568105039747*^9, 
   3.445681101054183*^9}, {3.445681452769599*^9, 3.445681453112856*^9}, {
   3.44568189182808*^9, 3.445681918108099*^9}, 3.44568208263723*^9, {
   3.445682115630171*^9, 3.4456821189780188`*^9}, {3.445767406068412*^9, 
   3.4457674269539967`*^9}, {3.445771892218801*^9, 3.445771908497809*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"8", "14", "20", "26", "32"},
     {"9", "15", "21", "27", "33"},
     {"10", "16", "22", "28", "34"},
     {"11", "17", "23", "29", "35"},
     {"12", "18", "24", "30", "36"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.445614529320745*^9, 3.4456145716553297`*^9, 3.4456807906294127`*^9, 
   3.4456811407133713`*^9, 3.445681762274458*^9, 3.445681919422995*^9, 
   3.445682124921335*^9, 3.445687847192442*^9, 3.445688999062475*^9, 
   3.445689881838605*^9, {3.44569007740904*^9, 3.445690100886145*^9}, 
   3.445690156890547*^9, 3.4456901880727262`*^9, 3.44569026676341*^9, 
   3.445690478361067*^9, 3.445690938043826*^9, 3.44569108382843*^9, 
   3.445691523001994*^9, 3.4456916010755167`*^9, 3.445691716554308*^9, 
   3.445692912879116*^9, 3.44569312374009*^9, 3.445695001173698*^9, 
   3.445695679099955*^9, 3.44569606012507*^9, 3.44569852194842*^9, 
   3.445769864074648*^9, 3.4457700511962442`*^9, {3.4457722635305767`*^9, 
   3.445772285578781*^9}, 3.445772792925432*^9, 3.445773039830532*^9, 
   3.445773189848325*^9, 3.445773225986043*^9, 3.445773271303748*^9, 
   3.4457734221990433`*^9, 3.445773609459531*^9, 3.445773725837721*^9, 
   3.4457740935676193`*^9, 3.4457789403076363`*^9, 3.445782229824463*^9, 
   3.4457828767132196`*^9, 3.445783905758215*^9, 3.445785196516789*^9, 
   3.445786113498329*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8", ",", "9", ",", "10", ",", "11", ",", "12", ",", "14", ",", "15", ",", 
   "16", ",", "17", ",", "18", ",", "20", ",", "21", ",", "22", ",", "23", 
   ",", "24", ",", "26", ",", "27", ",", "28", ",", "29", ",", "30", ",", 
   "32", ",", "33", ",", "34", ",", "35", ",", "36"}], "}"}]], "Output",
 CellChangeTimes->{
  3.445614529320745*^9, 3.4456145716553297`*^9, 3.4456807906294127`*^9, 
   3.4456811407133713`*^9, 3.445681762274458*^9, 3.445681919422995*^9, 
   3.445682124921335*^9, 3.445687847192442*^9, 3.445688999062475*^9, 
   3.445689881838605*^9, {3.44569007740904*^9, 3.445690100886145*^9}, 
   3.445690156890547*^9, 3.4456901880727262`*^9, 3.44569026676341*^9, 
   3.445690478361067*^9, 3.445690938043826*^9, 3.44569108382843*^9, 
   3.445691523001994*^9, 3.4456916010755167`*^9, 3.445691716554308*^9, 
   3.445692912879116*^9, 3.44569312374009*^9, 3.445695001173698*^9, 
   3.445695679099955*^9, 3.44569606012507*^9, 3.44569852194842*^9, 
   3.445769864074648*^9, 3.4457700511962442`*^9, {3.4457722635305767`*^9, 
   3.445772285578781*^9}, 3.445772792925432*^9, 3.445773039830532*^9, 
   3.445773189848325*^9, 3.445773225986043*^9, 3.445773271303748*^9, 
   3.4457734221990433`*^9, 3.445773609459531*^9, 3.445773725837721*^9, 
   3.4457740935676193`*^9, 3.4457789403076363`*^9, 3.445782229824463*^9, 
   3.4457828767132196`*^9, 3.445783905758215*^9, 3.445785196516789*^9, 
   3.4457861135026197`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"starting", " ", "from", " ", "fourier"}], ",", " ", 
    RowBox[{
    "there", " ", "are", " ", "four", " ", "directions", " ", "in", " ", 
     "which", " ", "we", " ", "can", " ", "move"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "here", " ", "we", " ", "take", " ", "small", " ", "steps", " ", "in", 
     " ", "the", " ", "first", " ", "direction"}], ",", " ", 
    RowBox[{"then", " ", "in", " ", "the", " ", "second"}], ",", " ", 
    RowBox[{"and", " ", "so", " ", "on"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "after", " ", "each", " ", "step", " ", "we", " ", "make", " ", "small", 
    " ", "corrections", " ", "with", " ", 
    RowBox[{"Newton", "'"}], "s", " ", "method"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "update", " ", "the", " ", "four", " ", "directions", " ", 
    "by", " ", "projecting", " ", "them", " ", "into", " ", "the", " ", 
    "changing", " ", "nullspace"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "F6Foray", " ", "takes", " ", "a", " ", "four", " ", "element", " ", 
     "list"}], ",", " ", "\"\<thetas\>\"", ",", " ", 
    RowBox[{
    "specifying", " ", "the", " ", "distance", " ", "to", " ", "move", " ", 
     "in", " ", "each", " ", "dir"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "returns", " ", "the", " ", "final", " ", "nonunitarity", " ", 
    "at", " ", "the", " ", "end", " ", "of", " ", "the", " ", "foray"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "it", " ", "also", " ", "records", " ", "tracking", " ", "data", " ", "to",
     " ", "review", " ", "the", " ", "foray", " ", "after", " ", 
    "completion"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"F6Foray", "[", "thetas_", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "here", " ", "is", " ", "the", " ", "list", " ", "of", " ", "variables", 
      " ", "used", " ", "only", " ", "within", " ", "this", " ", "Module"}], 
     " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "phivec", ",", "dirvecs", ",", "dth", ",", "dths", ",", "mincurv", ",", 
       "maxnewt", ",", "evals", ",", "evecs", ",", "n25", ",", "evecs36"}], 
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "specify", " ", "initial", " ", "Hadamard", " ", "and", " ", 
       "directions", " ", "and", " ", "integration", " ", "parameters"}], " ",
       "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"phivec", "=", 
       RowBox[{"N", "[", "fourier", "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "start", " ", "at", " ", "fourier", " ", "for", " ", "the", " ", 
        "initial", " ", "hadamard"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"dirvecs", "=", "phi1234"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "start", " ", "with", " ", "phi1234", " ", "for", " ", "the", " ", 
        "four", " ", "normalized", " ", "directions"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"dth", "=", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]], "//", "N"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"small", " ", 
         RowBox[{"(", "slow", ")"}], " ", "step", " ", "size"}], ",", " ", 
        RowBox[{"in", " ", "radians"}], ",", " ", 
        RowBox[{"in", " ", "nullspace"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"dth", "=", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "1"}]], "//", "N"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"big", " ", 
         RowBox[{"(", "fast", ")"}], " ", "step", " ", "size"}], ",", " ", 
        RowBox[{"in", " ", "radians"}], ",", " ", 
        RowBox[{"in", " ", "nullspace"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"dth", "=", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]], "//", "N"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"medium", " ", 
         RowBox[{"(", "moderate", ")"}], " ", "step", " ", "size"}], ",", " ",
         
        RowBox[{"in", " ", "radians"}], ",", " ", 
        RowBox[{"in", " ", "nullspace"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"nsteps", "=", 
       RowBox[{"Round", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{"thetas", "/", "dth"}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "number", " ", "of", " ", "steps", " ", "in", " ", "each", " ", 
        "direction"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"dths", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"thetas", "[", 
           RowBox[{"[", "dir", "]"}], "]"}], "/", 
          RowBox[{"nsteps", "[", 
           RowBox[{"[", "dir", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"dir", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "exact", " ", "dth", " ", "to", " ", "use", " ", "for", " ", "each", 
        " ", "direction"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"mincurv", "=", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "4"}]], "//", "N"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"minimum", " ", "curvature", " ", "for", " ", 
        RowBox[{"Newton", "'"}], "s", " ", "Method", " ", "corrective", " ", 
        "step"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"maxnewt", "=", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "2"}]], "dth"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"maximum", " ", "step", " ", "size"}], ",", " ", 
        RowBox[{"in", " ", "radians"}], ",", " ", 
        RowBox[{"for", " ", "corrective", " ", "step"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "here", " ", "is", " ", "a", " ", "way", " ", "to", " ", "keep", " ", 
        "track", " ", "of", " ", "the", " ", "four", " ", "way", " ", "foray",
         " ", "from", " ", "fourier"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"cntr", "=", "1"}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "step", " ", "index", " ", "for", " ", "tracking", " ", "data"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"track", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{
            RowBox[{"fgh", "[", "phivec", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "phivec", ",", "dirvecs"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Total", "[", "nsteps", "]"}], "+", "1"}], "}"}]}], 
        "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "first", " ", "slot", " ", "is", " ", "for", " ", "the", " ", 
        "accumulated", " ", "phase", " ", "shifts", " ", 
        RowBox[{"(", "thetas", ")"}], " ", "in", " ", "each", " ", 
        "direction"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "second", " ", "slot", " ", "is", " ", "for", " ", "the", " ", 
        "nonunitarity"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "third", " ", "slot", " ", "is", " ", "for", " ", "the", " ", 
        "current", " ", "phases", " ", 
        RowBox[{"(", "phivec", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "fourth", " ", "slot", " ", "is", " ", "for", " ", "the", " ", "four", 
        " ", "evolving", " ", "directions", " ", 
        RowBox[{"(", "dirvecs", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"here", ",", " ", 
        RowBox[{"at", " ", "last"}], ",", " ", 
        RowBox[{
        "is", " ", "the", " ", "four", " ", "way", " ", "foray", " ", "from", 
         " ", "fourier"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Do", "[", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "loop", " ", "over", " ", "the", " ", "four", " ", "directions"}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Do", "[", " ", 
          RowBox[{"(*", " ", 
           RowBox[{"walk", " ", "a", " ", "distance", " ", 
            RowBox[{"thetas", "[", 
             RowBox[{"[", "dir", "]"}], "]"}], " ", "in", " ", "the", " ", 
            RowBox[{"dirvecs", "[", 
             RowBox[{"[", "dir", "]"}], "]"}], " ", "direction"}], " ", 
           "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"phivec", "=", 
             RowBox[{"phivec", "+", 
              RowBox[{
               RowBox[{"dths", "[", 
                RowBox[{"[", "dir", "]"}], "]"}], " ", 
               RowBox[{"dirvecs", "[", 
                RowBox[{"[", "dir", "]"}], "]"}]}]}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{"take", " ", "a", " ", "small", " ", "step"}], " ", 
             "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"nonu", ",", "g36", ",", "h36"}], "}"}], "=", 
             RowBox[{"fgh", "[", "phivec", "]"}]}], ";", 
            RowBox[{"(*", " ", "evaluate", " ", "*)"}], "\[IndentingNewLine]",
             "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "figure", " ", "a", " ", "corrective", " ", "Newton", " ", 
              "Step", " ", "as", " ", "follows"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"g25", "=", 
             RowBox[{"g36", "[", 
              RowBox[{"[", "im25", "]"}], "]"}]}], ";", 
            RowBox[{"h25", "=", 
             RowBox[{"h36", "[", 
              RowBox[{"[", 
               RowBox[{"im25", ",", "im25"}], "]"}], "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "focus", " ", "on", " ", "unconstrained", " ", "phases"}], " ", 
             "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"evals", ",", "evecs"}], "}"}], "=", 
             RowBox[{"Eigensystem", "[", "h25", "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "get", " ", "the", " ", "curvatures", " ", "and", " ", 
              "principal", " ", "axes"}], " ", "*)"}], "\[IndentingNewLine]", 
            
            RowBox[{"evecs", "=", 
             RowBox[{"Orthogonalize", "[", 
              RowBox[{"evecs", ",", 
               RowBox[{"Method", "\[Rule]", "GramSchmidt"}]}], "]"}]}], ";", 
            " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "make", " ", "sure", " ", "degenerate", " ", "ones", " ", "are", 
              " ", "orthogonal"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"g25", "=", 
             RowBox[{"evecs", ".", "g25"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "transform", " ", "into", " ", "eigenbasis", " ", "of", " ", 
              "h25"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"n25", "=", 
             RowBox[{"Table", "[", " ", 
              RowBox[{"(*", " ", 
               RowBox[{"figure", " ", "newton", " ", "step"}], " ", "*)"}], 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"evals", "[", 
                    RowBox[{"[", "alp", "]"}], "]"}], "]"}], ">", "mincurv"}],
                  ",", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"g25", "[", 
                    RowBox[{"[", "alp", "]"}], "]"}]}], "/", 
                  RowBox[{"evals", "[", 
                   RowBox[{"[", "alp", "]"}], "]"}]}], ",", "0"}], "]"}], ",",
                
               RowBox[{"{", 
                RowBox[{"alp", ",", "1", ",", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"\[CapitalNu]", "-", "1"}], ")"}], "2"]}], "}"}]}],
               "]"}]}], ";", 
            RowBox[{"(*", " ", 
             RowBox[{
             "note", " ", "that", " ", "mincurv", " ", "prevents", " ", 
              "wild", " ", "step", " ", "in", " ", "dir", " ", "of", " ", 
              "almost", " ", "zero", " ", "curvature"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Sqrt", "[", 
                RowBox[{"n25", ".", "n25"}], "]"}], ">", "maxnewt"}], ",", 
              RowBox[{"Print", "[", 
               RowBox[{
               "\"\<Warning!!!!!   Large Newton Step = \>\"", ",", " ", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"n25", ".", "n25"}], "]"}]}], "]"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"n25", "=", 
             RowBox[{
              RowBox[{"Transpose", "[", "evecs", "]"}], ".", "n25"}]}], ";", 
            " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "transform", " ", "back", " ", "into", " ", "original", " ", 
              "basis"}], " ", "*)"}], "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"phivec", "[", 
              RowBox[{"[", "im25", "]"}], "]"}], "=", 
             RowBox[{
              RowBox[{"phivec", "[", 
               RowBox[{"[", "im25", "]"}], "]"}], "+", "n25"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{"take", " ", "the", " ", "newton", " ", "step"}], " ", 
             "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"nonu", ",", "g36", ",", "h36"}], "}"}], "=", 
             RowBox[{"fgh", "[", "phivec", "]"}]}], ";", 
            RowBox[{"(*", " ", "evaluate", " ", "*)"}], "\[IndentingNewLine]",
             "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "figure", " ", "the", " ", "new", " ", "nullspace", " ", "as", 
              " ", "follows"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"g25", "=", 
             RowBox[{"g36", "[", 
              RowBox[{"[", "im25", "]"}], "]"}]}], ";", 
            RowBox[{"h25", "=", 
             RowBox[{"h36", "[", 
              RowBox[{"[", 
               RowBox[{"im25", ",", "im25"}], "]"}], "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "focus", " ", "on", " ", "unconstrained", " ", "phases"}], " ", 
             "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"evals", ",", "evecs"}], "}"}], "=", 
             RowBox[{"Eigensystem", "[", "h25", "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "get", " ", "the", " ", "curvatures", " ", "and", " ", 
              "principal", " ", "axes"}], " ", "*)"}], "\[IndentingNewLine]", 
            
            RowBox[{"evecs", "=", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"evecs", "[", 
                RowBox[{"[", 
                 RowBox[{"Ordering", "[", "evals", "]"}], "]"}], "]"}], ")"}],
               "[", 
              RowBox[{"[", 
               RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{"take", " ", "4", "D", " ", "nullspace"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"evecs", "=", 
             RowBox[{"Orthogonalize", "[", 
              RowBox[{"evecs", ",", 
               RowBox[{"Method", "\[Rule]", "GramSchmidt"}]}], "]"}]}], ";", 
            RowBox[{"(*", " ", 
             RowBox[{
             "make", " ", "sure", " ", "degenerate", " ", "dirs", " ", "are", 
              " ", "orthogonal"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"evals", "=", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Sort", "[", "evals", "]"}], ")"}], "[", 
              RowBox[{"[", 
               RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{"check", " ", "nullspace", " ", "curvatures", " ", 
              RowBox[{"(", 
               RowBox[{"should", " ", "all", " ", "be", " ", "zero"}], 
               ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Total", "[", 
                RowBox[{
                 RowBox[{"Abs", "[", "evals", "]"}], "/", "4"}], "]"}], ">", 
               "mincurv"}], ",", "\[IndentingNewLine]", 
              RowBox[{"Print", "[", 
               RowBox[{
               "\"\<Warning!!!!!   Nullspace Average Curvature = \>\"", ",", 
                RowBox[{"Total", "[", 
                 RowBox[{
                  RowBox[{"Abs", "[", "evals", "]"}], "/", "4"}], "]"}]}], 
               "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "project", " ", "the", " ", "four", " ", "directions", " ", 
              "into", " ", "the", " ", "new", " ", "nullspace", " ", "and", 
              " ", "normalize"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"evecs36", "=", 
             RowBox[{"Table", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "4", "}"}], ",", 
               RowBox[{"{", "36", "}"}]}], "]"}]}], ";", 
            RowBox[{
             RowBox[{"evecs36", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"1", ";;", "4"}], ",", "im25"}], "]"}], "]"}], "=", 
             "evecs"}], ";", " ", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"expand", " ", "into", " ", 
               SuperscriptBox["\[CapitalNu]", "2"]}], "-", 
              RowBox[{"element", " ", "longvecs"}]}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"dirvecs", "=", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Sum", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"evecs36", "[", 
                   RowBox[{"[", "jdx", "]"}], "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"evecs36", "[", 
                    RowBox[{"[", "jdx", "]"}], "]"}], ".", 
                    RowBox[{"dirvecs", "[", 
                    RowBox[{"[", "idx", "]"}], "]"}]}], ")"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"jdx", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"idx", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Do", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"dirvecs", "[", 
                RowBox[{"[", "idx", "]"}], "]"}], "=", 
               RowBox[{
                RowBox[{"dirvecs", "[", 
                 RowBox[{"[", "idx", "]"}], "]"}], "/", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{"dirvecs", "[", 
                   RowBox[{"[", "idx", "]"}], "]"}], ".", 
                  RowBox[{"dirvecs", "[", 
                   RowBox[{"[", "idx", "]"}], "]"}]}], "]"}]}]}], ",", 
              RowBox[{"{", 
               RowBox[{"idx", ",", "1", ",", "4"}], "}"}]}], "]"}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{"record", " ", "tracking", " ", "data"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"cntr", "=", 
             RowBox[{"cntr", "+", "1"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"track", "[", 
              RowBox[{"[", 
               RowBox[{"cntr", ",", "1"}], "]"}], "]"}], "=", 
             RowBox[{"track", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"cntr", "-", "1"}], ",", "1"}], "]"}], "]"}]}], ";", 
            RowBox[{
             RowBox[{"track", "[", 
              RowBox[{"[", 
               RowBox[{"cntr", ",", "1", ",", "dir"}], "]"}], "]"}], "=", 
             "th"}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"track", "[", 
              RowBox[{"[", 
               RowBox[{"cntr", ",", "2"}], "]"}], "]"}], "=", "nonu"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"track", "[", 
              RowBox[{"[", 
               RowBox[{"cntr", ",", "3"}], "]"}], "]"}], "=", "phivec"}], ";",
             "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"track", "[", 
              RowBox[{"[", 
               RowBox[{"cntr", ",", "4"}], "]"}], "]"}], "=", "dirvecs"}], 
            ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "here", " ", "is", " ", "a", " ", "line", " ", "of", " ", "code",
               " ", "to", " ", "print", " ", "out", " ", "some", " ", 
              "tracking", " ", "data", " ", "every", " ", "ten", " ", 
              "steps"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Mod", "[", 
                RowBox[{"cntr", ",", "10"}], "]"}], "\[Equal]", "0"}], ",", 
              RowBox[{"Print", "[", 
               RowBox[{"track", "[", 
                RowBox[{"[", 
                 RowBox[{"cntr", ",", 
                  RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"th", ",", 
             RowBox[{"dths", "[", 
              RowBox[{"[", "dir", "]"}], "]"}], ",", 
             RowBox[{"thetas", "[", 
              RowBox[{"[", "dir", "]"}], "]"}], ",", 
             RowBox[{"dths", "[", 
              RowBox[{"[", "dir", "]"}], "]"}]}], "}"}]}], "]"}], ";"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"dir", ",", "1", ",", "4"}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "nonu"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"return", " ", "the", " ", "final", " ", "nonunitarity"}], ",", 
      " ", 
      RowBox[{
      "which", " ", "should", " ", "be", " ", "negligible", " ", "if", " ", 
       "all", " ", "went", " ", "well"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.44397847466243*^9, 3.4439785330696507`*^9}, {
   3.4439785808936243`*^9, 3.4439786493818083`*^9}, {3.443978679959446*^9, 
   3.443978894427311*^9}, {3.443981861773973*^9, 3.443981982875094*^9}, {
   3.443982051102251*^9, 3.443982076299615*^9}, {3.445609551302203*^9, 
   3.445609586284556*^9}, {3.445610152925268*^9, 3.445610174612989*^9}, {
   3.4456109289427443`*^9, 3.445610992445195*^9}, {3.4456110566384487`*^9, 
   3.445611103194913*^9}, {3.445611266879797*^9, 3.445611269069333*^9}, {
   3.445611580094226*^9, 3.445611582381892*^9}, {3.445613292280311*^9, 
   3.445613294798534*^9}, {3.4456133557043123`*^9, 3.445613359758258*^9}, {
   3.445682154190898*^9, 3.445682198725382*^9}, {3.445682260230731*^9, 
   3.445682452919689*^9}, {3.445682507431378*^9, 3.4456825126771517`*^9}, {
   3.445682584536837*^9, 3.445682746248857*^9}, {3.445682803330389*^9, 
   3.445682836089254*^9}, {3.4456828755520887`*^9, 3.445683363445442*^9}, {
   3.4456834246059427`*^9, 3.445683429839109*^9}, {3.445683470651684*^9, 
   3.445683633968316*^9}, {3.445683857332761*^9, 3.445683964205948*^9}, {
   3.445684007607283*^9, 3.445684055930941*^9}, {3.445684109384777*^9, 
   3.445684184866364*^9}, {3.44568427354687*^9, 3.445684396499238*^9}, {
   3.445684498750257*^9, 3.445684523302094*^9}, {3.44568456953468*^9, 
   3.445684570170062*^9}, {3.44568464514797*^9, 3.4456846618432817`*^9}, {
   3.4456850449359903`*^9, 3.445685076238378*^9}, {3.44568519048589*^9, 
   3.445685372449387*^9}, {3.445685524487856*^9, 3.4456855362657967`*^9}, {
   3.445685714498508*^9, 3.445685781906548*^9}, {3.445686066213771*^9, 
   3.445686068621152*^9}, {3.4456861833179293`*^9, 3.445686201181368*^9}, {
   3.445686282439378*^9, 3.4456862828854027`*^9}, {3.4456863382957783`*^9, 
   3.445686389390545*^9}, {3.445686668960887*^9, 3.445686669270443*^9}, {
   3.445686743494521*^9, 3.4456868867382383`*^9}, {3.445687090443637*^9, 
   3.445687095684092*^9}, {3.445687197857039*^9, 3.445687279890592*^9}, {
   3.445687478360902*^9, 3.445687753411076*^9}, {3.445687785091235*^9, 
   3.445687826353414*^9}, {3.445687890606258*^9, 3.445687891564485*^9}, {
   3.445688737005385*^9, 3.445688759485992*^9}, {3.4456887980009203`*^9, 
   3.445688836473773*^9}, {3.4456890268592567`*^9, 3.4456890270498962`*^9}, {
   3.4456891300691433`*^9, 3.44568913077135*^9}, {3.44568922069203*^9, 
   3.445689222203046*^9}, {3.4456892531400347`*^9, 3.445689270371354*^9}, {
   3.44568938133176*^9, 3.4456894745379753`*^9}, {3.445689712622999*^9, 
   3.44568971296719*^9}, {3.4456909101625233`*^9, 3.4456909189342537`*^9}, {
   3.4456909988793163`*^9, 3.445691069421878*^9}, {3.4456911160133753`*^9, 
   3.445691117202779*^9}, {3.445691149096586*^9, 3.445691149411625*^9}, {
   3.445691586439917*^9, 3.445691590153235*^9}, 3.445691636932032*^9, {
   3.445691707091138*^9, 3.445691809174543*^9}, {3.4456919729269114`*^9, 
   3.445692013621861*^9}, {3.445693050489416*^9, 3.445693082920011*^9}, {
   3.4456956473737097`*^9, 3.445695654291246*^9}, {3.445696770093782*^9, 
   3.445696773212411*^9}, {3.44569682287472*^9, 3.4456968343103724`*^9}, {
   3.4456969198499317`*^9, 3.445696921991786*^9}, {3.445697529687755*^9, 
   3.445697529879054*^9}, 3.445697561767507*^9, {3.445697654987384*^9, 
   3.4456976879552593`*^9}, {3.445698063566598*^9, 3.445698101084876*^9}, 
   3.445698214411598*^9, {3.445698267300433*^9, 3.445698275762927*^9}, 
   3.4456984408820953`*^9, {3.4456984953201303`*^9, 3.445698501075428*^9}, {
   3.445767443233199*^9, 3.445767608554834*^9}, {3.445767660809718*^9, 
   3.445767687855274*^9}, {3.445767780941854*^9, 3.4457679280108852`*^9}, {
   3.445768032097084*^9, 3.445768056858473*^9}, {3.4457680997769117`*^9, 
   3.445768432363915*^9}, {3.445768463010036*^9, 3.445768545284863*^9}, {
   3.44576867851466*^9, 3.4457687733420362`*^9}, {3.445768810189897*^9, 
   3.445768841805377*^9}, {3.4457691777759457`*^9, 3.445769207486425*^9}, {
   3.4457692593137693`*^9, 3.445769264841064*^9}, {3.445769307882164*^9, 
   3.4457693161760187`*^9}, {3.445769404414318*^9, 3.445769425302309*^9}, {
   3.445769566986274*^9, 3.445769570975*^9}, {3.445769671600239*^9, 
   3.445769710686495*^9}, {3.445769816518631*^9, 3.445769816950109*^9}, {
   3.445769955224265*^9, 3.445769964661742*^9}, {3.4457700834300623`*^9, 
   3.445770087517915*^9}, {3.4457701685216637`*^9, 3.445770171206786*^9}, {
   3.4457702194562387`*^9, 3.4457702198300447`*^9}, {3.445770621635847*^9, 
   3.445770632355164*^9}, {3.445770751587171*^9, 3.445770764830453*^9}, {
   3.445770806927815*^9, 3.445770948294265*^9}, {3.445771396529657*^9, 
   3.4457714849640427`*^9}, {3.4457715195259857`*^9, 
   3.4457715446689787`*^9}, {3.445771973766715*^9, 3.4457719750709953`*^9}, {
   3.445772022137442*^9, 3.445772024151387*^9}, {3.44577208403207*^9, 
   3.445772096224684*^9}, {3.445772144000049*^9, 3.445772159464204*^9}, {
   3.4457730745055933`*^9, 3.4457730749349833`*^9}, {3.445773534082226*^9, 
   3.445773590983365*^9}, {3.4457736601832867`*^9, 3.4457736606428413`*^9}, {
   3.4457821156763153`*^9, 3.445782117970883*^9}, {3.445782763411227*^9, 
   3.445782765342449*^9}, {3.445785163179636*^9, 3.445785164770303*^9}, {
   3.44578602662236*^9, 3.44578602987764*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"here", " ", "is", " ", "an", " ", "example"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"F6Foray", "[", 
   RowBox[{"{", 
    RowBox[{"1.31", ",", 
     RowBox[{"-", "2.33"}], ",", 
     RowBox[{"-", "1.101"}], ",", "2.17"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.445697697611733*^9, 3.4456977075674133`*^9}, {
  3.4457698296074677`*^9, 3.445769832742391*^9}, {3.4457699062355957`*^9, 
  3.445769909084646*^9}, {3.44576997273066*^9, 3.4457700009985313`*^9}, {
  3.445770645607188*^9, 3.445770648510847*^9}, {3.445772170817257*^9, 
  3.445772176759118*^9}, {3.44577280552177*^9, 3.4457728109432573`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.09`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   "7.771561172376096`*^-16"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786138321971*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.19`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   "5.218048215738236`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786139057027*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.29000000000000004`", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"-", "6.217248937900877`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786139791111*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.39`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "9.547918011776346`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861405295258`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.49`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "1.4765966227514582`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786141267048*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.59`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "1.4432899320127035`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786142004636*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.6900000000000001`", ",", "0", ",", "0", ",", "0"}], "}"}], ",",
    
   RowBox[{"-", "1.9872992140790302`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786142742331*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.79`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "6.661338147750939`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861434783278`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.89`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "3.3639757646142243`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786144214334*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.99`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "5.773159728050814`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786144950431*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.09`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "6.661338147750939`*^-16"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786145685315*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.19`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "9.658940314238862`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786146419737*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.29`", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   "1.1102230246251565`*^-16"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786147153015*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.08`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "1.3877787807814457`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786147887644*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.18000000000000002`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "8.326672684688674`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861486234827`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.28`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "3.552713678800501`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786149358769*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.38`"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "5.218048215738236`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861500916967`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.48000000000000004`"}], ",", "0", ",", "0"}], "}"}], ",", 
   
   RowBox[{"-", "8.548717289613705`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861508265944`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.5800000000000001`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "1.1102230246251565`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786151559578*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.68`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "1.3655743202889425`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861522935553`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.78`"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "7.993605777301127`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861530247993`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.88`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "1.8984813721090177`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861537582483`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "0.98`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "7.993605777301127`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786154491398*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.08`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "1.7985612998927536`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786155224846*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.18`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "2.2870594307278225`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786155957445*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.28`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "7.882583474838611`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786156693084*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.3800000000000001`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "2.5646151868841116`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786157426433*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.48`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "9.547918011776346`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786158160606*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.58`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "2.2315482794965646`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786158894785*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.68`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "1.2323475573339238`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786159624704*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.78`"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "3.9968028886505635`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.44578616035541*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.8800000000000001`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "1.3211653993039363`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861610870447`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "1.98`"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"-", "6.994405055138486`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861618173532`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.0799999999999996`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "2.0650148258027912`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786162547984*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.1799999999999997`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "2.631228568361621`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786163276388*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.28`"}], ",", "0", ",", "0"}], "}"}], ",", 
   "6.994405055138486`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786164006722*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.050045454545454546`"}], ",", "0"}], "}"}], ",", 
   "3.097522238704187`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861647376003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.15013636363636362`"}], ",", "0"}], "}"}], ",", 
   "3.7192471324942744`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786165468824*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.2502272727272727`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"-", "9.547918011776346`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786166201228*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.3503181818181818`"}], ",", "0"}], "}"}], ",", 
   "7.105427357601002`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786166933547*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.45040909090909087`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"-", "2.2426505097428162`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786167664748*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.5504999999999999`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"-", "1.1102230246251565`*^-16"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786168396161*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.650590909090909`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"-", "5.995204332975845`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861691284237`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.7506818181818181`"}], ",", "0"}], "}"}], ",", 
   "1.63202784619898`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861698596077`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.8507727272727271`"}], ",", "0"}], "}"}], ",", 
   "1.687538997430238`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786170591261*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "0.9508636363636362`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"-", "3.630429290524262`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861713241787`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.0509545454545453`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"-", "3.6415315207705135`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861720546103`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.05`"}], "}"}], ",", 
   "1.887379141862766`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861727847643`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.15000000000000002`"}], "}"}], ",", 
   "1.6986412276764895`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861735142307`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.25`"}], "}"}], ",", 
   "4.007905118896815`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786174244445*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.35000000000000003`"}], "}"}], ",", 
   "1.1213252548714081`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786174975078*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.45`"}], "}"}], ",", 
   "3.019806626980426`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786175704605*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.55`"}], "}"}], ",", 
   "3.6193270602780103`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786176433878*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.65`"}], "}"}], ",", 
   "1.7985612998927536`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861771605167`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.75`"}], "}"}], ",", 
   RowBox[{"-", "2.55351295663786`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861778890676`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.85`"}], "}"}], ",", 
   "6.217248937900877`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861786170397`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "0.9500000000000001`"}], "}"}], ",", 
   "2.3092638912203256`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786179344759*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.05`"}], "}"}], ",", 
   RowBox[{"-", "1.4099832412739488`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786180072155*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.1500000000000001`"}], "}"}], ",", 
   "3.552713678800501`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861807995577`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.25`"}], "}"}], ",", 
   RowBox[{"-", "1.8096635301390052`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786181525793*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.35`"}], "}"}], ",", 
   RowBox[{"-", "2.4202861936828413`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861822531767`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.45`"}], "}"}], ",", 
   "4.496403249731884`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786182979114*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.55`"}], "}"}], ",", 
   RowBox[{"-", "6.994405055138486`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861837066193`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.6500000000000001`"}], "}"}], ",", 
   "1.4210854715202004`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.4457861844346733`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.75`"}], "}"}], ",", 
   RowBox[{"-", "1.9872992140790302`*^-14"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786185160939*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.85`"}], "}"}], ",", 
   RowBox[{"-", "5.773159728050814`*^-15"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786185885961*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "1.95`"}], "}"}], ",", 
   RowBox[{"-", "3.3306690738754696`*^-16"}]}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786186609913*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "2.05`"}], "}"}], ",", 
   "2.1094237467877974`*^-15"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786187335129*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.31`", ",", 
     RowBox[{"-", "2.3299999999999996`"}], ",", 
     RowBox[{"-", "1.101`"}], ",", "2.15`"}], "}"}], ",", 
   "1.4099832412739488`*^-14"}], "}"}]], "Print",
 CellChangeTimes->{3.44578287934031*^9, 3.4457839084617777`*^9, 
  3.445785220821898*^9, 3.445786188060699*^9}]
}, Open  ]],

Cell[BoxData["3.6637359812630166`*^-15"], "Output",
 CellChangeTimes->{
  3.445772293460206*^9, {3.445772800670322*^9, 3.4457728200862837`*^9}, 
   3.445773047434713*^9, 3.445773086579808*^9, 3.4457731974264593`*^9, 
   3.4457732335061407`*^9, 3.4457732788316097`*^9, 3.4457734309251328`*^9, 
   3.445773616995306*^9, 3.445773733451853*^9, 3.445774101082116*^9, 
   3.4457789478193073`*^9, 3.4457823049046383`*^9, 3.4457828842352333`*^9, 
   3.445783913523501*^9, 3.445785271586919*^9, 3.4457861882080584`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "here", " ", "are", " ", "plots", " ", "of", " ", "the", " ", "phase", " ",
     "shifts", " ", "and", " ", "nonunitarity", " ", "during", " ", "the", 
    " ", "foray"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"deltaphivecs", "=", 
     RowBox[{
      RowBox[{"track", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"1", ";;", "cntr"}], ",", "3"}], "]"}], "]"}], "-", 
      RowBox[{"Table", "[", 
       RowBox[{"fourier", ",", 
        RowBox[{"{", "cntr", "}"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", "deltaphivecs", "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"track", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "cntr"}], ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4456921980022783`*^9, 3.4456922101027393`*^9}, {
  3.4456928642678747`*^9, 3.44569288943388*^9}, {3.4456930256756487`*^9, 
  3.445693034281432*^9}, {3.445694986523542*^9, 3.445694987594427*^9}, {
  3.445696037556563*^9, 3.445696049028903*^9}, {3.445696250050762*^9, 
  3.4456962545461597`*^9}, {3.445696351021223*^9, 3.44569635350576*^9}, {
  3.4456985429361763`*^9, 3.445698546273808*^9}, {3.4457710487370663`*^9, 
  3.4457710671766243`*^9}, {3.44577159389814*^9, 3.445771619120718*^9}, {
  3.445772839659107*^9, 3.445772861713344*^9}, {3.445773103026081*^9, 
  3.445773104031625*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.8503398874989481, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.08640786499873876, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.3224758424985268, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2nt4DNf/B/CpaqWa9LstJa5dt0pRFiFB8FZBQrBBSEhYkhAksnKRTbJJ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     "]]}, 
   {Hue[0.5585438199983166, 0.6, 0.6], PointBox[CompressedData["
1:eJxd13tcTWkXB/BHqDB0REQx2z3lctxzf9xTwxxMpHHZcsv9GFG6bl0Ues1x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     "]]}, 
   {Hue[0.7946117974981064, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2nl8DOcfB/DRKNs6uiVIKV1HK9Sx6oiifDToJq6NcxFMHPmFOjaIbO7J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     "]]}, 
   {Hue[0.030679774997896203`, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2Hl8TOcaB/AXUTujqEQjBqGpRIw9XMtLgtQ6iUZiq3OLJimRkbqWyHKI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     "]]}, 
   {Hue[0.266747752497686, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2nl8TNceAPBLLVE88yoIrbr2oGVKEMvjZw+KiSSSENwQxD7WzGS9k8kQ
1TBEJVHLtUctHQQpJbfWWDNENPZri1CPsVUs5R3T33mfzs8ffL5+9yy/c8+Z
O+fcaThm+tBx5QVByGF/ffz37z+u7oLnHxBS//I9nWvE//cC4fuPltE6EIbG
H9TXWoD2xrgd7QPCk67P/ypZhv4Cr89CiyDsOTB/bK9V6EZYXkE3Afk/9Rfd
LViHbob1bUD7gqxEhNV5vwndEuvfgv4K5E9WNhrw1VZ0a2xvO1oP8virj+KH
/4z+Btt3oNuCGpV2NfToTnQ77M8utB9A7e0w4+pudHvsXw66A6gnzmz87tke
dEfs7160P4D50acbquSiO2H/f0F3BrVlNeNBcT+6C+ZzAN0V4Fqroksdf0X/
B8Cd30F0NxAWDezsGnwI3R1Ud755aAB1zZ6CCu3Uvy0DiO780UIPkE19kpd0
+w3jPUBzjwda6AkQWOT35YDDGO8Jint80EIvEFqOu/9TyBGM9wLZPV5ooTdo
5V9mdYw8ivHeAO7xQwt9QLma8u3RKccw3geE/I/jiRb6gpTj/cFgOo7xvqC6
xxct9AMxbcPO69YTGO8Hsnu88zEeANo4v6hJi9FyAEju8T+J8f6gdjta+9UK
tNwfxFYf78cpjA8AuU7wSesmtDwANPf9OY3xgQCuO3G6XWh5ICju+3UG49+C
cHJW61UH0fK3ILnv31mMDwJt7Se3WpxEy4MA3PfzHMYHgxKbnr73IloeDMKE
j/e3AONDQApq3LeXhpaHgOa+306MG0C3PPzd/TloMAC47z9aNoAxeW3Ijrdo
1QCKez6cx/KB4Jz2YMdsCxoCQRj3cX6g5UCAEd94dal8AcsHgtE9X9DCUFD6
mSPLpaFhKDjd8wctDwXB77f9Jz4rxPJDQe+eT2ghCCSxiveiTDQEgeKeX2g5
CNRqgVODv7yI5YPA5Z5vaCEYxNeZx+ttQEMwSO75h5aDQb6nNbjVogjLB4Pq
no9oIQRc533Nm39GQwiI7vmJlkNAOmS8MLX9JSwfAnb3fEULw0D9KbeV3wE0
DAOXe/6i5WEgZgi2N/A7lh8GBvd8RguhIFsDbqjH0RAKDvf8LsbyoaBNt3ec
/y1aDQXd+I/zHS2EAUQU2wddQEMYGN3z/zKWDwMlQHxYMwythoHTvR7QQjgI
7aN7XbmOhnDQu9fHFSwfDlJDx0plLFoNB8W9XtDCcHBWL3s5/gEahoNQ4eP6
uYrlhwO86T7k6+lodThI7vWEFkaAvWR+9vMXaBgBqnt9XcPyI8B1oaDc/li0
OgJE93pDCxFgyKszQhauY/kIsLvXH1qOAMfW0Tl956HVCHC51yNaGAm6zM3V
q1e7geVHgsG9PtHySJBTnowvXIJWR4LDvV7RwijQjB3VrDo3sfwo0LnXL1oe
BTAyqa60Cq2OAqN7PaOF0eDcMLZT+r81LD8aSt3rGy2PBuHHyuPnBqPV0eDj
Xu9oQQL9kq1LwzPQogQG9/rn9UkQPX9IXtcraEkC2f15wOuXIDPh+R8N6t/6
2wqxSqwRC5GeFokhEpR/WiJxmcQVYpVYIxbGeFokBmKJWCZWiFVijVgYS9on
BmKJWCZWiFVijViIIu1HQbZH+8QSsUzKKySuEmvEwjhPi8RALBHLxAqxSqwR
C+NJ+8RALI0Hh0f7xAqxSqwRCxM8LRIDsUQsEyvEKrFGLEST9omBWCKWiRVi
NRpyPdonFiZ6WiQGYolYJlaIVWJtIqge7U/ytEgMxBKxTKwQq8TaJMj3aH8y
aZ8YiKXJnuVlYoVYJdaIhSmeFomBWJoCTo/2iRVilVgjFqZ6WiQGYolYJlaI
1alQ7NE+iQvTSPvEQCwRy9M861dIXCVxjViY7mmRGIglYplYmQ6aR/vEGrFg
9LSOWCTWEwOxgVgyQuk/bSSWie3ECrGDWCV2EmvELmJhhqd1M8DlkT+xnhiI
DcQSsZFYJrbPgDKP/EncQayS653EGrneReLCTE/riEViPTHMBCHxn/kTS8RG
YpnYPhO8/mmFxB3EKrneSawRu4iFWZ7WEYvEemKYBTqP/ElcIjaS62ViO7FC
7CBWiZ2zwMcjfxJ3kbgw29M6YpFYTwzEBmKJ2EgsE9uJFWIHsTobRI/8SVwj
cRexMIfkP8czLhLriYHYQCwRG4llYjuxMgd8PfIncZXEnSSukbiLWJjraR2x
SKwnBmIDsURsJJaJ7cQKsYNYJXYSa3Oh+GzhuI7VeP7MTVZ8G8z3r0IM+Ezt
tH7uQ7QuBvRrc6esvsz3wzFgT2+77XQ+Wh8DwoOiqPf7+P6YXa+7l9VhM9oQ
A77t9w6evZzvl2NA+mb3vH02tDEGUk3hfQS+/5ZZvFznRYOj0PYY8G/1Ompd
EFqJgeI1g8++7Yl2xIBX24qnh7fl+3lWPvdNZF5DtDMGSu82WN6CnwdozD6m
yVkC2hUDMLntmfr/Pz8wARQO8/bOQ+tMILw8v6/WarRoAl2drnmNEtB6E+gP
G9p1ieDnFSaQezz+YnQXtMEEji9q2RbVQ0smsC+8P/vkazzvMJpAu5P9ssZl
fj5iYvkf1I3JRdtZfZs3F+RloBVW3/WqXVvEoB3s+r5bR68exs9TTCAax/Vu
0AHtNIGrYccXW2uhNdbfdZ3MvV/ieY2L1V+29nrpRX5+YwZ7K7VVVg5aZwbZ
/H5qyDK0aAb4XttRfzZabwbHlvKvnwbx8yIzGG/6hF5ohzaYQWz1uPBQTbRk
BufqsbH7nuN5k9EMimV6yK+F/HzKDIapXxjP7kbbzaBGpxY9TEcrZtB/uGP3
no12sP6EzNg+IJifZ7H2O1s7pPmhnWaQOsV3vOaN1sygbTh7oONLPB9zsfo2
/HluTRE/P4sFRxdrvPdetC4WdMOqOn9YjhZjwXjqm6LGMWh9LMCY9RmHQvl5
WywYrtdqPN4fbYgF8c++1np10RKLR709cvU1nu8ZY0G5+ZdryxV+PhgLQqMv
a9sOoO2x4HzQpvvUlWiFtf+uimlMAtrB6vO1nYkaxc8TY0EOiAuY3R3tZPn0
O/7Kzs8fNdafpt1L9pdDu1j89a8Nnt3m55dxAO9rOjocReviQEr3Xp+6ES3G
gX3AdxVK56H1zK7OWnA0P++MA3HFvR4F/dGGOFB39mgf2gotxYHO6/2xR9XQ
RnZ9Sd6HxY/5+WwcOBo2egxOtD0ODH45Kz/sRCtxIAe/rn0mHe1g9S+ZEL1p
Dj/PjQPh+fiVi0LRTtb/TMOhlE5ojcVvTr2c+jnaFQfO1FdlK/7i58fxoJZ4
+x64idbFg6HS1RkPfkOL8SDfHnir6Qa0Ph60jBCLcR4/b2bXrzwfcTIabYgH
52tron4gWooHMa3e041fo43xoA/4Kq+FDi2z+mP8nx94hufd9nhwVd2UEVGE
Vlj/7h/eWzUX7WDttzky/OQKfp4eD5Kipv2QgHYy3/sl3CihtXgwvlqSH94L
7WL1x9W4G9iMn78ngKPFtT1hVdC6BHDqU/pNe4Tn92IC6DfPWbe0AK1PAKns
Q8GxXfy8PwG08KDLlZejDQlg6CWfCDOjJRZ/MHd9bgTamAAutdLc5sDfDySA
/a/r/TY2RttZe18uaNi2Mlph8bkzq557iO8jHKz9vFvVzef4+4wEUDdcd31+
Be1k7ce97Zl7D62x+LY7wuCnaBdrv565+fV3/P1HIkglxbvHeWF7ukTQRw9f
f78mzz8RBN/Fz8c04Pkzn+257veWPP9EMH4at71PB55/IojzY2pu78HzTwSH
uvNC9UE8/0S2vq89mBDG808E9ci90ANjef6JYJj17HOv6Tz/RHAZxrQfHIt2
MO8+uz7Nxt/HJIL9l4oTjtvRTla+kndS2Y9oLRE0a+dHjTejXSxe9/mOAH7/
hCRQRz05Mf4gzz8JxEE+/on5PP8kMJSmCYsLef7M9zY1yrrB82flB7rWrHzA
808C+bOvY7Ne8PyTwJgbsnvxB55/EuiLMwYlfcrf7ySBfV/IwOhafP6z9gub
/jxA5POf1R91Ia5ZKz7/WX0lYTlv//8+KQkc9gcjTgGf/+z6iyVzlg7k8z8J
pMK7FYOH8fnPyp/LrlEjks9/GdQM34wjk9FeMshvFygz5vL1IIPQvJG+rgXt
I4Oj6pwB+xeiRRm0Q34vgpejfWXQF0HbBwpaL4PrwMYqMVvR/jJI1Vcmvd/D
33fJYLwzPytJRQfIAM3KIt6cQhtY/b9vLJjGPw/CZDCMnPXq2k20xHx08pXe
D9HRrL1KhxM3vUAbmQc6H5b7gDax+prUaRpahX/+sPxOdfXbVBOdKoMSVK3B
k/poO+vv09mPvvFFZ7L8GixYP60tWmHjUZwwcGNXdDYbv1Nb/ijqi3bIoEtO
WSgEonNZf3/c2LbpCP4+Twb7f4+U9hqHzmf3Y2/OnojpaKcM4rFJa6eb0cWs
P8rL3fH8/Z/Gxm+n/NKahi5l9U8cOs2WgXax+ITTzSxr0WUsvmZc85it/PPf
AoaE3aYJe9BeFlCrjm48NI8/Dyzs+18LfceTaB8LuAJLN9cu5M8HCzjNqemu
a2hfdn1clXdHS/jzwgLSD4kP011ofwtocvXokW/484Ndn/7fhIYV8PkUYAHH
3fHttepoAytvOp+RVQcdZgFj5LIdgxqiJQvYHzWxvmuJjrYA5FdssMkPbbSA
3Ob4wgHd0CbWX+9yhQ/68eevBfRDIt5bA9GprL4T8+vUHcGfxyy+pavvlih0
Juvv0q6d/abx5zNr77ghdH8MOpvFo/ov6GLhz2s2niveXd73HTqXjd/tPkFt
lvHntwWEThU/rF2FzreAEv7l/Rqb+fOc9V8w1TI70MUs3uJt+vVf+POdtR+8
dMp/jqBL2fic9N2SeYY/79n9vbMl6EkRuoy1HybM7XGTv/9NBnFhrXqLS9Fe
yezzw9m/+ClalwzCjdo16r9F+ySz9ZA/a2QF/v0oGVzBRy1Z1dG+yQAbb/U8
X5t/X2Ll/V6oFUS0fzLoJ56s6NeCf39KBmdz389Ht0UHsPb9nJ/O68K/TyWD
bp35RnZvdBhrr8vFNScG8e9XrL4388JuD0NHJ4M2q81nr0fz71usvmGRl6pO
RJuSwX5r4456M/n7bVZ+TNyGpnHoVNb/vcG/fZWCtieDoyDzX/o0dCbLv+u6
H9osRyusPceh0a3WoLOZl7ee2zgb7UgGZXWT23V2onNZ/4OObfPaz9+nf2yv
2c2Xh9H5yWC4OCT55mm0k43PJP81xy6ii1k+8/K7ZfP37RrrX8viifNL0KUs
v1etW4x9gnax9outti5l6DJWflf8fB3/PixYQa29o+PtKmgvK0ivVqx2fIbW
WcERmXM07nO0D3On8F29mqBFK+hfF033+hrtawVxZlTFU+3ReivolrWKS+2G
9mfl/bpf7tWPv+9n119d0/zdEHSAFZyLOk/bGYY2WMGYXZozNhIdZgVt0/RP
ak5CS6z+SpbIvJnoaCt7vu+/FB3H9xusf6XrJ9VIQZtY/F+7m+z+nu8/WH9W
9asW/AM6lfWnwnbfZ6v4foTFn9W1pPHfK2Sy8gGOL5r9zPcnbPzex5f/dR86
2wquuqZOQ1S+X7ECrEjJv5mPzrWCbDTunXqe719YPrNfVHl9GZ3P2pdyTlpu
8/0Mq/94t3eV/0AXW0GpXT174XO+v2HXZ1gLq71Dl7LxmvQ0ZWEFvt9j7S+1
H65cHV3G+v/SttRSi+//UsAx4dabsvporxTQclaVm9aM7wdTQNqqbNNao33Y
9S0PlAvsyPeHKaC23VIprzvaNwX0L//9W8sAvl9kLp3fYZkB7Z8CcDV1ytsw
vn9MAWP1xGgpEh3A6uv9a5sjE/l+kvXnvvVE45noMHa9T7n2ybF8f8lcMDDh
RjI6OgXkNxM2+i9EG1NAWdFnlz0dbWL53FWzS37kvy9JAZe0Lq3zBnRqCth1
a8Z9vw1tZ/1fFNb+Wg46k13fbmS5lgfRCusv+J6bcwydnQLCh4ZK3lm0g5V/
tCau8iV0LvOtu1GDbvDfs6SAs0tDaUkJOp/V5zVrRuFjtJP1p3XJypqv0MUs
36zZJYEf0BrLZ0KloYsq436/NAUMtWbeya+BdrH6tsWvLueDLmP37+nlef4i
//2LDVxLvlKm+qK9bKAFVXqs6NE6G+j7ls664I/2sYHs6tm+fA+0aAODdW57
fX+0rw2kKoUxEYFovQ0cmZkf5oWj/W0AKa8Kfo5Egw2cabpHlyaiA5jrvBz2
bgbawPoTurmmyH+/E2YDcUG9pj2T0ZIN1C/bLRrzHTqa5fPn8UDLUn7ewvqT
tmrm6hVokw2MrY3Pf1nHz19sILR8eKnwJ3Qqq7/SlgaPdvHzGBvYd3V1lj+A
zrSB7kDzP+oc4eczNlBib85sdfpa9/8B4SsqEQ==
     "]]}, 
   {Hue[0.5028157299974758, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.7388837074972656, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2HdcFNcWB/CxBJFYCDbis6zGKImoa8MSoj8REbGhYkddEZDOsvS2zDZF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     "]]}, 
   {Hue[0.9749516849970554, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2HdcVGfWB/Cr6yoaNWNLyNqu5fUFxWSswWj0GNSwSHRiJQbMVRRRg44F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     "]]}, 
   {Hue[0.21101966249684523`, 0.6, 0.6], PointBox[CompressedData["
1:eJxV2XlcTfn/B/CLYZItCjGWaxhFlr6pbKnX2MpaqNyU3Pa9bvte5y5ZstUw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     "]]}, 
   {Hue[0.44708763999663503`, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2Hl4TPcaB/BTlFDL3AqipcbatLWMImKL1x77kIiIVI8tIpFkYk1ikvxm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     "]]}, 
   {Hue[0.6831556174964248, 0.6, 0.6], PointBox[CompressedData["
1:eJxd13l8DOcfB/BxtFKCOOpqsJSIOyUIgo+gVBxBpHGviFwi2Ww2yeaevSrU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     "]]}, 
   {Hue[0.9192235949962146, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.15529157249600445`, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2Ht0TPf2APBD08qv1RpVRFCnhCpVo96q145Xol7jdUUkDEEi1Rgh8k5O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     "]]}, 
   {Hue[0.39135954999579425`, 0.6, 0.6], PointBox[CompressedData["
1:eJxV2Hlczen7P/ATypLl2BI1OZYsqUQh9KmXLFlKhTZSp017nfa93meJJE0y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     "]]}, 
   {Hue[0.6274275274955841, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2ntUVNUeB/CjaCAGToKKmnryknJLbSRNLM1fqIQJl9F8oJgcFRWEdFSy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     "]]}, 
   {Hue[0.8634955049953739, 0.6, 0.6], PointBox[CompressedData["
1:eJxV1nlUTV/YB/BrSpJkznwrv0QhhCT1RSpz80TcSvN0m+c6d4j0I5l+MsRV
KGODWeiWEKFSNCAlQ6VIRAhv77rPedd6/cH6rH32efZ3P3ufS9UlwNKtL4fD
udj71//+K/vTYcT5/3/gvcE6ImRHuoGM8riIrsm2P7aSldHR9cK3z+kL5JGQ
r4+Qf6AkvCGzCiRtbb/FHx1pfAIepJjNr56dS+birtWeO1ZJZ8hqcKyvb331
uJA8Ba+yt5xWkbtE1kDPEZXFRedukjUx8495aU/SPfJ0LCjgJfJQQdbGzlX7
1nnvu02eCeHUmIdz66+TdaC9bNzWy3kPyLOh9kRv0xzzfPIcfBzX8247v4Q8
F181iurvdZ0n62JS8CfJxN13yPNQkb7N6d5cdj3zoeixY93vZ6wXoL9P175a
i2NkPYzMCpM7ePUReSEun01N6pfOvk8f7VsDj5W4l5MXocHXd5dI9S7ZAI59
n/qHi8rIi6GW9DFyrRe7XkPMetUpHjDkGtkI+w6uVJ7YxM4Hzv5qVS68d19m
BpggufFtgVI2jS+BovOMaR8bttP4ErivMNGqKWbXsxT6uT2OAcfZ+Uvx5dX8
0gQ7dr+XIUDDislQYceXYXG0V+riZrafxvD2fvTTxJT2nzHGbv2Wquld7P4v
x/SL31+M0H5I48uxs+x7+yBzKY2b4FycYvXqa+x8E7Tl7J4S3FVE46aYWX7e
8H1NKY2botmzz0mN4+z5MsNGt7bW6in0PsYM6kbfDZyq2fWvQMH99cmdlcU0
vgKCjr15SznseVmJnOjAfq16t2h8JcRH+udP+8O+fxUqjM74lfal9TCrUNT4
n/6YzCs0vhpewXObPW9QPWY1RnrHHaxOZu/HGmTVXXnMixHT+Bp8/FXj1NV6
isbXwva0/ubMLDbfWmTxLD886thD4+vgynPxu1bJ7s86MB7xBrn8szRuDq3l
D79XuNN8mGPcsfiyHwo36Hlz5HmonEibRvmk5lhlonHL+QqZY4EDl5vr/rtQ
SfMt0H/bapWRn+h8MBawuJ6h9cmb3i+1QF6ppZZLPpvPEuVGI1VNrtF9hCVG
5xx6XhHGrtcSk5K95BeasPUt0Z43L23vOva8W2HbWMfLoiy6X7BCkdQ1wyOP
7g9jhfhfH0d8sKVxqRXm1G75mVLEnl9rKBXLTZuXRPcF1mho4QjUFglpfu/4
28GhJafo/EmtwfzD7Dd96EvzbaBb0f+sYgfdL9ggLOpzz8E5bL9toNLyQeNn
9D7Z91Bqg1dWyQMKs3fRfFscvt054tw4Ou+wRcjADoH/0wM03xZFyW6m+rp0
PqS2+DYjYHXGXvb828FETd4uzU9C8+3g61nH/aeIPa92MD1yrlj6h/ZDaoeH
Y8zi5h+h+8ixR9waqydPlC/K1gd7PNQ9s1A3gr2v9qhckHcvYDTlk9qjSvj7
yZnH9H6OA1ze9Bm6dDp9b+EAwz4TNgVpkxkHvB2dtFXa5zHNd0D5BacnX5tE
9PvgiL2fUk3aJrP9c8Qfm9vRm9KpH4wjSs6PGdenm/ZL6oiI/WNssnh0njjr
Ua4w2kmoQ79PWI/tiXKTHkSz5289br8Y3G9tPK1Xuh6uHYlPJ9ux69+ARVm/
p5hq0nnDBuhY1lzJlx6UrY/ZgCOOD/ZvSaTvlXQDyk9J5hrtSKT5Tij7unO2
1Sb6PYIT7uysM5htSvefcUKKw63iyo9p1H8nuBTM8Dsyj+4XZyMaY6xD6i5f
pvkboVe5M6vQ6SjN34iL41yywkypH9KNUJ5nLrwykL3fm9D+1yI5opDOGzah
4d3br2Ev6X4zm6B9f/6mzYVXaf4mHH5z5lGeJIPm86DRX3Ta+CDN5/IwPXl2
q0UlzQcPc75HGhoqXZOtn8dDcs26Wvk+9P1ieBCqu/w57JIps4SHu1XzVQfl
Uv+kPAQFVH4/EkPnp4GHnwOWpAod2d8nZ/gXZL56f5H6z3XG9Trr43qzqX9w
xmy5XbNcJpB5zig6VXfytvUzqu8MpechH2Zep3GJM7I2WHaJJTVU3xnvkq2f
8ZLo/jY4Y7/vs6ycs2x9F6jdPtS0pOwi1XfB1sSMoPkv6H7BBfX7PIclbaXz
wnNBatuK9KEnn1B9F8TyuwtnGNRSfRdIjQcOvsN+X6Qu0N2rvXe9/lOq74Ky
gYqDnRay/z9xRacGxyroXBXVd8XT1+munapsfleMScxK6zSl53muUOTejZWX
0POMK5piBx0u+0vvl7hi0ZjgdVe1yFJXuGZbp0ycSN/LBlcMq1uyflIxjXM2
45u/1vjfutVUfzPEOX3K4oxpf7EZNg4zdBx4VI+3GXrLD54SOLD3azPmLNVO
9Hv7kupvRnxESuOhj3VUfzOSRcNuhFmTGzajraN4e/026g/HDao/PmnpONE4
1w2eU7OzJnxh67thS22C8VK9BqrvBrmtiRfjFlE9xg3DW4uf3pLSfEnv88vs
LUtm0rjUDZmrN885vpbqNbjBulzzb1BpPdV3R07/oeU3T1D/uO5YfV7TdeZe
qgd3FEvbFbUWsPXd4bxhoIekkq3vjqAjbouFBjQuccfspiLevkay1B1On6sw
/WQj1XdH2y/1gtnnaJzjAfutNV8fqLyh+h4YWKw74fidJqrvgUtfXBV+fGHr
e2B8Y2Xx5O/0POOB+y4q7dKN9LzEAwpmWcEzLd5SfQ/czhQZrYt/TfU9ELbj
zSGzL2SOJ05m71XSl6fnuZ64vnrp75MONA5PGM9/f9orlczzhMDh5tXnn6ke
44nW4bs9br9k8/c+f7Ck9fUTGpd6wqz/X03dnbTfDZ5wK7UPKDzL1veCw9Cp
PK4Zm98LCtNmtOvzyPBCn6/5drpl9D6eF1S1GqeM2kXrZbyQJdqZ5l/F5vfC
sj3N3YYhbH4vJBz5OUz7ELnBCxo35tdGJrP77w21tc7jp/Y0U31v9Fn4feC/
y95TfW94jtA5rD+TzPNGrsMS26RgMuONaQ8RJiklS7xhWSXwKTN9R/W98TnK
Ir9iMuVp8IZ4P8zcG8kcH3zoWq+7Y3wb1ffBlSXm+qlNZPigam9BwYstZJ4P
elYceyD3hq3vg21BZ4qHbm6l+j74Xe6Z8dCJLPXBY/uvcZHBH6i+DwoZI4Ur
qmSOL+onCo9P29RB9X2R83LMZiWTT1TfF7V6YasMR9P7eL7od/7hZUazher7
Ql1JR3VIKlvfF1q3hwVKf9G41Bfhs62/Jvxop/q+eHA7tCSnhtbP8UM/vtKS
FKePVN8PhX2+3v47gtYHP2i3qndPOMjm90NR8Zy+TV/ofYwfdtus2OMwmepJ
/HBsYUvejEwal/qhvKG52laZ1tfgh4AYSbp6Mz3P8YdZpbH8OXUy1x8LxomP
HHFi6/tj2cLD8bc62fr+EM8tljeaSvvF+KO9NmHnVmMal/gjoyGg/KAyW98f
MQqWhzPC2Pr+6PlyJn7oO3qeE4C2tOp3wdk0zg3AogPCqPsn2PoBsFj1rEBy
ht3/ABgqjg83yKP5TADq5729E6fB1g9A7UmjC7mg/ZUGgJ9bsbRfJtv/AGzR
aV2cKaHzzuHjkPx9jykzaL3KfAzYqF+n1MCeRz5cS1+HFZvTuA4fzWuTsq7v
YM8HHwl+GfyCaHrenI/Zr8b/nPR/54WPdzc6A/wv0Xw+H8mHj+/WTaJxho/L
cQ9LPFNpPIUP3dL51qmNbD/52MPx3PjUiN6fw4elQUeXRSKdFykfF/OPzj+3
nMbL+TAQz9z6Zxitr6HXhTzzFYvp+Y7ePDlpL26x+8EJhG3ahrtdC2hcudeL
ky98rWDPQyBWbLtb+fI5mz8Q5XWWa3wMaf8QiOo7W6pXTaPzYB6IxreOSyYN
ovfxApHQmCl+cZfWxw9E0cgJ1ZXfaJwJxLVwlSzl/Wz+QBikFUzJf8r2MxDS
TdG2G33p/TmBmP+0zLrJkSwNxOGxVXOXLiWXB0JV48nlkvnkhkBMGfv4nkID
uSMQj0eIozdUU31OEGYa9uvZtpXqKQdhVcWjEu0Tnyl/EP56buwQldJ8nSA4
bWw5ftyb5iMIcy61fV3kSvtlHgRT5uRUTXU2fxCOhtZsvTGR5vODUBYtzTrF
5mGCcCXpwV5bA+pXShD6j7sYvM6W9kMSBGOFMuPhXbSenCCgVmWH/Qo2fxDG
7Nd2aV1D88uDcLxVfZLlRqrfEITs78Gl6x7Q+zqC0LXrzsh6Pj3PCUb4pdwB
Gy/S+5SDUf3u6SxV707KH4zlAw2rbR3Y/MEQF1THLOkmIxiTHF/mj9Nlz38w
rknM5XoUaJwXjKhd2+ptu2n9/GAYqGWocY+z+YPxctntZ8b55JRgeBbm101m
+ycJhnCYif/EEjZ/MMqXKCQ2C9n8wegfqIVBxl8ofzD2rZp6ZoKE7X8w5sys
7GlUpPGOYCR9GG324gubPwQzZ2f+0/CD3q8cgodap/nW/WicG4JHZ1Me5L5g
84eg7Fz6X+vhtD8IgcTSU3nlAJpvHoKpZ0c2ml1j84fASlDppPucnuf3Pv/v
QO8wbTZ/CK62Fcw/fYTNHwL71MLvJRvZ/CG4WFtlxdnE5g+B+5z/pk5NZu9/
CJpKn1SojWbvfwgUf3Q/iwtjf29652voDnl5je1/COSzFwnFWuz3NxQ8rwSV
w4/Z718ofOxb96x1o+8DNxR2+y4dNLNh84di15RMx/0zaT0Ixcw1wrPTT9N8
81AYcc4MPbGCzAuFWq3wRjqP9pMfio1jvY71GcDmD8VIlfZXc2+x5z8UZ8zl
bFLb2PMfiutFcfWuybSenFD8SdG2/MCeL2kofqvYpLuNYfOHItvgj2CRNvv9
C0WDfcyo8VE0vyMU8XxJXroVfX85YRjSHaYeYMzmDwPXN7t6WgeZGwa1z6rt
S4Lpe6cTBg157zzFQzQfYQg5cOmjuRybPwz98kYFDVWj+rww3O7pVG9dQf3i
h2HB80fqzkPY3+8wpG664TboXzZ/GEyS1ufwxtHzkjCMWJlmLRzO5g/D1++l
vv/+ZPOHYUZ5tqNhF5s/DJ3nx7Qsz2bvfxgsh48rGtNoViDLH4aYPKW8+np7
mTnhWLe652vsCReZlcMxxLrEL7jOU2ZuOJzfmDhaKAXIrBOOkZYKR7dLgmRG
OO75+hm7XwuV2TwcLRGPV16uiJCZF45gu/42sS3RMvPDYRH55mc+J15mJhxG
b8M2XxsskDklHEMDf06u+E8osyQcO755ep9QFcucE47Hg+Uj5p9NkFkajvC1
ZWHi+VtlLg+HRuWS5J3SRJkbwqHkZfbKbmUS5Q/HhQpF8cvKfyl/BPq9f7qT
67SD8keg9dIbJdV3yZQ/Aq/XThMFLEih/BFQX9C98NwvMiKwcfmIzPsFuyh/
BFaO/lBYLNpN+SMQ9GRi3BHTPZQ/ArPfepbaDt5L+SPALD60r/0xOSUC4ycn
Frvs3kf5I/A+6eeiyzb/Uf4IXFl46vl7lf2UPwK5Wlrx35+TyyOQVdX2+82R
VMofgez6f7RynA9Q/gjs3Vb21H7KQcofiSnHDpXUvyMrR2KUStv9JacOUf5I
vNQrPSTwOUz5IxEc+eZX2ow0yh8J+Q+xGf99Ipv3jq8IMvXJPUL5I7HypFbq
+OCjlD8SC53KJFbjJJQ/EtluGV1y0eSUSNwbP+xw5nOyJBLhD+1c5xkco/yR
cLgXqpJzmCyNxNikqVvG/CaXR+IK3of4OKVT/kjY7mw7feYmuSOy9/+H2m3V
EzMofxSWnHL8+SmWrByFxTbNe7+8JHOjwPyVi3y9+Djlj8LkJ1nON9LIiEK5
tXCg4DfZPAquRoqqOk4nKH8ULHYmuNy/QeZHYU9TV+zqCScpfxSiJ+qoX4sm
p0RBY9nTv0rPyZIoRJ2wK1ijn0n5o5Cy7I9C6AGyNApG/OZt4m5yeRT+XBjW
GG2XRfmjoNZmc8HxMrkjCsHpoce4o05R/mh0Hxu38lEwWTkaQwpfrOA9IXOj
8U+TyaJandOUPxqdM19cXrCTjGiURky0im4nm0djd33y8YxVZyh/NNp33Vyc
c4rMj0bKs+XZkoFnKX801DRqt4a4kVOicTzB2FrrNlkSDYu+4UeLuecofzT6
2iZ2GsWRpdFQuVBQdfg5uTwaJZcOltbpnaf80fgQVuX4Yx+5IxorC337d3eS
OTFI9cg2e7Yum/LHwPnKopN7zpK5MbAdIPdof/8cyh+DbVdvlVXNISMGe/K1
UjnOZPMYDO3j/XrcTjIvBj2SSi/1m2R+DB697Ncy9gOZiQF39vOxf1RyKX8M
kl1El8pMyJIYvDwRHJIcQs6JQVRhiJJ+OlkaA0/9E/pPysjlMZi5NTbb9je5
IQbWplVq96bnUf4YJMW/XqFuT+bEoqfWtNY7gawcC88WpYS0PDI3Flf8czn5
r8g6sZh5bMLfIsULlD8WJ8Iuzbm0kGwei3vtG9bscifzYtFoF8Kx20PmxyLg
WGPPACmZiYXg4IgvaW3klFi8Wyy3Z9LYi5Q/FqZfTbZvXU7OiUVYdfeOmkCy
NBbOA/zLm+xpfnksbvk61fUDrbchFoHScR/0ptJ+dMSiO5y7VKRE+8+Jw5EB
owzvfqDzoxwH44BpotzrdF65cQhPmlNZso3ug04cLqycdF7Rge4b4mDAHbY3
VpPut3kc+r1xGTChm743vDh8vHNI2HyPvmf8OAwUvFa5N4u+l0wcRk3ZYjq+
nL7XKXF4G6iz5zGffg8kvc93LvjTOIx+b3Li0LPdZ/Q5d/q9k8Zh+4K/Xy5a
x1L+OEz9d/QlvXwPyh8H1TNzV57fZGskyx+HY9cz7tQPDpeZE48nYw1TJxiJ
ZVaOx4lp2i7R37fLzI1HSIHohbh6t8w68bjjnfjg9Zz9MiMeE4N0w5/tOCSz
eTzE/B31G5uPysyLh/nlFXGLVdNl5sfjQHf6u5Frj8vMxGPIVmuNS1EnZU6J
x63JbvkTM7NklsRD4dhr9bWVp2XOiUeh65uXy/+elVkaD5PtOzz6a2XLXB6P
+Se3HjU+kyNzQzxUttt8bpHmUv54WHs4Ngc+y6P8DAK8Hix78eGCzPIMvBXf
Fmn2uUT7wSBB+dsUu9GXZVZhsD7UdpqH1hXaHwaZnn477XFVZk0GKjq5o7Vs
rtF+MYgYlBVX73VdZj0GBwa0bAmKy6f9Y/C6ZsKnd7tvyGzGoP/JP2GLMm/S
fjKIlW6oD8i/JbM9A3f3sW9FZQW0vwxiru07kR8oldmTQa54XfPxX2Q+A6vx
pQdjEwpljmAw6O6UtOVDi2j/Gby1F5f1pJITGUyKmDg8Q+029YNBXO2s5Xpn
yakMxggGrrgxr5j6w8D2Z8/vmQXkLAbHtocap5jdoX4x+Ne3qedVBfkqg4PN
dwZOWn+X+sfg6a5Ty1e+IZcwaORp7t/sd4/6yWBcdcsL32/kGgZK4zO+u8SX
UH8ZvBo2psRE/r7Mzb3rDRk9S2UXuYPBqMb4IdVjH8jc3bv/zUbGonQyR4Ao
FYuLE7RKqf8CaPa5YZhxgawsgK3e/uLRBg+p/wI8sBs4NbyYzBVg4g9D0+LV
j6j/Aiw5Fyf3p4qsI4DK55EmU5weU/8FCJy08f38t2QIMMixuHSeXxn1X4DU
2IIqbhfZXIDy+NbP0Ybl1H8BpB9W+TkJyTwBls6yfqR7l+wpgPaYur59FSqo
/wKM/XP9T/EacoQAVVfrcmN3kRkB+grUh2g/JSf2+lVCn3KVJ9R/AX7v6o73
2kBO7V1veERk91GyRIBOf/lXMU3kLAEmLcs99k2jkvrfu/5EQZ6bN/mqAO9E
O/o+OEeWCqAj/0mo/plcIsBzhztTgnSrqP8CaAyZV3spnFwjQN0bj10fr5Mb
evc/Z7vhhD/kZgEcp1ZXGC55Sv0XYF9JvIGtmNwtwI282wEu98gcIcKZNxtc
FZ5R/4VYr6bZZb+GrCyE6GrNtGUpZBUhxD7GbaqVZK4Q74xvzugaVU39FwID
D7y6YU/WEUJBbvaXiENkPSH8exodptWTIcS1N4MHPObWUP+FuPt42Dt3V7K5
ECsvO3z8coJsL4SFw+qhoc1kXu/7lWz0W6fXUv+FqExt5Fn5kflCDO7rEpKT
TY4Qos3HzL1PJ5kRQqdZXtNEt476L8TvNWPPxIWRU4ToGPq54fRVcqoQpcMG
5T/4SZb0jsc9n15v8Jz637tfkibVt3HknN76F9N2vZKSrwoxt2iLz6O+L6j/
QnwOnXDsvDG5RIiqLy/URVvI5ULU5pq8XVlCrhEicF3NswEKL6n/vfn9lVsv
rCI3C6Ga5Kdss4PcIcSWKr9FLY/J3ULYKu7cwFeup/6L4Oyw1q3VgiwvgtVU
TVO7PWRlESo5qV8uV5FVRBjrq7Jh0OhX1H8R7O+pBa21I2uKsFZj1tQtqWQd
ERbrXPTNqSXriWARP+Kg+5AG6r8ItnGxCz7OIJuJcLDJfGDAWrK5CC1blvdt
8SfbizBVf7jqhp1kngg7r/tuKMkme4pgkj7o3IxyMr/XjocHb+8gR4hQoVjN
b1JupP73jqd6P507m5wowiyh3JxYC3KKCOM/2McXBJJTRRAIlS7/3EWW9O5X
9JPHM/PIWb3rZdYWrX9CzhHB5+z0bYJO8lUR9kYNmSAZ/pr6L8LvwkPBV+aQ
S3rXdyoi8Z4luVwEzrHlVuVB5BoRXtqkP6zYTW4QQeu8dntpHrlZhJsFzLlb
T8gdveu7ryd3upPcLcJC7fZPO4Y3Uf/FUHTXdfWeQ5YXY8XgDHsjS7KyGF8K
S0sUg8gqYgxdbHT2yS4yV4zlett/peSSNcVYHGKUbVpB1hFD80JTwbcOsp4Y
nMt9NI4ov6H+izFan1u3WIdsJsaE77ernq4jm4uRnRag5B5Athdj2bOM+I/J
ZJ649wS94gacJ3uKoRV8pPX9IzJfjPU965/at5MjxFjgklJbqPiW+i/G+Cl5
n9S0yYlizLoxTzlmFTlFDJdjO+Y+8ianivF8xXTL0UlkiRh3Z0RttjtFzhLj
5IMWl5QSco4YP042LS98T74qhpFt+YBWuXfUfzEiY0cfUtAgl4gxrmbcH7Xl
5HIx1Bdj6tzN5BoxPhx/r7RIRG7o7ccs/jn9dHKzGE2aC37NLiR3iDFlZGoH
t4Hc3duf820JA/+SOQk4+X37hbcT31P/E1C0qCww34CsnADuWPlrievJKgng
JCUJ1kSRub3j7Zm3Bx0gayZAYWhO+M0rZJ0E7Jv7eZ/nM7JeAi5Nvjp6cBcZ
Cbiubt55fEQz9T8B+f/0U50/h2yegI1nxx66ZU62T0B3S529YQCZl4CX97Zb
XtpB9kzAqM5gRv0smZ+ApU2VdYkPyBEJeNbx0eFtM5lJQJqd3De9gS3U/wSs
MHPMFP1DTkmA9Os09zvLyKkJUEm7MP2PM1mSgGlpuu0zmBaj/wFCPxyu
     "]]}, 
   {Hue[0.09956348249516367, 0.6, 0.6], PointBox[CompressedData["
1:eJxd1nt4TFf3B/Ct2hfV6FAlbWmHnxJFDXW/xIrroJggFUScNxKl0ZimpLln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     "]]}, 
   {Hue[0.3356314599949535, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.5716994374947433, 0.6, 0.6], PointBox[CompressedData["
1:eJxd13l8TFcbB/CLqnhfy9Ai+loGLWNpjUoqtf6CEgSTBYlYbsUSUYwWmew3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     "]]}, 
   {Hue[0.8077674149945295, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2Gt4TOfaB/BVx9BdRkvfKNrl2LAjpjQVqtzOYzuNcxCyRJLGMRPHyWny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     "]]}, 
   {Hue[0.04383539249432289, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2nlcjdkfB/AHMyPbaGYsWWbmTrYKI2sZQx8SSZIiJXSTklLd1nvbn7sp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     "]]}, 
   {Hue[0.27990336999410914`, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2GdUFGcXB/DRGMGocYklWBmjKLGuJYpK9EosKJa1g4WMYsG+FpSAwmyB
gHVjjKKIjljCa4mrviLBNjFqbOBaiBg0DkYNUd9k7QRF3+vZOx/27gc5v/Of
57nPfx4Ocmg6ae7wKZUFQfgv/vPuq+fj7iV4f8DzxRXi+erLbGCuA97L/Vne
iOUiyz9hbs7cgq0PYnkr5jbs+XYsNzJ3YM93ZO7E3Jn5M7ZfF+au7Plglndj
eXeW92AOYf6cuSdzL7Y/eOcysLy3t2Xd+n6hbD2z8AXLdeufPmx/3fr6vmw9
s9CP5cxCf5YzC2EsZxYGsJxZGMjOzyyEs/XhLB/E1uvW9x/McmZhCNt/CMuH
svXMgsnbwCwzq8zCMO/5wCwP835eZRaGs/nMMrPKLIxg85llZpVZGMnW69bn
s1xluTCKnZ9ZZlaZhdFsPbOsW5/PLIxh65llZlW3vj6CrWeWmVVmIdJ7P4j0
zmVmlVkYy+Yzy8yqbv3849h6ZplZZRbGe+8H471zmVllFiaw+cwys8osRLH1
zDKzyix8ydYzy8wqsyB5W2QGZolZZlaYVWaNWZjI5jMDs8QsMyvMKrOm23XU
83WSt0VmYJZ06/OZFWaVWWP7CdHeuRjtnQPLJWaZWWHrVZZrzMJkNl+3Pp9Z
YpbZeoXlKrPGLEzxtsgMuukjsVxmucKssuc1lgtT2fyp3jkwS8wys8Kssv01
ZmGa9/MiMzBLzDKzolt//8wasxDjbZEZmCVmmVnRTR+V5RqzMJ3NZwZmiVlm
VphVZo1ZmMHmMwOzxCwzK7o1ms+sseeFmWw+MzBLzDKzolufz6yx54VZ3rnI
DMwSs8ysMKvMGrMwm81nBmaJWWZWmFVmjVmYw+Yzg279/bNcZlaYVWaNWZjL
5jMDs8QsMyvMKrPGLJi9bWAWmY3MwGxilnSXemxmuczsYM8rLHcyq8wuZo3Z
zSzM87ZBN80XmY3MwNabWC6x3MxymeUOlissd7JcZXYxa8xuZmG+tw3MIrOR
GZhNzBKzmVlmdjArzE5mldnFrDG7dev3v8A7NzCLzEZmYDYxS8xmZpnZwaww
O5lVZhezplv//me5sNDbBmaR2cgMzCZmidnMLDM7mBVmJ7PK7GLWmN3MQqy3
Dcwis5EZmE3MErOZWWZ2MCvMTt36zz+Wu5g1ZjezsMjbBmZRt/7znxmYTcwS
s5lZZnYwK8xOZpXZxayhNSVnwNt+nr9ru9GmwT5h90bT37kXg5Db6fI0/4ke
G9Bi9WeG/VM9FtGpm9PXhMzy2IiOa1Yx95bZY0AbjnR48d0Cj03okGfrCvsv
8lh6t35mic/TOI/N6KK1+SnrEzyW0TevBQz6LNFjB7r54CtBU2WPFXRej/Sw
HyweO9HPGpsqP7V6rL4779ePhne2e+xCvw6d3HV+ssca+uSkA3v2pFB/dPDA
X/f98TX1j8PzHL36+cdp1B9d5eGBEf2XUX/0kCT57wXLqT/64u7B1TNXUH90
fFfj9ydXUn90zvLQE3dXUX/0TW1YdiUH9UfXK+rRZjVZRk9f8vSvBt9Qf7Rh
eS1tO1lBp3T+tGbbNdQfLTW7OfcgWUX3tJ2pGvwt9Ucf9Elz5ZE1dPenZy70
WEv90cYmLV7mkYWvQCioGDIs+Dvqjw7a/ajoIFlEd3qwZ0XbddQffc4IM3eQ
AX1gb+SChuupP9o5dN+21WQJveziv+WV0qk/ul72s8XzyTJ6UI+o+iVkB3rw
kZe3Bm+g/uh5kHwql+xEj8jPv9B0I/VHF47KeJJKdqFbncnr+jdZQ/9a7fWG
YRnUH737o47+B8lCPAhnbnfc/9Em6o9OtF+PNpNF9Jj2r9tdJBvR94yyX4tM
6o/eX7nfB4lkE7r6kE7+18gS+tYTY/egzdQfbf6w9dx4soxuUdkv5zzZgW4d
X1iz/hbqj26wcE7sFLITvbZv4cN9ZBV9KauquYzsQn893CIHKNQ/HuS0mPsF
vclutPphzifRZCEB5DVLYhNsZAN6S/buoiyyiL4SXtLtJ7IRveCusvl3MiTg
+/5xUdVXZBO6vNhtrreV+qM7tN1yy0g243pTVO1BA8ky5qXPtCOTyA7MJw/O
bBNPVtA3Mm9nOshO9OEyqLWTrOL6+KHj5TyyC/Pw2AJ3PllDb2jaRdLIbnw+
40mngsdkYQkI+XNndK+cRf2XgDyxRuJ2P7KIeeandWuIZCO6Vf0ic1syoCcE
zLvSjWxCT49dYexLltCp4UXLhpLNaL8LVUoiyDLa6n+q40SyA+fHjzqfFENW
0FlZ+b/MITvx+a+bpnywkKyiJ7/Y2z+O7ELfHlApKYGs4fofBvZ0LiW7Me/S
PrA4kSwsBaFW17i3ug3oxD2vGukWl4J8615spyV6f8wf99sX+pXeH902dP7A
WL0/+s/I5QPNen9cn9D0XOgMvT/mE3q+7hit98e89vSXDcbp/TFvNWd1+TC9
P+Y12mdc7q/3X/ru+/3plhC9P7rXpJu5H2+n/u/yZZGRT3dQf3TzgkDLpe+p
P/p/o1613/Mf6p+I93P+2ylpu6l/IshvRmY3nbaX+qPrbX0c3Xcf9U8EOPRP
7XprnNQf15+PrnTMsp/6J4LaIX/TznkHqD+u91vz05WJB6k/5gtuD+w9/L/U
H/PFu2o/CT1E/TG37X9xt1MO9cfcurSgfuBh6o+5GB3rqJdL/XF+bfvpMN8f
qT8+L7nSQ8vJGnq/z7mlj/KoPzorr33570eofxIITQbtPHz5KPVPAjXnyfs5
p45R/ySQq+W1fH74OPXHPMB+d+HuE9Q/CWBm8rKNQ1Xqj97hPrvxHFlKAnFr
Xv0jX/xE/XGeyXf6q2NkOQmU6f/LGhd8kvongRY4+2DxAbKCeVl8SkLbn6k/
nmfQK58e2WQV816nmjVodor6o6XNp/03kzV8fmbfG13qn6b+eP6q0wcuXEsW
ZFAse6tcrnXGY18ZNMeep4OWkw0yiDVeVC6t+ovH/jL+/2FokmUli+if4o0J
b8hBMkD5rsAF8Wfpfcmg1vX7K+0FORj3U+pNPTH/HL0/GeQ9Aam1/yGH4X4r
l3dPmXme3iful3Yo5uNScoQM0trnFWcmX6D3i+cXtt5bW0KOwec7VK9uibpI
7xs9KCVyeTE5Dvv9GX30YEQ+vX/Mc583KS8kp+L+3VbNihpRQPeB5xtjcWgu
cjq6buAiecgluh/sY7zi2/MiORvP8+WTDTUCXXRf2H961GPfyeRcXJ/2pVBn
G1mVwZS962jbO+SzMpi/edlwdNPLdJ/4PnpUqrNSIhfhfjVTNl7ZQtZkMLYO
29HiNrkUfaBmq7QmV+i+cV6lrU3KJ5DLZDD864r7KpMsWEALntfO5xbZ1wKu
qLGfbWt0le7fAobQGbbB48n+FlDb2D+suoks4vO1v7l4sZgcZAH3xaSDWxte
o/u3gBja90f7OHKwBYzbb16NzSADPr+h/78Li8lhuP+cVQHWhoV0/+jP1ZDM
ceQIPE+jp/3OZJAlNPTpXFFMjrEAtCwq793oV7p/Cyg//uZYO54ch/NmJD16
toks4/kjK1WJvkVOxfPN3pb/e+PrdP/vzuPsFRNFTreAqXmC6e1msoLvb0rU
i223ydk4r+OxlqPFIrp/nHeycnHdieRcdHpW1T+2klULmFf5bz12h3zWAkJJ
qbKj2Q26f5zfQ3m9cTK5COefuLorcwdZs4Dk0zRr731yKebt2t043/I3un+c
V/Cffs9jyGV43vfCS9rsIgtWEKdc3jLvIdnXCo733v/q5zbFdP/oSTnRn8wh
+1vBPPf46FX7yCKuX/wmzOcxOciKv69JHVZ2vEn3bwXn54VVxYXkYMwrxqgn
DpHBCsZ1D0bOekkOs4JpzPojgd1u0f1bwZVqfvgwnhxhBWm0o/j4UbKE63P8
bZvfkGOsIA/pdGMZ/E73bwWI9Cu0WclxVlBSHs5OO0WW0bcqZWRUvU33j89n
ZIzICyM7sK/BZ/W9ZeR0K2hLN/RpnE9WcP3i64ecPhrdvxUiPiisKAoiO3G/
muWxPgPJuVYIgzf1Q2aSVey3eNO9RSvIZ61wNmXNtcN7yS7sE7T1zpsCcpEV
Uv9aXn2Qm6xZIdhQP3yLXwndvxVy7X6ZZR3JbivE5ELFmJHkMiuUrlg47Vgs
WbBBdvel14PWk31t4O7SdsDGXLLBBo76kbl+v5H9bRBsvS6ufkUWbRBRISd+
1PgO3b8NlNL2+Rk9yUYbwBjVt7VEDraB9rxWW9VCBhsY/674bNw2cpgNxPMz
Al6fIptw3pjge1n3yRE2CEsbYBvq+wfdvw1/n7I+r9SKHIPnzfula1442Yzz
xrztGzebHId9N9ZqFLKaLNvAHH/70Pv7yak2SJ00ulbhFbLDBrm1xzff9Yyc
bgPflCK3vd5dun8bxJ0/aJ4STM7G/R4VbgkfS3bi+7jaIr7rEnIu9glc9Spo
M1m1QVng0wBRJZ+1gZQR8kejO2SXDdS9pt4BVe7R/eN5ztXp0rIFWcP3Z519
rHMYudQGQfN7Xu0/g+y2gavJjAXSCnKZDZw3Lm9I/IEs2EHYNio0y0X2tYO7
+rWYC0/IBjvI9VtVK69zn+7fDv4tOwW060oW7XieszunRZKDcP2Bkxk7E8hG
O6SuffHvg0xyMM6rEnyss0oGzKMiSmx3yGF2MOxtMamoyp90/3bQUuf26NiS
HIHzhYqYbwaQJTucjV93//lMcowdghTB+eUqstkOppAKtcBJjrNDaWB43S+u
kmU7KM13Zh99Tk7F81w/s6iHfyndP+63aVLCie7kdDukx7Y+EDaBrOD+zy7V
u55EzrZDUeNX22dkkZ12MI8aGfHeaXIuzuuT1Gbrn2TVDmGnGjbu88FfdP92
iDhzOvBRG7IL33+vuqEbhpKL0H6bZ4fPJ2v4vl78s63yd+RSvI/p67Tjh8lu
PO96/wD5N3IZ9un779h+FWQhGZzHc1b7iQ/o/pPBcOp8bkko2ZAMwqJdl3Om
kP3x+S/OFDpSyWIyFBWlqXN3k4OSIaLG+JUjCshG3O/S5q4hj8nBySA13Jf3
aZ2HdP+4/727fo26ksOSwVjt2+DaY8mmZHD08mlVayk5IhlM1ZeV1FLIUjJk
74kaW/dnckwyiLV/Xh1wn2xOBvelf5a0q/aI7j8Zynz9G4e2IcvJEDRr+syx
Q8mpyRDXrEb04vlkBz5/9pO36d+R05Mhd9z57idyyQru37mB34PiR73+D02b
Q/U=
     "]]}, 
   {Hue[0.5159713474939025, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2nt4TNf6B/CtVCfq+I02mlSrBkVI6eQ0SI/gG9dUtSYXBAk7IoxbTIhk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     "]]}, 
   {Hue[0.7520393249936888, 0.6, 0.6], PointBox[CompressedData["
1:eJxdzSlsAFsZBeA/qMoRiArEQAhpCCHDXtZ32cs+PLayXx48KOsb9rJftqRy
ZOWVlSMQlVdWjqwcWTmyEgiCzPeLe/Pl5OS89qVXXnz5VRHxr/88//3/d/sL
cbx05Anu8KvxKX4N7vHr8OvxG/AZfiN+E34zHvBb8Fvx2/Db8TvwO/G78Dl+
N34Pfi9+H34//gB+AaejC44PkuP4EDmOD5Pj+Ag5jo+S4/gYOY6Pk+O4IMfx
CXIcnyTH8SlyHJ8mx/EZchyfJcfxOXIc49EJF9xwfJ4+LrjheJE+Lrjh+AJ9
XHDD8UX6uOCG40v0ccENx5fp44Ibjq/QxwU3HJf0ccENx1fp44Ibjq/RxwU3
HF+njwtuOL5BHxfccHyTPi644fgWfVxww/Ft+rjghiMf3eOEMy644oY3HN9h
HyecccEVN7zheIl9nHDGBVfc8Ibju+zjhDMuuOKGNxzfYx8nnHHBFTe84XiZ
fZxwxgVX3PCG4/vs44QzLrjihjccP2AfJ5xxwRU3vOG4Yh8nnHHBFTe84fgh
+zjhjAuuuOENx4/YxwlnXHDFDW84fsw+TjjjgitueMPxE/ZxwhkXXHHDG46f
so8TzrjgihvecPyMfZxwxgVX3PCG4xX2ccIZF1xxwxuO6egO93jACY844wkX
POOKF9zwije84/j50R3u8YATHnHGEy54xhUvuOEVb3jH8YujO9zjASc84own
XPCMK15wwyve8I7jl0d3uMcDTnjEGU+44BlXvOCGV7zhHcevju5wjwec8Igz
nnDBM654wQ2veMM7jl8f3eEeDzjhEWc84YJnXPGCG17xhnccvzm6wz0ecMIj
znjCBc+44gU3vOIN7zh+e3SHezzghEec8YQLnnHFC254xRvecVwf3eEeDzjh
EWc84YJnXPGCG17xhnccvzu6wz0ecMIjznjCBc+44gU3vOIN7zh+f3SHezzg
hEec8YQLnnHFC254xRvecfzh6A73eMAJjzjjCRc844oX3PCKN7zj+OPRHe7x
gBMeccYTLnjGFS+44RVveMfxp6M73OMBJzzijCdc8IwrXnDDK97wjuPPR3e4
xwNOeMQZT7jgGVe84IZXvOEdx1+O7nCPB5zwiDOecMEzrnjBDa94wzuOcvQJ
7vAp7vEZHvA5TvgCj/gSZ3yFJ3yNC77BM77FFd/hBd/jhh/wih/xhp/wjp9x
/PXoE9zhU9zjMzzgc5zwBR7xJc74Ck/4Ghd8g2d8iyu+wwu+xw0/4BU/4g0/
4R0/4/jb0Se4w6e4x2d4wOc44Qs84kuc8RWe8DUu+AbP+BZXfIcXfI8bfsAr
fsQbfsI7fsbx96NPcIdPcY/P8IDPccIXeMSXOOMrPOFrXPANnvEtrvgOL/ge
N/yAV/yIN/yEd/yM4x9Hn+AOn+Ien+EBn+OEL/CIL3HGV3jC17jgGzzjW1zx
HV7wPW74Aa/4EW/4Ce/4Gcc/jz7BHT7FPT7DAz7HCV/gEV/ijK/whK9xwTd4
xre4/t//Blkb/8o=
     "]]}, 
   {Hue[0.9881073024934821, 0.6, 0.6], PointBox[CompressedData["
1:eJxd13l8TNf7B/Bb+m1TbZmSbwTFaJWUYGqNpXzQRmodqRKV1lgSESKTfbLf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     "]]}, 
   {Hue[0.22417527999326836`, 0.6, 0.6], PointBox[CompressedData["
1:eJxd1mt4TOcWB/CXVuWcozpFJeo2JNUcVEcoQfAirdQlGSUVgmyXRKohk7gk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     "]]}, 
   {Hue[0.4602432574930617, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2Hl4TNf/B/DbCg1FB8FUU4ZaYu20gtBU3rYIgthjH9lMJGSSTJLJZJK5
sxGVMMq3ogkde1rb2GMfFZpUaGqNtVNFgyCpaIPgd3N9zu953PzB83rOnPM5
77ucc+9tHxY3PvJ9juP2Cv/U/f/2rzKAe/cP79JTYhnZ5f/2fy+J5ZLfe0us
kLiDxB0l7iyxj8TdJO7B5nPk7f+9JFZK/IWk/5cS95b83lfiPpLf95W4n8R+
EveXeIDEX0nsL6n/tcQDJQ6QGO+Ox0vMDXr397zE3GBJOzP7GyIZn5n1Hyrp
LzE3TNIuMRcoaWdmf8Ml9SXmgiTtzGz8EZLxR7z7e26kpH2kpH2UZHxmNn6w
pH/wu7/nRkvaJebGSMYfI2kfK+kvMRfyriExL7FLYm4cuZT6j3u3nZfYJTE3
/t35Y/y77bzELom5CZL5S8xL7JKYmyjpz0x5eEm7S2JukqQ/M+svaXdJzE2W
9Gdm/SXtLom5KZL+EvPM9OeStHOhkv4S88w0H5eknZsq6S8xz8z6S8xNe9eQ
mJfYJTE3XdJfYl5il8TcDMn8Z7zbzkvaXZJ2bqak/8x323mJXRJzsyTzl5iX
2MXMjv9sSX+JeYldzGXUX/Vuu0JiMFM9laSdl9gh2P7K50yB5vjbboKX1Zl/
a7fgyYajypaL35qbAz67rt3+1oo54Kr8n766t/KtIbRPrPv96rdWCT5weFH4
kDVvzbP+jrd2CP0DPl1657f1VH8OXJV1422k+sLv188Ibf16M9UPAyeO/yPV
DwNfP6/DyB5bqb7QLtbbTvXD4FJfrzBM20n1w6AQ6zupvvD7qOzrUwp3UX3h
9wPr5rOb6ofB0Xo74q/vofrhUInz20v1w4Hikk3f/LOP6oeDE+e7n+qHw62v
aLSxYQHVD4djQt38D1L9cPA9GmuOKg5RfWE8Mc9hqi+Md6v7pcv9jlD9CLj3
1+U7SvUj4Fg2akDlmGNUPwK8mPc41RfaHft+8+jtovoR4MT8ZEcEVKnDzMsH
nqD6ESiNrDseZHcElOMv+bYd+TPVj4RdPD5kRSS47pF//zTpJNWPhEo8XmRV
JErrPVvdb04h1Y+EUjx+ZIcw3g1rcGHsKaovjCceT7JbGG+f15sQ3WmqH4XS
dXXHl6yIgnLpxl03Lb9Q/SjYxeNdRPWjwM31jZi3jMxHQSUe/2KqL4wXUNjq
v+/JLmE88Xz8SvWF8eQTiy2bydxcVHrUnZ8zVH8uVFV/pcl2kzEXrpt156uE
6s+F8tfEXmuOkvm5sIvn7yzVnwtuQ70/uxaTXcJ44vk8R/WF8dJWrNh/kcyp
oRTP729UXw37xM8Ch7jJUEMnnu9Sqq9G/ndTa/9OIvNqlGXVnX+yQw2ZZd2k
HS/JLjUgXg+/U31hvLj7O7QmMhcNp3h9kBXRcE//wvOrD85T/WjIxeuFrIpG
UFDqnPeyyXw0ePH6ITuike974tAvzS9QfWG8bnXXE9ktjNe+odfSHDI3D0Hi
9UVWzAPfZNz8iW0vUv15cIrXG1k1D+7nOafbbCTz8yATrz+yQxjvnrvdn10v
Uf150InXI9ktjHfeJ3XLTjIXA3dR3fVJVsRAdlxzfn6fy1Q/BkHi9UpWxUC3
taC772EyHwOneP2SHcJ4qzjbC1yh+jGQi9cz2S2MZw265TpN5mLBi9d3GdWP
hVNj77comIxYuKPqrneyKhbymWX20efJfCyCxOv/KtWPhW6E4kGLULJLGE+8
H8huYbw+6iHXbpK5+ZCL98c1qj8fQR2ceY5wMuaDF+8Xsmo+nE1rnkXdJ/Pz
US7eP9epvjDey4CxPePIrvkIEe8nslsY7+9F+U+rydwCFIj31w2qvwDlF357
75CejAWQi/cbWbUAIa7W03nuJtVfAF68/8iOBXBum703cCHZJYy3vu5+JLuF
8VZvadKk8S2qH4cg8f4kK+Kgsz2JurCcjDg4xfuVrIqDO76fa3XrP6h+HOTi
/Ut2COPNMn6sWkN2CeOJ9zPZHYfQTeH9VzRzU30NNOL9TZZpkJn7QVTyRLJC
g43i/U5WanBk+dZvp64iQ4OL4v1PDtGgctHY4/7XyCoNPMX1gKzRoGPG04ft
Pv2T5q+Bv7g+kO0aTNSuktdTkR0axIrrBdmpgXXeV8PurSe7NMgT1w9yqQYF
qj/ii++S3cL8xPXk9ltXalA+2bJ2mw+Ziwcnri9kWTy8R3c5syyGrIiHn7je
kJXxCBly5r+EHWTEQy2uP+SQePD94zpOriKr4pEnrkd/Uf547P28xbj+vmQ+
HiXi+kS2x6O804F07xSyQ5ifuF6RnfGQe0//6c1BsiseSnH9IpfGI7j5m8u3
a8nueESI69kdyh8Pg+eGeqcDyFwCcsT1jSxLgPN1oPJHM1mRgCJxvSMrE+Cu
fjAj6xQZCah5Urf+kUMS4PVw6eI4z7uUPwE+4npI1iQAf365f/woMp+AGeL6
SLYnQHvl8u0+S8mOBGSJ6yXZmYD8s/qPPv6d7EqAS1w/yaUJuHGyrX9ti3uU
PwHVx+rWU3JlAjwP/az+YzKZS0RHcX0lyxLh74z638+ryYpETBTXW7IyEbGb
G/286QYZibCK6y85JBGOvB2PM9v9TfkTUSCux2RNIi5+O/6T2DAyn4iK7Lr1
mWxPhMfif4eP3UR2JMJbXK/JzkT4Gb/XfllOdiUiWFy/yyl/ItRJA9e17E52
J8IgrufkykTkxNw+WzOfzGnhFNd3skyLojkLX1x3khVauGfUrfdkpRa1U7p1
Of6UDC28xPX/PuXXoseYcxPW9yWrtAgS9wOyRosZQxN4WyqZ10Ir7g9kuxb2
Aa22q4+QHVrki/sF2amFS3no6qg3ZJcWN7rX7R8PKL8WlZ1nNfh8MNmtRWNx
PyFXauHz6fu9m9vIXBL8xf2FLEvCxBabZz/7haxIgkbcb8jKJGQ1HJlV1ugh
5U+CQ9x/yCFJKHjzqODwaLIqCRdf1O1HZE0SKp4tv7vWTuaT4CHuT2R7Erwr
+jQ3XyA7kuAr7ldkZxJCbl8dGNmqgvInQS3uX+TSJPBl6TFBU8nuJOSJ+xm5
Mgl7z7XP6Z5H5pJRUly3v5FlySgvPFXY9A+yIhmcuN89ovzJkB+OrqpqT0Yy
lOL+Rw5JRvCuJm0vRZBVyYgQ90OyJhn8ll0jC7aQ+WTkiPsj2Z4M55pJKbkP
yA5hfjl1++Vjyp+MOyueb8joSXYlo3Zp3f5JLk2G1zdrSudoyO5kePuZjgUl
kSuTUVj035IeejKXApX8SK8mRrIsBYX3d+Y9sJAVKQh5dv1MYSZZmQJld83u
3GwyUtC46mRg3LfkkBRcnDbZGLCKrEpB5axz4xvnkTUpcNZ/eeCSg8wLXnFh
U+4msl3ovzOlxayfyA5hfOvnNd47Wf4U2K/GjCrbw/IL81Ge9rAXsPwpyC/l
vIceZflTEHutweLqEyx/CqzBFUPWnWb5dVjZ8PHQkWdYfh38rsRbn/zG8uuQ
F9rgpf0iy69DrEf4ul5XWX4dFK3UmqKbLL8OOfq2c2bdZvl18C04EFt5j+XX
gT+fnZXxkOXXIaTrZ4c8K1l+oX1ChydLq1l+HdTPZnZq9pzl10G2onTyslcs
vw4+s/LSG77/hPLr4Ml9uNLYgOzWIWt29sqqRuRKHarDDqfO/ojMpcJnx4SB
xS3IslR4zPzqZi85WZEq7Bfp4+zeZGUq+KpR3z1SkJEK/xO1mwM7kUNSUdax
sTG3K1mVCvfrNm0qepI1qcg/9jjR70syn4qh9eIz+b5keyrUX+2cUDiA7EjF
3sHXfq8XQHYK86kd9mbgELJLmM99dVnScJY/FUUnrk/NH8XyC/OrN5W/PJbl
F9qtR4K4iSy/Hjke9ZydQll+Pdx7R+wJnMHy61F4+uzYcBXLr4fm6UNzWgTL
r8eReoqRy9Qsvx6yyR4b1say/Hp4hY9b8qOG5dej46CbwjLO8usR2zn3vd06
ll8PvwffL9lpYPn16GHzXJPPs/x6lNm7+66xsvx6GE5Hjc3OZPn1UKX3e6TL
Yvn1sPr0aayys/x6BF2UbR28kuVPA79hZZEih+VPw97gDeEvcln+NMhX9Uv7
7QeWPw03roQ3dWxg+dOgiRvnHbuF5U8DhmNj760svzDe2IWb/t3B8qch5/XS
dvt2s/xpiDh3rVncfpY/DSVHX6d1PMTyp8G/dMPMS0dZ/jT4Llu433SC5U9D
bFbywq6nWP40eN2ddLakiOVPg+dp+ZKYEpY/DR2rCo/XL2X5DagZEh+Te4Hl
N2BlwLClPa6w/Aa4lut8Dl5j+Q3I/GH8gEG3WH4DQpt1Kyz8k+U3wKqKOD3k
LstvgC4qadCxcpbfgNhHt/r4VrD8BpQNVm7c9ITlNyDrTP3s5k9ZfgMcqz2r
9P+y/AZ4ejwuvfWc5TfAFyk9B75i+Q3YllFgCeYqKb8Bl/mrO/97j1xpwPk7
y3Id9chcOhZ6jR8+vD5Zlo6mKbl7HjYgK9IROKTCne1JVqZjxoTi33o2IiMd
oc8P82c+JIekw3lxXHVUE7IqHeX53t25j8iadPTos7vTKhmZT4dHk213ujcn
29NRHb9FfawF2ZGOMb2G7R7TkuwUxtN0/flGK7IrHcc47Q05+31pOu78l2Ga
wOq50yH7cOH2LDa/ynToWxTNKPyA5c9AWOSiJS/Y8ZBl4PXrhn0/Z8dPkYFt
C3rvKqxh5z8DtVc9/+hSxc5/BjTRfo8X3WfnPwOFH8VducOuB1UG7HfDVgxk
148mA2rbhTb/O8/Ofwasc7+JKv+Vnf8M+Hw9Pc7vJDv/GVCM6tjLdpidf6H+
yXO55/aw85+BvPZjd3ltY+c/AyXpm+ZO2ciuf6H+g5sHvstj138Ggotluef/
//43IqJ9eKMPs9n1b4T7WYM3ATZ2/Rvh/f1XCfHpLL8RR+qPmflDEstvRHCX
1QeL57P8RgT1XchXRrL8RhTUy97aYhbLb0TRCF/f3pNZfiNCXjTzGjuG5TfC
K+vM0LmBLL8RNwJbudIGsvxG+Cw9YMxi+4XLiPxutvTVvVh+I7TfRu5Z35nl
N8L5ecgn+W1ZfiPKN43e+WMrlp9HbUtd9JamZE9euH9fDlnH9k8Zj7yolv1X
vab9Vs4jdkSrIYv/Zc8HPFxbVDNSHpN9eKiuRRvnsP1eyUPb69Dm4bfIfjyy
2j4q6XqZPT/wOLJ4V8UH58hBPCbeL+Zun2LPEzwirI09CtjzTCgP+frwqsX7
2PMFj5KDZ09O2U5W89i7bmZye/Y8pRHyHB7g8Td7/tIJ47Vbp85fyZ4/eMhO
/bk2MoucycNja9j6tlb2PCIcn5drF1xII+fw0HzZ5Y0lkT2fCOMNWDdWGUPO
59F4edH0sjD2vMKjPGxBO8M0cgGPoi2p330ynj2/8Kjw//vI/hHkIh7qV8VL
Rw9iz3PC/MtGerr9yGU8gu/ld1qgZM93PHz1/f/6rwu5nIe7t/rr9HbseY+H
oukB5etW5BphPjHHDuqbsuc/E/I+63npn/pkTxPUmUXGqFf0/C0zoTA+dv+l
arLcBL9BHyajgqwwYei97Yc3/0X2MYF3J1o9r7P3BRMqAlacjTxP9jNh24bQ
lcfY8z6E8ft2udz8BDnIBGzV2cMK2PuECUd633Rt30kONUGe9jKiejN7vzAh
53u7vu9aslqYf1PNm8T/sfcNE2LzLVXbssg6ob7pzJg/Lez9wwT3/Zktm6WR
M024MWnuEP8E9j5igndwtyth0eQcoX7Im3NWFXs/McGrZGLX9VPI+Saonu+4
c2gM2WmC4Zctb84NIxeYkH/ise6WP9klHM+nQWPv9yYXCe2/2k1PupFLTQh5
ua/p/79vlZlQPfPos0dystuEHqWuPvc+IpebYG/+5OzVBuRKEwo2LTla9Ire
52pMiNj8uN6eavb+Z4Yy3+rIeUj2NGPbsnPfpt5m74Nm9IiZc23SVbLcjKKR
95J7lrL3QzN0rduouV/IPmbIos9uP8feJ5XC76ffGZ6zl+xnRn7E5L4zt5Ih
1O/UK/XT9eQgMzQDF8uu5pBDzAj6LKd22TJyqBmV99d8PXghWWWG16eVF54Y
yGozPLL+PZ6TSNaYkdem+/tfzyPrzDDYP869oSLzZrjmzl6SMoWcKdTL3Xqh
yRiyXeivPab9YSg5xwy/qdFxPb4iO8woWLW0cO8X5HwzeN/2SX4+ZKcZ8v0d
zQfakgvMUFVtq/iiJXt/NyP40s19Wz4kF5nh6Pvwlvx99j5vxsRcebStht7/
y8y4U//gpEePyW5hPFevzSF3yeVmZHZ5OH3ndXKlML+kBbqG58k1ZhRmD381
q4jMWeA+1aJi5zGypwXa3RmBtXvJMgvKKwc1HbqVLLeg4J+OwxatIyssCCmq
rTi1iuxjgaxi6wfcUrLSAmeTDqv6WMl+wu9vTl8TpWffTyyQXwnzXqEhB1lw
o+noVoej2PcUC0pe+mffmkEOFcYbOsfyajz7vmIBl1X9ovUIstoC3v/rf3sG
sO8twviTs1MC+pB1FhQNGGwK7s6+v1jgYShsOak9OdMCXf6iflNbs+8xFtR+
3Oh+aBNyjgV3Tl7sMbEe+z5jgeu9tPqjntP3oXwLgqO+T/r6CdlpgdeSa8bu
d8kFgt0VnVteJ7uE42XImv+ilFxkgfej9MnXT7PvWRZcbLjszoEj5DIL8n/+
ro19N/u+JczvqfZleD653IIgv+bf9F7LvndZoDw8u/j1CnKNBVmNpxw5tZh9
/7IipPp5ZKaR7GlFUeD44sAk9j3Mih4H4+9zMWS5Fe798cX7Vez7mBW+/RJj
1ZPJPlbErlh7qWUw+15mRebMzzyPDyL7WRHUz++DiH5kWNH4pzaXPXqSg6w4
8rqpbl0HcogV21qpKvvLyaFW7B06e/C5JmSVFRc7R8TPqkdWW2HgS/gHNex7
oxV+LWsTEx6TdVaUW2aM+fcv9v3RCl2HmS2Sr5IzrfC5lnC66hz7Hin095DH
RBeSc4T5Dy/xuHmQfZ+0okLrtSp4JznfCoVa36lgI/teaUX1X1l72rHvmwVW
lCT8MdSyjH2/tMI/sNHN21ZykVC/9U/GgXpyqZC/gUr5XRy5TJiP8fd/7keQ
3VaoW+X/2n8audwKedzyw7ax5EphfO+A4rNDyTXCfC1R/zUbQOZs8DrpGjH+
c7KnDfbljQqXdiTLbNjW2WPeLx+T5TYEtY0PqG1KVtignCUP6ulB9rGhR+3J
RdOes+/FNvh2HPS+9THZzwbNm9mHf/yLfT+2Cevb0/1nyshBwvi//15z/yw5
xAZ3rwtWj5PkUBuCb52f9UkBWWUDlu34ptd2sloYTxXYeOB6ssaGkiLD3yNW
kXVCPnNfxfgsMm9DtXbaockmcqYNET/8fnBKMtluQ5nHog6TYsg5NuhWza0Z
oyI7bFjZMSxg2KTy4/8H/ESoXQ==
     "]]}, 
   {Hue[0.696311234992848, 0.6, 0.6], PointBox[CompressedData["
1:eJxd13lcVPXXB/Dr1qNhOoULmenA44Jro5K7cjRDwMzJBUFTL65kpqOoLAPM
dxCUkGpcEDK16wqW2pgbCupNzSCzRqmfkKLXrcgsRzRFf6jP6bnn/jHHP+T1
fn3OdzlzdLg3cPqCsbPqS5K0H//696f+xxsq+f4B/Yc6WP/ZGHxjE8tbMAcw
t2U2Mwcxd2DuRPaQg5m7Mndn7slsYe7F3Ju5D3MI8+vMfZn7MfcnV5AHsHwg
ywexfDDzEOahzKHM4Lu/AJYP87UY5lsvDWf5cJa/wXJmaQTLDRvr32Q5sxTG
7h/G8pEsH8nycJaHszyC5REsj2T3Y5ZGsZxZeovlzNJoljNLb7OcWRrD7s8s
WX3rgVkwq4aN9e/4GpiFYWM9szSWrWcWzCqzNI6tZxbMKrM0nq1nFsyqYeP+
E3wNE3zrhWH6/lJZvRTF1jMLw8b5zNJEdn9mwawyS9FsPbMwbMyP5VIMWaP1
Mb65YFYNG/1PYuczi0m+9SrLpclsPbNgVpmld9n93/XNBbPKLE1h5zMLw8b9
WS5N9c1hqm8umFVmaRo7n1kwq8yS7GszMzDLhunzEixXWK4ya8xSLPkGnc8M
sb71MssFs8KsMmuGjf6n++5vZgbDtF5mFswKs8qsMUszfG02bJzPcplZMCvM
KttPY7k0k1xN58/0rYeZvvUyszB8m85n+6msXmOWZvnazAyGaT+ZWTArzCqz
ZpjuK832zc3MwCwzC2aFWWXWDBvnz/G1mRmYZWZh2Evns1xl1pilOHY+MzDL
huk8wXKF5SrLNZZL7/nazAzMMrMwXEPnM6vMGlsvzfXNzczALDMLw/fpfGaV
WWOW3ic/oPOZgVk2TOsFs8LqVWaNWZrHzmcGw7V0PssFyxWWq4Yf0/kslz7w
zc0f+OZg2DifWTArzCqzxizN97XZMN0HmGVmwdYrLFdZrrFcWsDOX+CbA7Ns
uI7OZ1bYfipbrzFLNl+bmM3MFmZgtho25mWY7mdjFswuZoXt72a5yuxh1gw/
1e1llhb61puYzQt96y0sB2Yrq5dZbmO5YLmL5Qqzm1ll9jBrhusN+f8fXpZL
i8iSnpuYzYt86y2GaT9guZWtl5ltrF6w3MWssPPczCqr9zBrrN5ruL5uKd43
NzGbmS2GaX9gtrJ62TCdZ2MWrN7FrLB6N8tVZg+r15i9rF5a7JubFvvmZpZb
WA7MVlYvG25A/bNcMLtYvcJyN8tVlnuYNWYvs7TE1yZmM7PFMJ0PLLcyy8w2
ZsH2c7FcYXazetWwMX+Wa2y9l1la6msTs5nZYtjo37Axf1Yvs3obywWzi9Ur
LHcbbkj9s3oPq9fQ9xv0VObFHtf7R0c7L4ywLdQtJYA0VOl4s0eybhP6tvrH
ZwlO3WZ0YLYn8NdM3Rb0a5UbVwzN1g3oy9c3ebZ9rNuKXrHRTyxfpVtOABE+
RskpXqPbhq6J2/7J3VzdAusbH96dHZyv24X50N/CHPJ63QraNvnR/E836Haj
u4eETy7fpFtNAPXG2oqgFYpuD+73Ifyn9fbNujX0mylRH53cQv2jt19snnFt
K/WfCDC43cG6etup/0QQezs/fhi4g/pPBOmV2g+XDi+g/tG7t5mSZhRS/+gj
1r5S5k7qH/dr0llpWvAF9Y9OGefdVPYl9Y9u9uTbQ7d3Uf+JoAbD0YmmPdQ/
7hfZZYEj5CvqPxGUBhVFed3d1D/er3dlt5DjZBXXD0uMbjl2L/WfCPK4hpmD
bpI1rC8b8GBH4tfUfyJom+HOxKb7qP8kUOu+2Pu2Qjahz8anrgzZT/0ngVL8
xNWsjGxJArnLS10qphyg/pMA5mqiuoZsxfVBT86FZh2k/nH9+djxl189RP0n
gTl73tBT+8gC9yu7cupuRBH1nwSuD6+1maORFcznS4s6JBym/vG8oK6PuzQ7
Qv0ngbviwNWE7WRPEngfT5vQbEgx9Z8EonaU+OtnsjcJPMMb5bT8oIT6Twb1
PaEsb3SU+k8GZXrbG7CJbE4G7c5W+4h+x6j/ZPD2HJO9ykOGZJAivu0VPPc4
9Y/7BTWPaFhfpf5xvaNm5stjyDas39TUPm4DWSSD+++AT7/+g+zC/Tc2/6Fv
v2+o/2QQZzqZtQyyOxkKy8uVPefJajJE7/gheov5BPWPebcmY4vnkzXs5+Cp
3EclZC/eZ5mj+xS/k9S/HUxhUrvfYsgmO8DRCQvXFpLNdtAmVXSPe0i22KHo
Treo2LBT1L8dxKxhNY5cstUOtvToRqdukGU7BByst6ZHyLfUvx2y7rTfVLKM
LOzgTrkVvLCc7LKDcvfvkFH/e5r6t0N+a/+TkfFkN66/vq58wUmyaof+8a1m
H/H/jvq3Q+GLOUldZ5I1O3hCxzZV95O9drCc6tjW3qiU+k+B4OOdd0yOIptS
wH3yyo7YArI5BbR7Q9p8VEu2pIA5aON/qyLKqP8UyLp/6s3xn5GtKWBpervm
zm2ynAL5PY7UuYd+T/2nQMW8yHfzXGSRAtUxPZ7feo3sSsHv1/efloecof5T
IO5ZpqXrCrI7BWp/s+dtrySrWD+wrEtY9x+o/xTov39ulZ+DrKWAWnCl4ME5
shfdtXvacx3PUv+pkDji4vhBiWRTKsit65lzz5DNqRDgN6Tcv/2P1H8qeGuK
Yw8tIkMqNO498JjjNNmaClDV6OK8Nj9R/6ngrpS+SJtPtqWCqXZL2wMnyCIV
bjd6+mKWn4f6T4WSZ5MqvnudrKRC00UrK1+Wye5U2J/mfCEtm6ymwmLrsjdO
zSd7UmFwzMN8v3FkLRXCpZtPx/Uje1NBGdhr9sZXyFIaSHsGO356RvcxpUFW
7/yHs0rJ5jRQvl7Q6qmLbEkDS0RSSV4MGdLAe7rT972DyNY0SKy/o/1Pt+jz
kHH9a1c3zNtHtqVB6WBHoF8KWaRBbd8bOV+MILvSoGJ/r2ORL5CVNFBHjlz7
5y80Dzf63om/cjaR1TQQe+rt7DmH7MH7XG+/zfMaWUuDxg0elyyqNeafBiZT
j3MtviFLDqgY0vrYwQ/JJgeYPq6Qo8eSzQ4IThy37lEbssUBRbk9Bq2/Tv/+
AD3R023gLrLVAdHqeyMqF5NlB1g7/CUnDCHbHOCu8Z/S4jmycIB52dQW7h+N
f//oWy2mR+aRFbzfzyMDr08jux0gzT3XPTmYrDogq1fUtOZ36f+bB/MGYWu2
HCZreP6jS1v6pJO92M8HHeJORJIlAeZ/7pW87U9uLKDxvJrkiovG94EAV906
+7Rt5AABok/X/OvzjO8HAe5W3+2c+To5GPPh73547Ql931gEVPvtbj7lNLm/
AGvh2JY/f0wGAcqko4tGTiSHC/Bsf1061J5sFWBbVpUbVE3fd9F4P2WvX7ab
LAsI2JA94K9EcpyA8HfaPRw1jGwTYGlbr+2OJuREAXHdChz/PWd8/wqIPjfr
0aj15Cz0xcVy3nTj+1hAxZ93VlZ1Jefj51V5YWy7e/T9rmC/zVvkxBSTCwUE
P4hv9skysluAFu12HxtFLsL9yudFVPuTVQHy8AFf+V2i3y+l+Hn2WlMUvI3s
wc9v/O+DQueRK3B93ermY0LImoDCVTebRNfR77dqAfnNgupNOmX8vsP7CnFm
fA65FuuXvRYaPp4sOaGibELvkLbkxk7w5PvbA27Q71cT+p2MO/e/JAc4If/B
8Vll8WSzE8B9aV/uIHKwE9wTvV/FNCBbsP7Ji5aWZ+j3e38nWBdPfr50NRmc
4K241WLRJHK4E4pevdHRP4hsdYKl881OUeX0fBGN+1evnRM/nSw7cR7jj6Te
peeROCc+bx85s1iQbbh+1ZLw6ObkRCeYOk2o6mw83wg8f3N4v+vdyVl4v59n
NMgupucjlxOU76/+/UokOd8J2oXOBfkV9DylOEH9tLTy2WxyoRNsj5aHvPMP
PY+58fPpEjMrZxm5CO//+ftt9r5oPL85QWraof7xz+n5rtQJckSHMwd6kD14
v8jRHXKL6XmwAufR8ETJu8bzoob3e/vWG00v0PNkNX4eJ5a8t3Um2Yvnr55a
FVhDz6O1eN6022NWOMhSOqjSoYXlTcmN0W/vvNdoPT3PmtLBfLnBinadyQGY
F0+rarvfeD5Gv7q3UBpGDsb6FyI/KztLz9OWdAC/qjkJk8j900Hb5fimye/0
PA7poPTYPVnEk8MxfxJ+69dn9PxuTQcRtjnw5RxydDpIsxYeHBhAlnH9tBtT
QrfR+0AcnmfNO9vJQrbh/Vz9Eq4m0PtEIq4fd79kwCf0viHQd+b8OmHHbpo/
1g/NGfr6UXo/caFtUTEXyun9JR/3n1/82aBb9H6joPvvT4iVyIW4X7fhcngr
eh9y4/0t8WV3utH7UhH62qzgicPofUrF+rWj76VG0ftWKe731tLNM96n9zEP
5jvDv/wfsY3mj/f5enT2e2vp/U3D+vzeh7MK6f2uGveP/mHfzBJ6//NiHv3K
w7qf6P2wFvNTG+tvOf05zX8Z3nfVVvX2Rpo/2h56fvxL9L5pQveMWD2lH72P
BiwD8ez0H5WT6X3VjHkH69VSxzqaP3qylNFl61qaP9afT73y+NvVNH/Mbz5t
MLjaRfNHy583rvCn9+dwdN2eP/2j6P3ain5l8NUuectp/ugJm9sFXEin+aNF
26OHu6XR/NFtgk7c3rGU5o/u7tizMnQ+zR9d+nzEczFTaf5oKaSi8+Ebx/T5
o6OfXdnbfGqoPn90yNgDA7rM152PXt7i/KGCpboV9N8tVsGQNN2F6MRN7Tfe
StftRm+Oqys/tFx3Ebpqypyw5dm6VfSM0Ov/TPhYdyl+XnOzHyz0X6Xbgx7p
/zSrbrXuin/7qVPht7W6Ncw7Bf3zqWed7mrMTfbRucX5ur2YR/on9ylYr7sW
8wK/4CVrNuiWMkB8kFdvstiku3EGqCOe/Kemr6LbhPmtk9XP99ysOyADpO9+
em5pxy26zeh7USLk1a26gzMALrXYGtZym24Lrv8qonjXC9t190f/fNh/znM7
dAOuT979z5Jn5HBc38tbWFlboNuKXu+JX11TqDsa179q/ky5vVO3jOuP9J7e
8PcvdMfh/S9dfv7Y1S9129CjUn85e2mX7kRc3+4PnPhu3QL3P+n43lu+R3cW
5q0C5zf0fEXz/zdvvabfbDfNPwO0wNLc/BtkJQOUb36Z1HHGXpo/3mdW3ydV
V8nuDJC3BeadkL+m+eN+QS8OL79CVnG/b9VWpmn7aP4ZYK7r2SPpMtmD9c82
bGg2dT/NH/fr8IndU0XW8L6vnb1ybMoBmj/2u2v65coqshdt/Xxl4NSDNH+8
75TW/829TJYyQWu2LbTftEM0/0wQTWa+30gjmzJBPV/8iRRbRPPPBOmtqKPB
18hmrO/TsWHajMM0/0yAL2PjpZtkC64/mfOye/YRmj+uf8HW8KNqMuD6bu2G
5c0tpvlngrzo3sUfb5Ot6PR1Wp8FJTR/vO9ftTGn75Jl9JWJY5cvPkrzx/3K
BpfHPyTbMkF5Ke3mx8nHaP6Y/xi66sITssD7LrlfNdp5nOaP9/X0/COxvkrz
zwRXXNiR2BHkfHTLmpmxy8lKJni3rvwzoVQN/T/iaL7b
     "]]}, 
   {Hue[0.9323792124926413, 0.6, 0.6], PointBox[CompressedData["
1:eJxd2HdUFNfbB/C1QowFOwriaizEFmwBLPi1JaioSBRRoi7Slr7AUhYWmG22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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.445693011080385*^9, 3.445693035511705*^9}, 
   3.4456932217297297`*^9, 3.445695099081821*^9, 3.445695777651144*^9, 
   3.44569621668326*^9, 3.445696306806594*^9, 3.4456965222936277`*^9, 
   3.4456970918063803`*^9, 3.445697592268742*^9, 3.445697793353101*^9, 
   3.445698131476881*^9, 3.4456984560834627`*^9, {3.445698529448236*^9, 
   3.445698546902193*^9}, 3.445769865670526*^9, 3.445770679775371*^9, 
   3.445771068438896*^9, 3.445771620244232*^9, 3.44577219716649*^9, 
   3.4457722945176163`*^9, {3.4457728008518143`*^9, 3.44577282632953*^9}, 
   3.4457730476805477`*^9, {3.4457730960915203`*^9, 3.445773104551662*^9}, 
   3.445773197720985*^9, 3.445773233691918*^9, 3.445773279011272*^9, 
   3.445773431145508*^9, 3.445773617185302*^9, 3.445773733643413*^9, 
   3.445774101272928*^9, 3.4457789480332108`*^9, 3.445782311472579*^9, 
   3.445782884481044*^9, 3.445783913722437*^9, 3.445785272237554*^9, 
   3.4457861888677063`*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxdmkmQJkUVgItNGhAoYYAGBqgZhqEdCKPcWx0k3bDdf3Fr9wJFW1EoV1rc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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.445693011080385*^9, 3.445693035511705*^9}, 
   3.4456932217297297`*^9, 3.445695099081821*^9, 3.445695777651144*^9, 
   3.44569621668326*^9, 3.445696306806594*^9, 3.4456965222936277`*^9, 
   3.4456970918063803`*^9, 3.445697592268742*^9, 3.445697793353101*^9, 
   3.445698131476881*^9, 3.4456984560834627`*^9, {3.445698529448236*^9, 
   3.445698546902193*^9}, 3.445769865670526*^9, 3.445770679775371*^9, 
   3.445771068438896*^9, 3.445771620244232*^9, 3.44577219716649*^9, 
   3.4457722945176163`*^9, {3.4457728008518143`*^9, 3.44577282632953*^9}, 
   3.4457730476805477`*^9, {3.4457730960915203`*^9, 3.445773104551662*^9}, 
   3.445773197720985*^9, 3.445773233691918*^9, 3.445773279011272*^9, 
   3.445773431145508*^9, 3.445773617185302*^9, 3.445773733643413*^9, 
   3.445774101272928*^9, 3.4457789480332108`*^9, 3.445782311472579*^9, 
   3.445782884481044*^9, 3.445783913722437*^9, 3.445785272237554*^9, 
   3.445786189196162*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "here", " ", "is", " ", "the", " ", "final", " ", "hadamard"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{"final", "=", 
     RowBox[{"candmat", "[", 
      RowBox[{"track", "[", 
       RowBox[{"[", 
        RowBox[{"cntr", ",", "3"}], "]"}], "]"}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"comprising", " ", "equimodular", " ", "elements"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", 
    RowBox[{
     SqrtBox["6"], 
     RowBox[{"Abs", "[", "final", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"of", " ", "various", " ", "phases"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", 
    RowBox[{"Arg", "[", "final", "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "and", " ", "looking", " ", "very", " ", "nicely", " ", "unitary"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", 
    RowBox[{"Chop", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Conjugate", "[", "final", "]"}], "]"}], ".", "final"}], ",", 
      
      SuperscriptBox["10", 
       RowBox[{"-", "6"}]]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4457723642332287`*^9, 3.445772517536854*^9}, {
  3.4457725589551983`*^9, 3.4457725655307198`*^9}, {3.445772868049663*^9, 
  3.445773014137611*^9}, {3.4457731132204647`*^9, 3.445773150222458*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.08113214488872074`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.400105288308493`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.11877752706427351`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.39058746233227004`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.40039980495734734`"}], "-", 
       RowBox[{"0.07966594540194039`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.060943866687819426`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.4036737690014104`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.26870202414838285`"}], "-", 
       RowBox[{"0.30735303623883176`", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.24130541875531186`"}], "+", 
       RowBox[{"0.32929980495893146`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.10146606787963272`"}], "-", 
       RowBox[{"0.39543811618976804`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.2871699957257322`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.2901724663395024`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.3644094336186456`"}], "+", 
       RowBox[{"0.1840446450087713`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.01176263406277309`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.4080788001190113`", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.3810502770043064`"}], "-", 
       RowBox[{"0.14651741555735998`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.369025224314446`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.1746054136799301`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.1991446892149171`"}], "-", 
       RowBox[{"0.35638190108949247`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.09871945830107366`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.39613272424707513`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.29579800686115615`"}], "+", 
       RowBox[{"0.28137200607671353`", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.20458842927317736`"}], "-", 
       RowBox[{"0.35328492930522926`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.39116265114171994`"}], "+", 
       RowBox[{"0.11686935876630714`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.285336724313343`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.2919753764015006`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.15076251737806903`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.37939073528552875`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.24859645173902944`"}], "+", 
       RowBox[{"0.3238309294206332`", " ", "\[ImaginaryI]"}]}]},
     {
      RowBox[{"0.4082482904638631`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.33756368968128575`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.22960274840563938`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.40342232282333923`"}], "+", 
       RowBox[{"0.06258670876862121`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.38121051633163683`"}], "-", 
       RowBox[{"0.1460999962519971`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "0.3542646992111665`"}], "+", 
       RowBox[{"0.2028871350270599`", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"0.3930855582208445`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.11022890086031782`", " ", "\[ImaginaryI]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.4457723739798717`*^9, 3.445772393823008*^9}, {
   3.445772454281539*^9, 3.445772518126732*^9}, 3.445772565944785*^9, 
   3.4457728009112787`*^9, 3.44577283255648*^9, 3.445773047861189*^9, {
   3.4457731085994473`*^9, 3.445773159266041*^9}, 3.445773197894266*^9, 
   3.4457732337508383`*^9, 3.445773279069373*^9, 3.445773431220299*^9, 
   3.445773617241527*^9, 3.445773733819791*^9, 3.445774101448185*^9, 
   3.445778948204569*^9, 3.445782321378983*^9, 3.445782884591448*^9, 
   3.445783913796574*^9, 3.445785272740446*^9, 3.4457861893721848`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.`", "1.`", "1.`", "1.`", "1.`", "1.`"},
     {"1.`", "0.9999999999999999`", "1.`", "1.0000000000000002`", 
      "1.0000000000000002`", "1.0000000000000002`"},
     {"1.`", "1.`", "1.`", "1.`", "1.`", "1.`"},
     {"1.`", "1.0000000000000002`", "1.`", "1.`", "0.9999999999999999`", 
      "1.`"},
     {"1.`", "1.`", "1.`", "0.9999999999999999`", "1.`", "1.`"},
     {"1.`", "1.`", "1.0000000000000002`", "1.`", "1.`", "1.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.4457723739798717`*^9, 3.445772393823008*^9}, {
   3.445772454281539*^9, 3.445772518126732*^9}, 3.445772565944785*^9, 
   3.4457728009112787`*^9, 3.44577283255648*^9, 3.445773047861189*^9, {
   3.4457731085994473`*^9, 3.445773159266041*^9}, 3.445773197894266*^9, 
   3.4457732337508383`*^9, 3.445773279069373*^9, 3.445773431220299*^9, 
   3.445773617241527*^9, 3.445773733819791*^9, 3.445774101448185*^9, 
   3.445778948204569*^9, 3.445782321378983*^9, 3.445782884591448*^9, 
   3.445783913796574*^9, 3.445785272740446*^9, 3.445786189420649*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "1.3707320185814238`", "1.2755826036790054`", 
      RowBox[{"-", "2.9451915271837787`"}], 
      RowBox[{"-", "1.4209548612246226`"}], 
      RowBox[{"-", "2.289198867391209`"}]},
     {"0.`", "2.203187428800934`", 
      RowBox[{"-", "1.8219690887785867`"}], "0.7905986184895192`", 
      "2.6739139529555467`", 
      RowBox[{"-", "1.541979887341941`"}]},
     {"0.`", 
      RowBox[{"-", "2.7745111448777404`"}], 
      RowBox[{"-", "0.4419403199212734`"}], 
      RowBox[{"-", "2.080367417273204`"}], "1.326563180106719`", 
      "2.3811836572026492`"},
     {"0.`", 
      RowBox[{"-", "2.095708794538639`"}], "2.8512607065696027`", 
      "0.7968968995018361`", 
      RowBox[{"-", "1.1925500922050294`"}], "2.2255129136080587`"},
     {"0.`", 
      RowBox[{"-", "0.5972970554951609`"}], "2.9876801986328867`", 
      RowBox[{"-", "2.77560635866097`"}], "2.621489151602939`", 
      "0.2733977694533865`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.4457723739798717`*^9, 3.445772393823008*^9}, {
   3.445772454281539*^9, 3.445772518126732*^9}, 3.445772565944785*^9, 
   3.4457728009112787`*^9, 3.44577283255648*^9, 3.445773047861189*^9, {
   3.4457731085994473`*^9, 3.445773159266041*^9}, 3.445773197894266*^9, 
   3.4457732337508383`*^9, 3.445773279069373*^9, 3.445773431220299*^9, 
   3.445773617241527*^9, 3.445773733819791*^9, 3.445774101448185*^9, 
   3.445778948204569*^9, 3.445782321378983*^9, 3.445782884591448*^9, 
   3.445783913796574*^9, 3.445785272740446*^9, 3.4457861894873466`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.0000000000000002`", "0", "0", "0", "0", "0"},
     {"0", "1.0000000000000004`", "0", "0", "0", "0"},
     {"0", "0", "1.0000000000000002`", "0", "0", "0"},
     {"0", "0", "0", "1.0000000000000002`", "0", "0"},
     {"0", "0", "0", "0", "1.0000000000000002`", "0"},
     {"0", "0", "0", "0", "0", "1.0000000000000002`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.4457723739798717`*^9, 3.445772393823008*^9}, {
   3.445772454281539*^9, 3.445772518126732*^9}, 3.445772565944785*^9, 
   3.4457728009112787`*^9, 3.44577283255648*^9, 3.445773047861189*^9, {
   3.4457731085994473`*^9, 3.445773159266041*^9}, 3.445773197894266*^9, 
   3.4457732337508383`*^9, 3.445773279069373*^9, 3.445773431220299*^9, 
   3.445773617241527*^9, 3.445773733819791*^9, 3.445774101448185*^9, 
   3.445778948204569*^9, 3.445782321378983*^9, 3.445782884591448*^9, 
   3.445783913796574*^9, 3.445785272740446*^9, 3.4457861895378447`*^9}]
}, Open  ]]
},
WindowSize->{1275, 969},
WindowMargins->{{-7, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 1472, 32, 156, "Input"],
Cell[2043, 55, 1093, 27, 133, "Input"],
Cell[3139, 84, 920, 22, 87, "Input"],
Cell[4062, 108, 1079, 21, 79, "Input"],
Cell[5144, 131, 1031, 22, 136, "Input"],
Cell[CellGroupData[{
Cell[6200, 157, 2087, 45, 186, "Input"],
Cell[8290, 204, 2220, 43, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10547, 252, 1685, 41, 169, "Input"],
Cell[12235, 295, 1796, 29, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14068, 329, 1363, 34, 87, "Input"],
Cell[15434, 365, 2757, 56, 111, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18228, 426, 1514, 39, 163, "Input"],
Cell[19745, 467, 4367, 101, 218, "Output"]
}, Open  ]],
Cell[24127, 571, 1586, 33, 127, "Input"],
Cell[25716, 606, 1513, 38, 94, "Input"],
Cell[CellGroupData[{
Cell[27254, 648, 1991, 43, 133, "Input"],
Cell[29248, 693, 1588, 23, 40, "Output"]
}, Open  ]],
Cell[30851, 719, 5033, 112, 364, "Input"],
Cell[CellGroupData[{
Cell[35909, 835, 330, 7, 64, "Input"],
Cell[36242, 844, 1496, 22, 40, "Output"]
}, Open  ]],
Cell[37753, 869, 1750, 39, 124, "Input"],
Cell[39506, 910, 16239, 360, 1026, "Input"],
Cell[CellGroupData[{
Cell[55770, 1274, 2530, 57, 248, "Input"],
Cell[58303, 1333, 1544, 22, 40, "Output"],
Cell[59850, 1357, 1948, 29, 40, "Output"],
Cell[61801, 1388, 37597, 1297, 1152, "Output"],
Cell[99401, 2687, 1956, 30, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101394, 2722, 3878, 91, 296, "Input"],
Cell[105275, 2815, 2325, 42, 120, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107637, 2862, 1001, 22, 110, "Input"],
Cell[108641, 2886, 2658, 68, 792, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111336, 2959, 1620, 42, 148, "Input"],
Cell[112959, 3003, 7244, 124, 360, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120240, 3132, 3033, 70, 250, "Input"],
Cell[123276, 3204, 1905, 37, 141, "Output"],
Cell[125184, 3243, 1541, 24, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126762, 3272, 2716, 64, 250, "Input"],
Cell[129481, 3338, 1847, 37, 141, "Output"],
Cell[131331, 3377, 1458, 23, 40, "Output"]
}, Open  ]],
Cell[132804, 3403, 28570, 612, 1901, "Input"],
Cell[CellGroupData[{
Cell[161399, 4019, 680, 14, 64, "Input"],
Cell[CellGroupData[{
Cell[162104, 4037, 283, 7, 39, "Print"],
Cell[162390, 4046, 283, 7, 39, "Print"],
Cell[162676, 4055, 317, 8, 39, "Print"],
Cell[162996, 4065, 300, 7, 39, "Print"],
Cell[163299, 4074, 299, 7, 39, "Print"],
Cell[163601, 4083, 299, 7, 39, "Print"],
Cell[163903, 4092, 317, 8, 39, "Print"],
Cell[164223, 4102, 300, 7, 39, "Print"],
Cell[164526, 4111, 299, 7, 39, "Print"],
Cell[164828, 4120, 298, 7, 39, "Print"],
Cell[165129, 4129, 298, 7, 39, "Print"],
Cell[165430, 4138, 298, 7, 39, "Print"],
Cell[165731, 4147, 284, 7, 39, "Print"],
Cell[166018, 4156, 309, 8, 39, "Print"],
Cell[166330, 4166, 325, 8, 39, "Print"],
Cell[166658, 4176, 308, 8, 39, "Print"],
Cell[166969, 4186, 325, 8, 39, "Print"],
Cell[167297, 4196, 344, 9, 39, "Print"],
Cell[167644, 4207, 323, 8, 39, "Print"],
Cell[167970, 4217, 311, 8, 39, "Print"],
Cell[168284, 4227, 325, 8, 39, "Print"],
Cell[168612, 4237, 311, 8, 39, "Print"],
Cell[168926, 4247, 308, 8, 39, "Print"],
Cell[169237, 4257, 309, 8, 39, "Print"],
Cell[169549, 4267, 309, 8, 39, "Print"],
Cell[169861, 4277, 308, 8, 39, "Print"],
Cell[170172, 4287, 323, 8, 39, "Print"],
Cell[170498, 4297, 308, 8, 39, "Print"],
Cell[170809, 4307, 309, 8, 39, "Print"],
Cell[171121, 4317, 309, 8, 39, "Print"],
Cell[171433, 4327, 323, 8, 39, "Print"],
Cell[171759, 4337, 325, 8, 39, "Print"],
Cell[172087, 4347, 325, 8, 39, "Print"],
Cell[172415, 4357, 323, 8, 39, "Print"],
Cell[172741, 4367, 322, 8, 39, "Print"],
Cell[173066, 4377, 308, 8, 39, "Print"],
Cell[173377, 4387, 365, 9, 39, "Print"],
Cell[173745, 4398, 363, 9, 39, "Print"],
Cell[174111, 4409, 376, 9, 39, "Print"],
Cell[174490, 4420, 361, 9, 39, "Print"],
Cell[174854, 4431, 378, 9, 39, "Print"],
Cell[175235, 4442, 377, 9, 39, "Print"],
Cell[175615, 4453, 377, 9, 39, "Print"],
Cell[175995, 4464, 362, 9, 39, "Print"],
Cell[176360, 4475, 361, 9, 39, "Print"],
Cell[176724, 4486, 378, 9, 39, "Print"],
Cell[177105, 4497, 379, 9, 39, "Print"],
Cell[177487, 4508, 354, 9, 39, "Print"],
Cell[177844, 4519, 370, 9, 39, "Print"],
Cell[178217, 4530, 352, 9, 39, "Print"],
Cell[178572, 4541, 368, 9, 39, "Print"],
Cell[178943, 4552, 352, 9, 39, "Print"],
Cell[179298, 4563, 353, 9, 39, "Print"],
Cell[179654, 4574, 355, 9, 39, "Print"],
Cell[180012, 4585, 368, 9, 39, "Print"],
Cell[180383, 4596, 354, 9, 39, "Print"],
Cell[180740, 4607, 367, 9, 39, "Print"],
Cell[181110, 4618, 368, 9, 39, "Print"],
Cell[181481, 4629, 368, 9, 39, "Print"],
Cell[181852, 4640, 368, 9, 39, "Print"],
Cell[182223, 4651, 370, 9, 39, "Print"],
Cell[182596, 4662, 352, 9, 39, "Print"],
Cell[182951, 4673, 369, 9, 39, "Print"],
Cell[183323, 4684, 369, 9, 39, "Print"],
Cell[183695, 4695, 368, 9, 39, "Print"],
Cell[184066, 4706, 367, 9, 39, "Print"],
Cell[184436, 4717, 368, 9, 39, "Print"],
Cell[184807, 4728, 353, 9, 39, "Print"],
Cell[185163, 4739, 353, 9, 39, "Print"]
}, Open  ]],
Cell[185531, 4751, 510, 7, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186078, 4763, 1660, 39, 110, "Input"],
Cell[187741, 4804, 218358, 3627, 337, 185246, 3084, "CachedBoxData", \
"BoxData", "Output"],
Cell[406102, 8433, 5081, 85, 309, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[411220, 8523, 1565, 41, 225, "Input"],
Cell[412788, 8566, 5686, 115, 162, "Output"],
Cell[418477, 8683, 1552, 31, 162, "Output"],
Cell[420032, 8716, 2095, 45, 162, "Output"],
Cell[422130, 8763, 1448, 29, 162, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
